@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -30,26 +31,25 @@
 
 
 #include <vcl/svapp.hxx>
-
+#include <sal/macros.h>
 #include "cfgitem.hxx"
 
 #include "starmath.hrc"
 #include "smdll.hxx"
 #include "format.hxx"
 
-using namespace rtl;
 using namespace com::sun::star;
 using namespace com::sun::star::uno;
 using namespace com::sun::star::beans;
 
+using ::rtl::OUString;
+
 
 static const char* aRootName = "Office.Math";
 
 #define SYMBOL_LIST         "SymbolList"
 #define FONT_FORMAT_LIST    "FontFormatList"
 
-SV_IMPL_OBJARR( SmFntFmtListEntryArr, SmFntFmtListEntry );
-
 /////////////////////////////////////////////////////////////////
 
 
@@ -70,11 +70,10 @@ static Sequence< OUString > lcl_GetFontPropertyNames()
 
     Sequence< OUString > aNames( 6 );
     OUString *pNames = aNames.getArray();
-    for( INT32 i = 0; *ppPropName;  ++i, ++ppPropName )
+    for( sal_Int32 i = 0; *ppPropName;  ++i, ++ppPropName )
     {
         pNames[i] = A2OU( *ppPropName );
     }
-    //aNames.realloc( i );
     return aNames;
 }
 
@@ -96,11 +95,10 @@ static Sequence< OUString > lcl_GetSymbolPropertyNames()
 
     Sequence< OUString > aNames( 4 );
     OUString *pNames = aNames.getArray();
-    for( INT32 i = 0; *ppPropName;  ++i, ++ppPropName )
+    for( sal_Int32 i = 0; *ppPropName;  ++i, ++ppPropName )
     {
         pNames[i] = A2OU( *ppPropName );
     }
-    //aNames.realloc( i );
     return aNames;
 }
 
@@ -113,7 +111,8 @@ static const char * aMathPropNames[] =
     "Print/Frame",
     "Print/Size",
     "Print/ZoomFactor",
-    //"Misc/NoSymbolsWarning",
+    "LoadSave/IsSaveOnlyUsedSymbols",
+    //"Misc/NoSymbolsWarning",  @deprecated
     "Misc/IgnoreSpacesRight",
     "View/ToolboxVisible",
     "View/AutoRedraw",
@@ -170,32 +169,31 @@ static const char * aFormatPropNames[] =
 
 
 static Sequence< OUString > lcl_GetPropertyNames( 
-        const char * aPropNames[], USHORT nCount )
+        const char * aPropNames[], sal_uInt16 nCount )
 {
 
     const char** ppPropName = aPropNames;
 
     Sequence< OUString > aNames( nCount );
     OUString *pNames = aNames.getArray();
-    for (INT32 i = 0;  i < nCount;  ++i, ++ppPropName)
+    for (sal_Int32 i = 0;  i < nCount;  ++i, ++ppPropName)
     {
         pNames[i] = A2OU( *ppPropName );
     }
-    //aNames.realloc( i );
     return aNames;
 }
 
     
 static Sequence< OUString > GetFormatPropertyNames()
 {
-    USHORT nCnt = sizeof(aFormatPropNames) / sizeof(aFormatPropNames[0]);
+    sal_uInt16 nCnt = SAL_N_ELEMENTS(aFormatPropNames);
     return lcl_GetPropertyNames( aFormatPropNames, nCnt );
 }
 
 
 static Sequence< OUString > GetOtherPropertyNames()
 {
-    USHORT nCnt = sizeof(aMathPropNames) / sizeof(aMathPropNames[0]);
+    sal_uInt16 nCnt = SAL_N_ELEMENTS(aMathPropNames);
     return lcl_GetPropertyNames( aMathPropNames, nCnt );
 }
 
@@ -204,15 +202,16 @@ static Sequence< OUString > GetOtherPropertyNames()
 struct SmCfgOther
 {
     SmPrintSize     ePrintSize;
-    USHORT          nPrintZoomFactor;
-    BOOL            bPrintTitle;
-    BOOL            bPrintFormulaText;
-    BOOL            bPrintFrame;
-    BOOL            bIgnoreSpacesRight;
-    BOOL            bToolboxVisible;
-    BOOL            bAutoRedraw;
-    BOOL            bFormulaCursor;
-    //BOOL            bNoSymbolsWarning;
+    sal_uInt16      nPrintZoomFactor;
+    bool            bPrintTitle;
+    bool            bPrintFormulaText;
+    bool            bPrintFrame;
+    bool            bIsSaveOnlyUsedSymbols;
+    bool            bIgnoreSpacesRight;
+    bool            bToolboxVisible;
+    bool            bAutoRedraw;
+    bool            bFormulaCursor;
+    //sal_Bool            bNoSymbolsWarning;
 
     SmCfgOther();
 };
@@ -225,7 +224,7 @@ SmCfgOther::SmCfgOther()
     bPrintTitle         = bPrintFormulaText   =
     bPrintFrame         = bIgnoreSpacesRight  =
     bToolboxVisible     = bAutoRedraw         =
-    bFormulaCursor      = /*bNoSymbolsWarning   =*/ TRUE;
+    bFormulaCursor      = bIsSaveOnlyUsedSymbols = true;
 }
 
 /////////////////////////////////////////////////////////////////
@@ -245,11 +244,11 @@ SmFontFormat::SmFontFormat()
 SmFontFormat::SmFontFormat( const Font &rFont )
 {
     aName       = rFont.GetName();
-    nCharSet    = (INT16) rFont.GetCharSet();
-    nFamily     = (INT16) rFont.GetFamily();
-    nPitch      = (INT16) rFont.GetPitch();
-    nWeight     = (INT16) rFont.GetWeight();
-    nItalic     = (INT16) rFont.GetItalic();
+    nCharSet    = (sal_Int16) rFont.GetCharSet();
+    nFamily     = (sal_Int16) rFont.GetFamily();
+    nPitch      = (sal_Int16) rFont.GetPitch();
+    nWeight     = (sal_Int16) rFont.GetWeight();
+    nItalic     = (sal_Int16) rFont.GetItalic();
 }
 
 
@@ -266,7 +265,7 @@ const Font SmFontFormat::GetFont() const
 }
 
     
-BOOL SmFontFormat::operator == ( const SmFontFormat &rFntFmt ) const
+bool SmFontFormat::operator == ( const SmFontFormat &rFntFmt ) const
 {
     return  aName    == rFntFmt.aName       &&
             nCharSet == rFntFmt.nCharSet    &&
@@ -288,17 +287,16 @@ SmFntFmtListEntry::SmFntFmtListEntry( const String &rId, const SmFontFormat &rFn
 
 SmFontFormatList::SmFontFormatList()
 {
-    bModified = FALSE;
+    bModified = false;
 }
 
 
 void SmFontFormatList::Clear()
 {
-    USHORT nCnt = aEntries.Count();
-    if (nCnt)
+    if (!aEntries.empty())
     {
-        aEntries.Remove( 0, nCnt );
-        SetModified( TRUE );
+        aEntries.clear();
+        SetModified( true );
     }
 }
 
@@ -307,47 +305,44 @@ void SmFontFormatList::AddFontFormat( const String &rFntFmtId,
         const SmFontFormat &rFntFmt )
 {
     const SmFontFormat *pFntFmt = GetFontFormat( rFntFmtId );
-    DBG_ASSERT( !pFntFmt, "FontFormatId already exists" );
+    OSL_ENSURE( !pFntFmt, "FontFormatId already exists" );
     if (!pFntFmt)
     {
         SmFntFmtListEntry aEntry( rFntFmtId, rFntFmt );
-        aEntries.Insert( aEntry, aEntries.Count() );
-        SetModified( TRUE );
+        aEntries.push_back( aEntry );
+        SetModified( true );
     }
 }
     
     
 void SmFontFormatList::RemoveFontFormat( const String &rFntFmtId )
 {
-    USHORT nPos = 0xFFFF;
-
+    
     // search for entry
-    USHORT nCnt = aEntries.Count();
-    for (USHORT i = 0;  i < nCnt  &&  nPos == 0xFFFF;  ++i)
+    for (size_t i = 0;  i < aEntries.size();  ++i)
     {
         if (aEntries[i].aId == rFntFmtId)
-            nPos = i;
-    }
-
-    // remove entry if found
-    if (nPos != 0xFFFF)
-    {
-        aEntries.Remove( nPos );
-        SetModified( TRUE );
+        {
+            // remove entry if found
+            aEntries.erase( aEntries.begin() + i );
+            SetModified( true );
+            break;
+        }
     }
 }
 
     
 const SmFontFormat * SmFontFormatList::GetFontFormat( const String &rFntFmtId ) const
 {
-    SmFontFormat *pRes = 0;
+    const SmFontFormat *pRes = 0;
 
-    USHORT nCnt = aEntries.Count();
-    USHORT i;
-    for (i = 0;  i < nCnt  &&  !pRes;  ++i)
+    for (size_t i = 0;  i < aEntries.size();  ++i)
     {
         if (aEntries[i].aId == rFntFmtId)
+        {
             pRes = &aEntries[i].aFntFmt;
+            break;
+        }
     }
     
     return pRes;
@@ -355,11 +350,11 @@ const SmFontFormat * SmFontFormatList::GetFontFormat( const String &rFntFmtId )
 
 
 
-const SmFontFormat * SmFontFormatList::GetFontFormat( USHORT nPos ) const
+const SmFontFormat * SmFontFormatList::GetFontFormat( size_t nPos ) const
 {
-    SmFontFormat *pRes = 0;
-    if (nPos < aEntries.Count())
-        pRes = &aEntries[ nPos ].aFntFmt;
+    const SmFontFormat *pRes = 0;
+    if (nPos < aEntries.size())
+        pRes = &aEntries[nPos].aFntFmt;
     return pRes;
 }
 
@@ -368,19 +363,20 @@ const String SmFontFormatList::GetFontFormatId( const SmFontFormat &rFntFmt ) co
 {
     String aRes;
 
-    USHORT nCnt = aEntries.Count();
-    USHORT i;
-    for (i = 0;  i < nCnt  &&  0 == aRes.Len();  ++i)
+    for (size_t i = 0;  i < aEntries.size();  ++i)
     {
-        if (aEntries[i].aFntFmt == rFntFmt)
+        if (aEntries[i].aFntFmt == rFntFmt) 
+        {
             aRes = aEntries[i].aId;
+            break;
+        }
     }
     
     return aRes;
 }
 
 
-const String SmFontFormatList::GetFontFormatId( const SmFontFormat &rFntFmt, BOOL bAdd )
+const String SmFontFormatList::GetFontFormatId( const SmFontFormat &rFntFmt, bool bAdd )
 {
     String aRes( GetFontFormatId( rFntFmt) );
     if (0 == aRes.Len()  &&  bAdd)
@@ -392,10 +388,10 @@ const String SmFontFormatList::GetFontFormatId( const SmFontFormat &rFntFmt, BOO
 }
 
 
-const String SmFontFormatList::GetFontFormatId( USHORT nPos ) const
+const String SmFontFormatList::GetFontFormatId( size_t nPos ) const
 {
     String aRes;
-    if (nPos < aEntries.Count())
+    if (nPos < aEntries.size())
         aRes = aEntries[nPos].aId;
     return aRes;
 }
@@ -407,16 +403,19 @@ const String SmFontFormatList::GetNewFontFormatId() const
     
     String aRes;
 
-    String aPrefix( RTL_CONSTASCII_STRINGPARAM( "Id" ) );
-    INT32 nCnt = GetCount();
-    for (INT32 i = 1;  i <= nCnt + 1  &&  0 == aRes.Len();  ++i)
+    String aPrefix( RTL_CONSTASCII_USTRINGPARAM( "Id" ) );
+    sal_Int32 nCnt = GetCount();
+    for (sal_Int32 i = 1;  i <= nCnt + 1;  ++i)
     {
         String aTmpId( aPrefix );
         aTmpId += String::CreateFromInt32( i );
         if (!GetFontFormat( aTmpId ))
+        {
             aRes = aTmpId;
+            break;
+        }
     }
-    DBG_ASSERT( 0 != aRes.Len(), "failed to create new FontFormatId" );
+    OSL_ENSURE( 0 != aRes.Len(), "failed to create new FontFormatId" );
 
     return aRes;
 }
@@ -431,7 +430,7 @@ SmMathConfig::SmMathConfig() :
     pFontFormatList = 0;
     pSymbolMgr      = 0;
 
-    bIsOtherModified = bIsFormatModified = FALSE;
+    bIsOtherModified = bIsFormatModified = false;
 }
     
 
@@ -445,19 +444,19 @@ SmMathConfig::~SmMathConfig()
 }
 
           
-void SmMathConfig::SetOtherModified( BOOL bVal )
+void SmMathConfig::SetOtherModified( bool bVal )
 {
     bIsOtherModified = bVal;
 }
 
 
-void SmMathConfig::SetFormatModified( BOOL bVal )
+void SmMathConfig::SetFormatModified( bool bVal )
 {
     bIsFormatModified = bVal;
 }
 
 
-void SmMathConfig::SetFontFormatListModified( BOOL bVal )
+void SmMathConfig::SetFontFormatListModified( bool bVal )
 {
     if (pFontFormatList)
         pFontFormatList->SetModified( bVal );
@@ -469,11 +468,11 @@ void SmMathConfig::ReadSymbol( SmSym &rSymbol,
                         const rtl::OUString &rBaseNode ) const
 {
     Sequence< OUString > aNames = lcl_GetSymbolPropertyNames();
-    INT32 nProps = aNames.getLength();
+    sal_Int32 nProps = aNames.getLength();
 
     OUString aDelim( OUString::valueOf( (sal_Unicode) '/' ) );
     OUString *pName = aNames.getArray();
-    for (INT32 i = 0;  i < nProps;  ++i)
+    for (sal_Int32 i = 0;  i < nProps;  ++i)
     {
         OUString &rName = pName[i];
         OUString aTmp( rName );
@@ -490,39 +489,39 @@ void SmMathConfig::ReadSymbol( SmSym &rSymbol,
     {
         const Any * pValue = aValues.getConstArray();
         Font        aFont;
-        sal_Unicode cChar = '\0';
+        sal_UCS4    cChar = '\0';
         String      aSet;
-        BOOL        bPredefined = FALSE;
+        bool        bPredefined = false;
 
         OUString    aTmpStr;
-        INT32       nTmp32 = 0;
-        BOOL        bTmp = FALSE;
+        sal_Int32       nTmp32 = 0;
+        bool        bTmp = false;
 
-        BOOL bOK = TRUE;
+        bool bOK = true;
         if (pValue->hasValue()  &&  (*pValue >>= nTmp32))
-            cChar = (sal_Unicode) nTmp32;
+            cChar = static_cast< sal_UCS4 >( nTmp32 );
         else
-            bOK = FALSE;
+            bOK = false;
         ++pValue;
         if (pValue->hasValue()  &&  (*pValue >>= aTmpStr))
             aSet = aTmpStr;
         else
-            bOK = FALSE;
+            bOK = false;
         ++pValue;
         if (pValue->hasValue()  &&  (*pValue >>= bTmp))
             bPredefined = bTmp;
         else
-            bOK = FALSE;
+            bOK = false;
         ++pValue;
         if (pValue->hasValue()  &&  (*pValue >>= aTmpStr))
         {
             const SmFontFormat *pFntFmt = GetFontFormatList().GetFontFormat( aTmpStr );
-            DBG_ASSERT( pFntFmt, "unknown FontFormat" );
+            OSL_ENSURE( pFntFmt, "unknown FontFormat" );
             if (pFntFmt)
                 aFont = pFntFmt->GetFont();
         }
         else
-            bOK = FALSE;
+            bOK = false;
         ++pValue;
 
         if (bOK)
@@ -533,11 +532,11 @@ void SmMathConfig::ReadSymbol( SmSym &rSymbol,
             {
                 String aTmp;
                 aTmp = GetUiSymbolName( rSymbolName );
-                DBG_ASSERT( aTmp.Len(), "localized symbol-name not found" );
+                OSL_ENSURE( aTmp.Len(), "localized symbol-name not found" );
                 if (aTmp.Len())
                     aUiName = aTmp;
                 aTmp = GetUiSymbolSetName( aSet );
-                DBG_ASSERT( aTmp.Len(), "localized symbolset-name not found" );
+                OSL_ENSURE( aTmp.Len(), "localized symbolset-name not found" );
                 if (aTmp.Len())
                     aUiSetName = aTmp;
             }
@@ -548,7 +547,7 @@ void SmMathConfig::ReadSymbol( SmSym &rSymbol,
         }
         else
         {
-            DBG_ERROR( "symbol read error" );
+            OSL_FAIL( "symbol read error" );
         }
     }
 }
@@ -583,7 +582,7 @@ void SmMathConfig::GetSymbols( std::vector< SmSym > &rSymbols ) const
 {
     Sequence< OUString > aNodes( ((SmMathConfig*) this)->GetNodeNames( A2OU( SYMBOL_LIST ) ) );
     const OUString *pNode = aNodes.getConstArray();
-    INT32 nNodes = aNodes.getLength();
+    sal_Int32 nNodes = aNodes.getLength();
     
     rSymbols.resize( nNodes );
     std::vector< SmSym >::iterator aIt( rSymbols.begin() );
@@ -601,7 +600,7 @@ void SmMathConfig::SetSymbols( const std::vector< SmSym > &rNewSymbols )
 
     Sequence< OUString > aNames = lcl_GetSymbolPropertyNames();
     const OUString *pNames = aNames.getConstArray();
-    sal_uIntPtr nSymbolProps = sal::static_int_cast< UINT32 >(aNames.getLength());
+    sal_uIntPtr nSymbolProps = sal::static_int_cast< sal_uInt32 >(aNames.getLength());
     
     Sequence< PropertyValue > aValues( nCount * nSymbolProps );
     PropertyValue *pValues = aValues.getArray();
@@ -613,7 +612,6 @@ void SmMathConfig::SetSymbols( const std::vector< SmSym > &rNewSymbols )
     while (aIt != aEnd)
     {
         const SmSym &rSymbol = *aIt++;
-        //const Font  &rFont = rSymbol.GetFace(); 
         OUString  aNodeNameDelim( A2OU( SYMBOL_LIST ) );
         aNodeNameDelim += aDelim;
         aNodeNameDelim += rSymbol.GetExportName();
@@ -624,7 +622,7 @@ void SmMathConfig::SetSymbols( const std::vector< SmSym > &rNewSymbols )
         // Char
         pVal->Name  = aNodeNameDelim;
         pVal->Name += *pName++;
-        pVal->Value <<= (INT32) rSymbol.GetCharacter();
+        pVal->Value <<= static_cast< sal_UCS4 >( rSymbol.GetCharacter() );
         pVal++;
         // Set
         pVal->Name  = aNodeNameDelim;
@@ -637,18 +635,18 @@ void SmMathConfig::SetSymbols( const std::vector< SmSym > &rNewSymbols )
         // Predefined
         pVal->Name  = aNodeNameDelim;
         pVal->Name += *pName++;
-        pVal->Value <<= (BOOL) rSymbol.IsPredefined();
+        pVal->Value <<= (sal_Bool) rSymbol.IsPredefined();
         pVal++;
         // FontFormatId
         SmFontFormat aFntFmt( rSymbol.GetFace() );
-        String aFntFmtId( GetFontFormatList().GetFontFormatId( aFntFmt, TRUE ) );
-        DBG_ASSERT( aFntFmtId.Len(), "FontFormatId not found" );
+        String aFntFmtId( GetFontFormatList().GetFontFormatId( aFntFmt, true ) );
+        OSL_ENSURE( aFntFmtId.Len(), "FontFormatId not found" );
         pVal->Name  = aNodeNameDelim;
         pVal->Name += *pName++;
         pVal->Value <<= OUString( aFntFmtId );
         pVal++;
     }
-    DBG_ASSERT( pVal - pValues == sal::static_int_cast< ptrdiff_t >(nCount * nSymbolProps), "properties missing" );
+    OSL_ENSURE( pVal - pValues == sal::static_int_cast< ptrdiff_t >(nCount * nSymbolProps), "properties missing" );
     ReplaceSetProperties( A2OU( SYMBOL_LIST ) , aValues );
 
     StripFontFormatList( rNewSymbols );
@@ -675,20 +673,20 @@ void SmMathConfig::LoadFontFormatList()
 
     Sequence< OUString > aNodes( GetNodeNames( A2OU( FONT_FORMAT_LIST ) ) );
     const OUString *pNode = aNodes.getConstArray();
-    INT32 nNodes = aNodes.getLength();
+    sal_Int32 nNodes = aNodes.getLength();
 
-    for (INT32 i = 0;  i < nNodes;  ++i)
+    for (sal_Int32 i = 0;  i < nNodes;  ++i)
     {
         SmFontFormat aFntFmt;
         ReadFontFormat( aFntFmt, pNode[i], A2OU( FONT_FORMAT_LIST ) );
         if (!pFontFormatList->GetFontFormat( pNode[i] ))
         {
-            DBG_ASSERT( 0 == pFontFormatList->GetFontFormat( pNode[i] ), 
+            OSL_ENSURE( 0 == pFontFormatList->GetFontFormat( pNode[i] ),
                     "FontFormat ID already exists" );
             pFontFormatList->AddFontFormat( pNode[i], aFntFmt );
         }
     }
-    pFontFormatList->SetModified( FALSE );
+    pFontFormatList->SetModified( false );
 }
     
 
@@ -696,11 +694,11 @@ void SmMathConfig::ReadFontFormat( SmFontFormat &rFontFormat,
         const OUString &rSymbolName, const OUString &rBaseNode ) const
 {
     Sequence< OUString > aNames = lcl_GetFontPropertyNames();
-    INT32 nProps = aNames.getLength();
+    sal_Int32 nProps = aNames.getLength();
 
     OUString aDelim( OUString::valueOf( (sal_Unicode) '/' ) );
     OUString *pName = aNames.getArray();
-    for (INT32 i = 0;  i < nProps;  ++i)
+    for (sal_Int32 i = 0;  i < nProps;  ++i)
     {
         OUString &rName = pName[i];
         OUString aTmp( rName );
@@ -718,41 +716,42 @@ void SmMathConfig::ReadFontFormat( SmFontFormat &rFontFormat,
         const Any * pValue = aValues.getConstArray();
 
         OUString    aTmpStr;
-        INT16       nTmp16 = 0;
+        sal_Int16       nTmp16 = 0;
 
-        BOOL bOK = TRUE;
+        bool bOK = true;
         if (pValue->hasValue()  &&  (*pValue >>= aTmpStr))
             rFontFormat.aName = aTmpStr;
         else
-            bOK = FALSE;
+            bOK = false;
         ++pValue;
         if (pValue->hasValue()  &&  (*pValue >>= nTmp16))
             rFontFormat.nCharSet = nTmp16; // 6.0 file-format GetSOLoadTextEncoding not needed
         else
-            bOK = FALSE;
+            bOK = false;
         ++pValue;
         if (pValue->hasValue()  &&  (*pValue >>= nTmp16))
             rFontFormat.nFamily = nTmp16;
         else
-            bOK = FALSE;
+            bOK = false;
         ++pValue;
         if (pValue->hasValue()  &&  (*pValue >>= nTmp16))
             rFontFormat.nPitch = nTmp16;
         else
-            bOK = FALSE;
+            bOK = false;
         ++pValue;
         if (pValue->hasValue()  &&  (*pValue >>= nTmp16))
             rFontFormat.nWeight = nTmp16;
         else
-            bOK = FALSE;
+            bOK = false;
         ++pValue;
         if (pValue->hasValue()  &&  (*pValue >>= nTmp16))
             rFontFormat.nItalic = nTmp16;
         else
-            bOK = FALSE;
+            bOK = false;
         ++pValue;
 
-        DBG_ASSERT( bOK, "read FontFormat failed" );
+        OSL_ENSURE( bOK, "read FontFormat failed" );
+        (void)bOK;
     }
 }
 
@@ -765,16 +764,16 @@ void SmMathConfig::SaveFontFormatList()
         return;
 
     Sequence< OUString > aNames = lcl_GetFontPropertyNames();
-    INT32 nSymbolProps = aNames.getLength();
+    sal_Int32 nSymbolProps = aNames.getLength();
     
-    USHORT nCount = rFntFmtList.GetCount();
+    size_t nCount = rFntFmtList.GetCount();
 
     Sequence< PropertyValue > aValues( nCount * nSymbolProps );
     PropertyValue *pValues = aValues.getArray();
 
     PropertyValue *pVal = pValues;
     OUString aDelim( OUString::valueOf( (sal_Unicode) '/' ) );
-    for (USHORT i = 0;  i < nCount;  ++i)
+    for (size_t i = 0;  i < nCount;  ++i)
     {
         String aFntFmtId( rFntFmtList.GetFontFormatId( i ) );
         const SmFontFormat aFntFmt( *rFntFmtList.GetFontFormat( aFntFmtId ) );
@@ -794,65 +793,64 @@ void SmMathConfig::SaveFontFormatList()
         // CharSet
         pVal->Name  = aNodeNameDelim;
         pVal->Name += *pName++;
-        pVal->Value <<= (INT16) aFntFmt.nCharSet; // 6.0 file-format GetSOStoreTextEncoding not needed
+        pVal->Value <<= (sal_Int16) aFntFmt.nCharSet; // 6.0 file-format GetSOStoreTextEncoding not needed
         pVal++;
         // Family
         pVal->Name  = aNodeNameDelim;
         pVal->Name += *pName++;
-        pVal->Value <<= (INT16) aFntFmt.nFamily;
+        pVal->Value <<= (sal_Int16) aFntFmt.nFamily;
         pVal++;
         // Pitch
         pVal->Name  = aNodeNameDelim;
         pVal->Name += *pName++;
-        pVal->Value <<= (INT16) aFntFmt.nPitch;
+        pVal->Value <<= (sal_Int16) aFntFmt.nPitch;
         pVal++;
         // Weight
         pVal->Name  = aNodeNameDelim;
         pVal->Name += *pName++;
-        pVal->Value <<= (INT16) aFntFmt.nWeight;
+        pVal->Value <<= (sal_Int16) aFntFmt.nWeight;
         pVal++;
         // Italic
         pVal->Name  = aNodeNameDelim;
         pVal->Name += *pName++;
-        pVal->Value <<= (INT16) aFntFmt.nItalic;
+        pVal->Value <<= (sal_Int16) aFntFmt.nItalic;
         pVal++;
     }
-    DBG_ASSERT( pVal - pValues == nCount * nSymbolProps, "properties missing" );
+    OSL_ENSURE( sal::static_int_cast<size_t>(pVal - pValues) == nCount * nSymbolProps, "properties missing" );
     ReplaceSetProperties( A2OU( FONT_FORMAT_LIST ) , aValues );
     
-    rFntFmtList.SetModified( FALSE );
+    rFntFmtList.SetModified( false );
 }
 
 
 void SmMathConfig::StripFontFormatList( const std::vector< SmSym > &rSymbols )
 {
-    size_t nCount = rSymbols.size();
-    USHORT i;
+    size_t i;
     
     // build list of used font-formats only
     //!! font-format IDs may be different !!
     SmFontFormatList aUsedList;
-    for (i = 0;  i < nCount;  ++i)
+    for (i = 0;  i < rSymbols.size();  ++i)
     {
-        DBG_ASSERT( rSymbols[i].GetName().Len() > 0, "non named symbol" );
-        aUsedList.GetFontFormatId( SmFontFormat( rSymbols[i].GetFace() ) , TRUE );
+        OSL_ENSURE( rSymbols[i].GetName().Len() > 0, "non named symbol" );
+        aUsedList.GetFontFormatId( SmFontFormat( rSymbols[i].GetFace() ) , true );
     }
     const SmFormat & rStdFmt = GetStandardFormat();
     for (i = FNT_BEGIN;  i <= FNT_END;  ++i)
     {
-        aUsedList.GetFontFormatId( SmFontFormat( rStdFmt.GetFont( i ) ) , TRUE );
+        aUsedList.GetFontFormatId( SmFontFormat( rStdFmt.GetFont( i ) ) , true );
     }
 
     // remove unused font-formats from list
     SmFontFormatList &rFntFmtList = GetFontFormatList();
-    USHORT nCnt = rFntFmtList.GetCount();
+    size_t nCnt = rFntFmtList.GetCount();
     SmFontFormat *pTmpFormat = new SmFontFormat[ nCnt ];
     String       *pId     = new String      [ nCnt ];
-    INT32 k;
+    size_t k;
     for (k = 0;  k < nCnt;  ++k)
     {
-        pTmpFormat[k] = *rFntFmtList.GetFontFormat( (USHORT) k );
-        pId[k]     = rFntFmtList.GetFontFormatId( (USHORT) k );
+        pTmpFormat[k] = *rFntFmtList.GetFontFormat( k );
+        pId[k]     = rFntFmtList.GetFontFormatId( k );
     }
     for (k = 0;  k < nCnt;  ++k)
     {
@@ -872,7 +870,7 @@ void SmMathConfig::LoadOther()
         pOther = new SmCfgOther;
 
     Sequence< OUString > aNames( GetOtherPropertyNames() );
-    INT32 nProps = aNames.getLength();
+    sal_Int32 nProps = aNames.getLength();
 
     Sequence< Any > aValues( GetProperties( aNames ) );
     if (nProps  &&  aValues.getLength() == nProps)
@@ -880,8 +878,8 @@ void SmMathConfig::LoadOther()
         const Any *pValues = aValues.getConstArray();
         const Any *pVal = pValues;
 
-        INT16   nTmp16 = 0;
-        BOOL    bTmp = FALSE;
+        sal_Int16   nTmp16 = 0;
+        bool    bTmp = false;
 
         // Print/Title
         if (pVal->hasValue()  &&  (*pVal >>= bTmp))
@@ -902,11 +900,10 @@ void SmMathConfig::LoadOther()
         // Print/ZoomFactor
         if (pVal->hasValue()  &&  (*pVal >>= nTmp16))
             pOther->nPrintZoomFactor = nTmp16;
-/*        ++pVal;
-        // Misc/NoSymbolsWarning
+        ++pVal;
+        // LoadSave/IsSaveOnlyUsedSymbols
         if (pVal->hasValue()  &&  (*pVal >>= bTmp))
-            pOther->bNoSymbolsWarning = bTmp;
-*/
+            pOther->bIsSaveOnlyUsedSymbols = bTmp;
         ++pVal;
         // Misc/IgnoreSpacesRight
         if (pVal->hasValue()  &&  (*pVal >>= bTmp))
@@ -925,8 +922,8 @@ void SmMathConfig::LoadOther()
             pOther->bFormulaCursor = bTmp;
         ++pVal;
 
-        DBG_ASSERT( pVal - pValues == nProps, "property mismatch" );
-        SetOtherModified( FALSE );
+        OSL_ENSURE( pVal - pValues == nProps, "property mismatch" );
+        SetOtherModified( false );
     }
 }
 
@@ -937,38 +934,37 @@ void SmMathConfig::SaveOther()
         return;
 
     const Sequence< OUString > aNames( GetOtherPropertyNames() );
-    INT32 nProps = aNames.getLength();
+    sal_Int32 nProps = aNames.getLength();
 
     Sequence< Any > aValues( nProps );
     Any *pValues = aValues.getArray();
     Any *pValue  = pValues;
 
     // Print/Title
-    *pValue++ <<= (BOOL) pOther->bPrintTitle;
+    *pValue++ <<= (sal_Bool) pOther->bPrintTitle;
     // Print/FormulaText
-    *pValue++ <<= (BOOL) pOther->bPrintFormulaText;
+    *pValue++ <<= (sal_Bool) pOther->bPrintFormulaText;
     // Print/Frame
-    *pValue++ <<= (BOOL) pOther->bPrintFrame;
+    *pValue++ <<= (sal_Bool) pOther->bPrintFrame;
     // Print/Size
-    *pValue++ <<= (INT16) pOther->ePrintSize;
+    *pValue++ <<= (sal_Int16) pOther->ePrintSize;
     // Print/ZoomFactor
-    *pValue++ <<= (INT16) pOther->nPrintZoomFactor;
-/*    // Misc/NoSymbolsWarning
-    *pValue++ <<= (BOOL) pOther->bNoSymbolsWarning;
-*/
+    *pValue++ <<= (sal_Int16) pOther->nPrintZoomFactor;
+    // LoadSave/IsSaveOnlyUsedSymbols
+    *pValue++ <<= (sal_Bool) pOther->bIsSaveOnlyUsedSymbols;
     // Misc/IgnoreSpacesRight
-    *pValue++ <<= (BOOL) pOther->bIgnoreSpacesRight;
+    *pValue++ <<= (sal_Bool) pOther->bIgnoreSpacesRight;
     // View/ToolboxVisible
-    *pValue++ <<= (BOOL) pOther->bToolboxVisible;
+    *pValue++ <<= (sal_Bool) pOther->bToolboxVisible;
     // View/AutoRedraw
-    *pValue++ <<= (BOOL) pOther->bAutoRedraw;
+    *pValue++ <<= (sal_Bool) pOther->bAutoRedraw;
     // View/FormulaCursor
-    *pValue++ <<= (BOOL) pOther->bFormulaCursor;
+    *pValue++ <<= (sal_Bool) pOther->bFormulaCursor;
     
-    DBG_ASSERT( pValue - pValues == nProps, "property mismatch" );
+    OSL_ENSURE( pValue - pValues == nProps, "property mismatch" );
     PutProperties( aNames , aValues );
 
-    SetOtherModified( FALSE );
+    SetOtherModified( false );
 }
 
 void SmMathConfig::LoadFormat()
@@ -978,7 +974,7 @@ void SmMathConfig::LoadFormat()
 
     
     Sequence< OUString > aNames( GetFormatPropertyNames() );
-    INT32 nProps = aNames.getLength();
+    sal_Int32 nProps = aNames.getLength();
 
     Sequence< Any > aValues( GetProperties( aNames ) );
     if (nProps  &&  aValues.getLength() == nProps)
@@ -987,8 +983,8 @@ void SmMathConfig::LoadFormat()
         const Any *pVal = pValues;
 
         OUString    aTmpStr;
-        INT16       nTmp16 = 0;
-        BOOL        bTmp = FALSE;
+        sal_Int16       nTmp16 = 0;
+        bool        bTmp = false;
 
         // StandardFormat/Textmode
         if (pVal->hasValue()  &&  (*pVal >>= bTmp))
@@ -1011,7 +1007,7 @@ void SmMathConfig::LoadFormat()
             pFormat->SetBaseSize( Size(0, SmPtsTo100th_mm( nTmp16 )) );
         ++pVal;
 
-        USHORT i;
+        sal_uInt16 i;
         for (i = SIZ_BEGIN;  i <= SIZ_END;  ++i)
         {
             if (pVal->hasValue()  &&  (*pVal >>= nTmp16))
@@ -1030,7 +1026,7 @@ void SmMathConfig::LoadFormat()
         for (i = FNT_BEGIN;  i < FNT_END;  ++i)
         {
             Font aFnt;
-            BOOL bUseDefaultFont = TRUE;
+            bool bUseDefaultFont = true;
             if (pVal->hasValue()  &&  (*pVal >>= aTmpStr))
             {
                 bUseDefaultFont = 0 == aTmpStr.getLength();
@@ -1042,7 +1038,7 @@ void SmMathConfig::LoadFormat()
                 else
                 {
                     const SmFontFormat *pFntFmt = GetFontFormatList().GetFontFormat( aTmpStr );
-                    DBG_ASSERT( pFntFmt, "unknown FontFormat" );
+                    OSL_ENSURE( pFntFmt, "unknown FontFormat" );
                     if (pFntFmt)
                         aFnt = pFntFmt->GetFont();
                 }
@@ -1053,8 +1049,8 @@ void SmMathConfig::LoadFormat()
             pFormat->SetFont( i, aFnt, bUseDefaultFont );
         }
 
-        DBG_ASSERT( pVal - pValues == nProps, "property mismatch" );
-        SetFormatModified( FALSE );
+        OSL_ENSURE( pVal - pValues == nProps, "property mismatch" );
+        SetFormatModified( false );
     }
 }
 
@@ -1065,30 +1061,30 @@ void SmMathConfig::SaveFormat()
         return;
 
     const Sequence< OUString > aNames( GetFormatPropertyNames() );
-    INT32 nProps = aNames.getLength();
+    sal_Int32 nProps = aNames.getLength();
 
     Sequence< Any > aValues( nProps );
     Any *pValues = aValues.getArray();
     Any *pValue  = pValues;
 
     // StandardFormat/Textmode
-    *pValue++ <<= (BOOL) pFormat->IsTextmode();
+    *pValue++ <<= (sal_Bool) pFormat->IsTextmode();
     // StandardFormat/GreekCharStyle
-    *pValue++ <<= (INT16) pFormat->GetGreekCharStyle();
+    *pValue++ <<= (sal_Int16) pFormat->GetGreekCharStyle();
     // StandardFormat/ScaleNormalBracket
-    *pValue++ <<= (BOOL) pFormat->IsScaleNormalBrackets();
+    *pValue++ <<= (sal_Bool) pFormat->IsScaleNormalBrackets();
     // StandardFormat/HorizontalAlignment
-    *pValue++ <<= (INT16) pFormat->GetHorAlign();
+    *pValue++ <<= (sal_Int16) pFormat->GetHorAlign();
     // StandardFormat/BaseSize
-    *pValue++ <<= (INT16) SmRoundFraction( Sm100th_mmToPts( 
+    *pValue++ <<= (sal_Int16) SmRoundFraction( Sm100th_mmToPts( 
                                     pFormat->GetBaseSize().Height() ) );
 
-    USHORT i;
+    sal_uInt16 i;
     for (i = SIZ_BEGIN;  i <= SIZ_END;  ++i)
-        *pValue++ <<= (INT16) pFormat->GetRelSize( i );
+        *pValue++ <<= (sal_Int16) pFormat->GetRelSize( i );
 
     for (i = DIS_BEGIN;  i <= DIS_END;  ++i)
-        *pValue++ <<= (INT16) pFormat->GetDistance( i );
+        *pValue++ <<= (sal_Int16) pFormat->GetDistance( i );
 
     for (i = FNT_BEGIN;  i < FNT_END;  ++i)
     {
@@ -1097,17 +1093,17 @@ void SmMathConfig::SaveFormat()
         if (!pFormat->IsDefaultFont( i ))
         {
             SmFontFormat aFntFmt( pFormat->GetFont( i ) );
-            aFntFmtId = GetFontFormatList().GetFontFormatId( aFntFmt, TRUE );
-            DBG_ASSERT( aFntFmtId.getLength(), "FontFormatId not found" );
+            aFntFmtId = GetFontFormatList().GetFontFormatId( aFntFmt, true );
+            OSL_ENSURE( aFntFmtId.getLength(), "FontFormatId not found" );
         }
 
         *pValue++ <<= aFntFmtId;
     }
     
-    DBG_ASSERT( pValue - pValues == nProps, "property mismatch" );
+    OSL_ENSURE( pValue - pValues == nProps, "property mismatch" );
     PutProperties( aNames , aValues );
     
-    SetFormatModified( FALSE );
+    SetFormatModified( false );
 }
 
 
@@ -1119,20 +1115,20 @@ const SmFormat & SmMathConfig::GetStandardFormat() const
 }
 
 
-void SmMathConfig::SetStandardFormat( const SmFormat &rFormat, BOOL bSaveFontFormatList )
+void SmMathConfig::SetStandardFormat( const SmFormat &rFormat, bool bSaveFontFormatList )
 {
     if (!pFormat)
         LoadFormat();
     if (rFormat != *pFormat)
     {
         *pFormat = rFormat;
-        SetFormatModified( TRUE );
+        SetFormatModified( true );
         SaveFormat();
 
         if (bSaveFontFormatList)
         {
             // needed for SmFontTypeDialog's DefaultButtonClickHdl
-            SetFontFormatListModified( TRUE );
+            SetFontFormatListModified( true );
             SaveFontFormatList();
         }
     }
@@ -1154,12 +1150,12 @@ void SmMathConfig::SetPrintSize( SmPrintSize eSize )
     if (eSize != pOther->ePrintSize)
     {
         pOther->ePrintSize = eSize;
-        SetOtherModified( TRUE );
+        SetOtherModified( true );
     }
 }
 
 
-USHORT SmMathConfig::GetPrintZoomFactor() const
+sal_uInt16 SmMathConfig::GetPrintZoomFactor() const
 {
     if (!pOther)
         ((SmMathConfig *) this)->LoadOther();
@@ -1167,29 +1163,29 @@ USHORT SmMathConfig::GetPrintZoomFactor() const
 }
 
 
-void SmMathConfig::SetPrintZoomFactor( USHORT nVal )
+void SmMathConfig::SetPrintZoomFactor( sal_uInt16 nVal )
 {
     if (!pOther)
         LoadOther();
     if (nVal != pOther->nPrintZoomFactor)
     {
         pOther->nPrintZoomFactor = nVal;
-        SetOtherModified( TRUE );
+        SetOtherModified( true );
     }
 }
     
 
-void SmMathConfig::SetOtherIfNotEqual( BOOL &rbItem, BOOL bNewVal )
+void SmMathConfig::SetOtherIfNotEqual( bool &rbItem, bool bNewVal )
 {
     if (bNewVal != rbItem)
     {
         rbItem = bNewVal;
-        SetOtherModified( TRUE );
+        SetOtherModified( true );
     }
 }
 
 
-BOOL SmMathConfig::IsPrintTitle() const
+bool SmMathConfig::IsPrintTitle() const
 {
     if (!pOther)
         ((SmMathConfig *) this)->LoadOther();
@@ -1197,7 +1193,7 @@ BOOL SmMathConfig::IsPrintTitle() const
 }
 
 
-void SmMathConfig::SetPrintTitle( BOOL bVal )
+void SmMathConfig::SetPrintTitle( bool bVal )
 {
     if (!pOther)
         LoadOther();
@@ -1205,7 +1201,7 @@ void SmMathConfig::SetPrintTitle( BOOL bVal )
 }
 
 
-BOOL SmMathConfig::IsPrintFormulaText() const
+bool SmMathConfig::IsPrintFormulaText() const
 {
     if (!pOther)
         ((SmMathConfig *) this)->LoadOther();
@@ -1213,15 +1209,21 @@ BOOL SmMathConfig::IsPrintFormulaText() const
 }
 
 
-void SmMathConfig::SetPrintFormulaText( BOOL bVal )
+void SmMathConfig::SetPrintFormulaText( bool bVal )
 {
     if (!pOther)
         LoadOther();
     SetOtherIfNotEqual( pOther->bPrintFormulaText, bVal );
 }
 
+bool SmMathConfig::IsSaveOnlyUsedSymbols() const
+{
+    if (!pOther)
+        ((SmMathConfig *) this)->LoadOther();
+    return pOther->bIsSaveOnlyUsedSymbols;
+}
 
-BOOL SmMathConfig::IsPrintFrame() const
+bool SmMathConfig::IsPrintFrame() const
 {
     if (!pOther)
         ((SmMathConfig *) this)->LoadOther();
@@ -1229,7 +1231,7 @@ BOOL SmMathConfig::IsPrintFrame() const
 }
 
 
-void SmMathConfig::SetPrintFrame( BOOL bVal )
+void SmMathConfig::SetPrintFrame( bool bVal )
 {
     if (!pOther)
         LoadOther();
@@ -1237,7 +1239,15 @@ void SmMathConfig::SetPrintFrame( BOOL bVal )
 }
 
 
-BOOL SmMathConfig::IsIgnoreSpacesRight() const
+void SmMathConfig::SetSaveOnlyUsedSymbols( bool bVal )
+{
+    if (!pOther)
+        LoadOther();
+    SetOtherIfNotEqual( pOther->bIsSaveOnlyUsedSymbols, bVal );
+}
+
+
+bool SmMathConfig::IsIgnoreSpacesRight() const
 {
     if (!pOther)
         ((SmMathConfig *) this)->LoadOther();
@@ -1245,7 +1255,7 @@ BOOL SmMathConfig::IsIgnoreSpacesRight() const
 }
 
 
-void SmMathConfig::SetIgnoreSpacesRight( BOOL bVal )
+void SmMathConfig::SetIgnoreSpacesRight( bool bVal )
 {
     if (!pOther)
         LoadOther();
@@ -1253,7 +1263,7 @@ void SmMathConfig::SetIgnoreSpacesRight( BOOL bVal )
 }
 
 
-BOOL SmMathConfig::IsAutoRedraw() const
+bool SmMathConfig::IsAutoRedraw() const
 {
     if (!pOther)
         ((SmMathConfig *) this)->LoadOther();
@@ -1261,7 +1271,7 @@ BOOL SmMathConfig::IsAutoRedraw() const
 }
 
 
-void SmMathConfig::SetAutoRedraw( BOOL bVal )
+void SmMathConfig::SetAutoRedraw( bool bVal )
 {
     if (!pOther)
         LoadOther();
@@ -1269,7 +1279,7 @@ void SmMathConfig::SetAutoRedraw( BOOL bVal )
 }
 
 
-BOOL SmMathConfig::IsShowFormulaCursor() const
+bool SmMathConfig::IsShowFormulaCursor() const
 {
     if (!pOther)
         ((SmMathConfig *) this)->LoadOther();
@@ -1277,7 +1287,7 @@ BOOL SmMathConfig::IsShowFormulaCursor() const
 }
 
 
-void SmMathConfig::SetShowFormulaCursor( BOOL bVal )
+void SmMathConfig::SetShowFormulaCursor( bool bVal )
 {
     if (!pOther)
         LoadOther();
@@ -1289,3 +1299,4 @@ void SmMathConfig::Notify( const com::sun::star::uno::Sequence< rtl::OUString >&
 
 /////////////////////////////////////////////////////////////////
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
