@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -39,7 +40,6 @@
 #include <docary.hxx>
 #include <xmloff/odffields.hxx>
 #include <editsh.hxx>
-#include <errhdl.hxx>
 #include <fmtanchr.hxx>
 #include <frmfmt.hxx>
 #include <functional>
@@ -58,7 +58,6 @@
 #include <swserv.hxx>
 #include <swundo.hxx>
 #include <tools/pstm.hxx>
-#include <undobj.hxx>
 #include <unocrsr.hxx>
 #include <viscrs.hxx>
 #include <stdio.h>
@@ -247,7 +246,7 @@ namespace
             bind(&::rtl::OUString::equals, bind(&IMark::GetName, _1), rName));
     }
 
-#if FALSE
+#if 0
     static void lcl_DebugMarks(IDocumentMarkAccess::container_t vMarks)
     {
         OSL_TRACE("%d Marks", vMarks.size());
@@ -293,8 +292,7 @@ IDocumentMarkAccess::MarkType IDocumentMarkAccess::GetType(const IMark& rBkmk)
         return NAVIGATOR_REMINDER;
     else
     {
-        OSL_ENSURE(false,
-            "IDocumentMarkAccess::GetType(..)"
+        OSL_FAIL("IDocumentMarkAccess::GetType(..)"
             " - unknown MarkType. This needs to be fixed!");
         return UNO_BOOKMARK;
     }
@@ -305,7 +303,7 @@ namespace sw { namespace mark
     MarkManager::MarkManager(SwDoc& rDoc)
         : m_pDoc(&rDoc)
     { }
-
+#if OSL_DEBUG_LEVEL > 1
     void MarkManager::dumpFieldmarks( ) const
     {
         const_iterator_t pIt = m_vFieldmarks.begin();
@@ -316,12 +314,12 @@ namespace sw { namespace mark
                 ::rtl::OUStringToOString(str, RTL_TEXTENCODING_UTF8).getStr());
         }
     }
-
+#endif
     ::sw::mark::IMark* MarkManager::makeMark(const SwPaM& rPaM,
         const ::rtl::OUString& rName,
         const IDocumentMarkAccess::MarkType eType)
     {
-#if FALSE
+#if 0
         {
             ::rtl::OString sName = ::rtl::OUStringToOString(rName, RTL_TEXTENCODING_UTF8);
             const SwPosition* const pPos1 = rPaM.GetPoint();
@@ -352,28 +350,28 @@ namespace sw { namespace mark
         switch(eType)
         {
             case IDocumentMarkAccess::TEXT_FIELDMARK:
-                pMark = shared_ptr<IMark>(new TextFieldmark(rPaM));
+                pMark = boost::shared_ptr<IMark>(new TextFieldmark(rPaM));
                 break;
             case IDocumentMarkAccess::CHECKBOX_FIELDMARK:
-                pMark = shared_ptr<IMark>(new CheckboxFieldmark(rPaM));
+                pMark = boost::shared_ptr<IMark>(new CheckboxFieldmark(rPaM));
                 break;
             case IDocumentMarkAccess::NAVIGATOR_REMINDER:
-                pMark = shared_ptr<IMark>(new NavigatorReminder(rPaM));
+                pMark = boost::shared_ptr<IMark>(new NavigatorReminder(rPaM));
                 break;
             case IDocumentMarkAccess::BOOKMARK:
-                pMark = shared_ptr<IMark>(new Bookmark(rPaM, KeyCode(), rName, ::rtl::OUString()));
+                pMark = boost::shared_ptr<IMark>(new Bookmark(rPaM, KeyCode(), rName, ::rtl::OUString()));
                 break;
             case IDocumentMarkAccess::DDE_BOOKMARK:
-                pMark = shared_ptr<IMark>(new DdeBookmark(rPaM));
+                pMark = boost::shared_ptr<IMark>(new DdeBookmark(rPaM));
                 break;
             case IDocumentMarkAccess::CROSSREF_HEADING_BOOKMARK:
-                pMark = shared_ptr<IMark>(new CrossRefHeadingBookmark(rPaM, KeyCode(), rName, ::rtl::OUString()));
+                pMark = boost::shared_ptr<IMark>(new CrossRefHeadingBookmark(rPaM, KeyCode(), rName, ::rtl::OUString()));
                 break;
             case IDocumentMarkAccess::CROSSREF_NUMITEM_BOOKMARK:
-                pMark = shared_ptr<IMark>(new CrossRefNumItemBookmark(rPaM, KeyCode(), rName, ::rtl::OUString()));
+                pMark = boost::shared_ptr<IMark>(new CrossRefNumItemBookmark(rPaM, KeyCode(), rName, ::rtl::OUString()));
                 break;
             case IDocumentMarkAccess::UNO_BOOKMARK:
-                pMark = shared_ptr<IMark>(new UnoMark(rPaM));
+                pMark = boost::shared_ptr<IMark>(new UnoMark(rPaM));
                 break;
         }
         OSL_ENSURE(pMark.get(),
@@ -395,12 +393,10 @@ namespace sw { namespace mark
             case IDocumentMarkAccess::BOOKMARK:
             case IDocumentMarkAccess::CROSSREF_NUMITEM_BOOKMARK:
             case IDocumentMarkAccess::CROSSREF_HEADING_BOOKMARK:
-            // if(dynamic_cast<IBookmark*>)
                 lcl_InsertMarkSorted(m_vBookmarks, pMark);
                 break;
             case IDocumentMarkAccess::TEXT_FIELDMARK:
             case IDocumentMarkAccess::CHECKBOX_FIELDMARK:
-            // if(dynamic_cast<IFieldmark*>
                 lcl_InsertMarkSorted(m_vFieldmarks, pMark);
                 break;
             case IDocumentMarkAccess::NAVIGATOR_REMINDER:
@@ -410,7 +406,7 @@ namespace sw { namespace mark
                 break;
         }
         pMarkBase->InitDoc(m_pDoc);
-#if FALSE
+#if 0
         OSL_TRACE("--- makeType ---");
         OSL_TRACE("Marks");
         lcl_DebugMarks(m_vMarks);
@@ -419,6 +415,7 @@ namespace sw { namespace mark
         OSL_TRACE("Fieldmarks");
         lcl_DebugMarks(m_vFieldmarks);
 #endif
+
         return pMark.get();
     }
 
@@ -520,7 +517,7 @@ namespace sw { namespace mark
         // restore sorting if needed
         if(isSortingNeeded)
             sortMarks();
-#if FALSE
+#if 0
         OSL_TRACE("correctMarksAbsolute");
         lcl_DebugMarks(m_vMarks);
 #endif
@@ -560,7 +557,7 @@ namespace sw { namespace mark
         // restore sorting if needed
         if(isSortingNeeded)
             sortMarks();
-#if FALSE
+#if 0
         OSL_TRACE("correctMarksRelative");
         lcl_DebugMarks(m_vMarks);
 #endif
@@ -610,7 +607,7 @@ namespace sw { namespace mark
             {
                 // completely in range
 
-                // --> OD 2009-08-07 #i92125#
+                // #i92125#
                 bool bKeepCrossRefBkmk( false );
                 {
                     if ( rStt == rEnd &&
@@ -628,7 +625,6 @@ namespace sw { namespace mark
                         pSaveBkmk->push_back(SaveBookmark(true, true, *pMark, rStt, pSttIdx));
                     vMarksToDelete.push_back(ppMark);
                 }
-                // <--
             }
             else if(isPosInRange ^ isOtherPosInRange)
             {
@@ -645,7 +641,7 @@ namespace sw { namespace mark
                         rEnd,
                         isPosInRange ? pMark->GetOtherMarkPos() : pMark->GetMarkPos());
 
-                // --> OD 2009-08-06 #i92125#
+                // #i92125#
                 // no move of position for cross-reference bookmarks,
                 // if move occurs inside a certain node
                 if ( ( IDocumentMarkAccess::GetType(*pMark) !=
@@ -662,23 +658,22 @@ namespace sw { namespace mark
                     // illegal selection? collapse the mark and restore sorting later
                     isSortingNeeded |= lcl_FixCorrectedMark(isPosInRange, isOtherPosInRange, pMark);
                 }
-                // <--
             }
         }
 
         // we just remembered the iterators to delete, so we do not need to search
-        // for the shared_ptr<> (the entry in m_vMarks) again
+        // for the boost::shared_ptr<> (the entry in m_vMarks) again
         // reverse iteration, since erasing an entry invalidates iterators
         // behind it (the iterators in vMarksToDelete are sorted)
         for(vector<const_iterator_t>::reverse_iterator pppMark = vMarksToDelete.rbegin();
             pppMark != vMarksToDelete.rend();
-            pppMark++)
+            ++pppMark)
         {
             deleteMark(*pppMark);
         }
         if(isSortingNeeded)
             sortMarks();
-#if FALSE
+#if 0
         OSL_TRACE("deleteMarks");
         lcl_DebugMarks(m_vMarks);
 #endif
@@ -704,7 +699,6 @@ namespace sw { namespace mark
             }
             case IDocumentMarkAccess::TEXT_FIELDMARK:
             case IDocumentMarkAccess::CHECKBOX_FIELDMARK:
-            // if(dynamic_cast<IFieldmark*>
             {
                 IDocumentMarkAccess::iterator_t ppFieldmark = lcl_FindMark(m_vFieldmarks, *ppMark);
                 OSL_ENSURE(ppFieldmark != m_vFieldmarks.end(),
@@ -747,7 +741,7 @@ namespace sw { namespace mark
         iterator_t pMarkHigh = m_vMarks.end();
         iterator_t pMarkFound = find_if(
             pMarkLow, pMarkHigh,
-            bind(equal_to<const IMark*>(), bind(&shared_ptr<IMark>::get, _1), pMark));
+            bind(equal_to<const IMark*>(), bind(&boost::shared_ptr<IMark>::get, _1), pMark));
         if(pMarkFound != pMarkHigh)
             deleteMark(pMarkFound);
     }
@@ -811,6 +805,7 @@ namespace sw { namespace mark
     IFieldmark* MarkManager::getFieldmarkBefore(const SwPosition& rPos) const
         { return dynamic_cast<IFieldmark*>(lcl_getMarkBefore(m_vFieldmarks, rPos)); }
 
+
     ::rtl::OUString MarkManager::getUniqueMarkName(const ::rtl::OUString& rName) const
     {
         OSL_ENSURE(rName.getLength(),
@@ -837,10 +832,6 @@ namespace sw { namespace mark
 }} // namespace ::sw::mark
 
 
-// old implementation
-
-//SV_IMPL_OP_PTRARR_SORT(SwBookmarks, SwBookmarkPtr)
-
 #define PCURCRSR (_pCurrCrsr)
 #define FOREACHPAM_START(pSttCrsr) \
     {\
@@ -885,19 +876,19 @@ namespace
     class _SwSaveTypeCountContent
     {
         union {
-            struct { USHORT nType, nCount; } TC;
-            ULONG nTypeCount;
+            struct { sal_uInt16 nType, nCount; } TC;
+            sal_uLong nTypeCount;
             } TYPECOUNT;
         xub_StrLen nContent;
 
     public:
         _SwSaveTypeCountContent() { TYPECOUNT.nTypeCount = 0; nContent = 0; }
-        _SwSaveTypeCountContent( USHORT nType )
+        _SwSaveTypeCountContent( sal_uInt16 nType )
             {
                 SetTypeAndCount( nType, 0 );
                 nContent = 0;
             }
-        _SwSaveTypeCountContent( const SvULongs& rArr, USHORT& rPos )
+        _SwSaveTypeCountContent( const SvULongs& rArr, sal_uInt16& rPos )
             {
                 TYPECOUNT.nTypeCount = rArr[ rPos++ ];
                 nContent = static_cast<xub_StrLen>(rArr[ rPos++ ]);
@@ -908,17 +899,17 @@ namespace
             rArr.Insert( nContent, rArr.Count() );
         }
 
-        void SetType( USHORT n )		{ TYPECOUNT.TC.nType = n; }
-        USHORT GetType() const 			{ return TYPECOUNT.TC.nType; }
+        void SetType( sal_uInt16 n )		{ TYPECOUNT.TC.nType = n; }
+        sal_uInt16 GetType() const 			{ return TYPECOUNT.TC.nType; }
         void IncType() 	 				{ ++TYPECOUNT.TC.nType; }
         void DecType() 	 				{ --TYPECOUNT.TC.nType; }
 
-        void SetCount( USHORT n ) 		{ TYPECOUNT.TC.nCount = n; }
-        USHORT GetCount() const 		{ return TYPECOUNT.TC.nCount; }
-        USHORT IncCount()  				{ return ++TYPECOUNT.TC.nCount; }
-        USHORT DecCount()  				{ return --TYPECOUNT.TC.nCount; }
+        void SetCount( sal_uInt16 n ) 		{ TYPECOUNT.TC.nCount = n; }
+        sal_uInt16 GetCount() const 		{ return TYPECOUNT.TC.nCount; }
+        sal_uInt16 IncCount()  				{ return ++TYPECOUNT.TC.nCount; }
+        sal_uInt16 DecCount()  				{ return --TYPECOUNT.TC.nCount; }
 
-        void SetTypeAndCount( USHORT nT, USHORT nC )
+        void SetTypeAndCount( sal_uInt16 nT, sal_uInt16 nC )
             { TYPECOUNT.TC.nCount = nC; TYPECOUNT.TC.nType = nT; }
 
         void SetContent( xub_StrLen n )		{ nContent = n; }
@@ -934,9 +925,9 @@ namespace
     static const int BEHIND_SAME_NODE = 3;     // Same node index but content index behind given content index
     static const int BEHIND_NODE = 4;          // Position behind the given node index
 
-    static int lcl_RelativePosition( const SwPosition& rPos, ULONG nNode, xub_StrLen nCntnt )
+    static int lcl_RelativePosition( const SwPosition& rPos, sal_uLong nNode, xub_StrLen nCntnt )
     {
-        ULONG nIndex = rPos.nNode.GetIndex();
+        sal_uLong nIndex = rPos.nNode.GetIndex();
         int nReturn = BEFORE_NODE;
         if( nIndex == nNode )
         {
@@ -959,17 +950,17 @@ namespace
         return rPos.nNode > rNdIdx || ( pIdx && rPos.nNode == rNdIdx && rPos.nContent > pIdx->GetIndex() );
     }
 
-    static void lcl_ChkPaM( SvULongs& rSaveArr, ULONG nNode, xub_StrLen nCntnt,
+    static void lcl_ChkPaM( SvULongs& rSaveArr, sal_uLong nNode, xub_StrLen nCntnt,
                     const SwPaM& rPam, _SwSaveTypeCountContent& rSave,
-                    BOOL bChkSelDirection )
+                    sal_Bool bChkSelDirection )
     {
         // SelektionsRichtung beachten
-        bool bBound1IsStart = !bChkSelDirection ? TRUE :
+        bool bBound1IsStart = !bChkSelDirection ? sal_True :
                             ( *rPam.GetPoint() < *rPam.GetMark()
                                 ? rPam.GetPoint() == &rPam.GetBound()
                                 : rPam.GetMark() == &rPam.GetBound());
 
-        const SwPosition* pPos = &rPam.GetBound( TRUE );
+        const SwPosition* pPos = &rPam.GetBound( sal_True );
         if( pPos->nNode.GetIndex() == nNode &&
             ( bBound1IsStart ? pPos->nContent.GetIndex() < nCntnt
                                 : pPos->nContent.GetIndex() <= nCntnt ))
@@ -978,7 +969,7 @@ namespace
             rSave.Add( rSaveArr );
         }
 
-        pPos = &rPam.GetBound( FALSE );
+        pPos = &rPam.GetBound( sal_False );
         if( pPos->nNode.GetIndex() == nNode &&
             ( (bBound1IsStart && bChkSelDirection)
                         ? pPos->nContent.GetIndex() <= nCntnt
@@ -1075,12 +1066,12 @@ void SaveBookmark::SetInDoc(
             if(pIdx && !m_nNode2)
                 aPam.GetMark()->nContent += m_nCntnt2;
             else
-                aPam.GetMark()->nContent.Assign(aPam.GetCntntNode(FALSE), m_nCntnt2);
+                aPam.GetMark()->nContent.Assign(aPam.GetCntntNode(sal_False), m_nCntnt2);
         }
         else
         {
             aPam.GetMark()->nNode = m_nNode2;
-            aPam.GetMark()->nContent.Assign(aPam.GetCntntNode(FALSE), m_nCntnt2);
+            aPam.GetMark()->nContent.Assign(aPam.GetCntntNode(sal_False), m_nCntnt2);
         }
     }
 
@@ -1100,7 +1091,7 @@ void SaveBookmark::SetInDoc(
     }
 
     if(!aPam.HasMark()
-        || CheckNodesRange(aPam.GetPoint()->nNode, aPam.GetMark()->nNode, TRUE))
+        || CheckNodesRange(aPam.GetPoint()->nNode, aPam.GetMark()->nNode, sal_True))
     {
         ::sw::mark::IBookmark* const pBookmark = dynamic_cast< ::sw::mark::IBookmark* >(pDoc->getIDocumentMarkAccess()->makeMark(aPam, m_aName, m_eOrigBkmType));
         if(pBookmark)
@@ -1142,13 +1133,13 @@ void _DelBookmarks(
     // Array, das alle Angaben auf die Position als Offset speichert.
     // Die neue Zuordung erfolgt nach dem Moven.
     SwRedlineTbl& rTbl = (SwRedlineTbl&)pDoc->GetRedlineTbl();
-    for(USHORT nCnt = 0; nCnt < rTbl.Count(); ++nCnt )
+    for(sal_uInt16 nCnt = 0; nCnt < rTbl.Count(); ++nCnt )
     {
         // liegt auf der Position ??
         SwRedline* pRedl = rTbl[ nCnt ];
 
-        SwPosition *pRStt = &pRedl->GetBound(TRUE),
-                   *pREnd = &pRedl->GetBound(FALSE);
+        SwPosition *pRStt = &pRedl->GetBound(sal_True),
+                   *pREnd = &pRedl->GetBound(sal_False);
         if( *pRStt > *pREnd )
         {
             SwPosition *pTmp = pRStt; pRStt = pREnd, pREnd = pTmp;
@@ -1161,11 +1152,11 @@ void _DelBookmarks(
                 pRStt->nContent = *pEndIdx;
             else
             {
-                BOOL bStt = TRUE;
+                sal_Bool bStt = sal_True;
                 SwCntntNode* pCNd = pRStt->nNode.GetNode().GetCntntNode();
                 if( !pCNd && 0 == ( pCNd = pDoc->GetNodes().GoNext( &pRStt->nNode )) )
                 {
-                    bStt = FALSE;
+                    bStt = sal_False;
                     pRStt->nNode = rStt;
                     if( 0 == ( pCNd = pDoc->GetNodes().GoPrevious( &pRStt->nNode )) )
                     {
@@ -1184,11 +1175,11 @@ void _DelBookmarks(
                 pREnd->nContent = *pSttIdx;
             else
             {
-                BOOL bStt = FALSE;
+                sal_Bool bStt = sal_False;
                 SwCntntNode* pCNd = pREnd->nNode.GetNode().GetCntntNode();
                 if( !pCNd && 0 == ( pCNd = pDoc->GetNodes().GoPrevious( &pREnd->nNode )) )
                 {
-                    bStt = TRUE;
+                    bStt = sal_True;
                     pREnd->nNode = rEnd;
                     if( 0 == ( pCNd = pDoc->GetNodes().GoNext( &pREnd->nNode )) )
                     {
@@ -1204,10 +1195,10 @@ void _DelBookmarks(
 }
 
 void _SaveCntntIdx(SwDoc* pDoc,
-    ULONG nNode,
+    sal_uLong nNode,
     xub_StrLen nCntnt,
     SvULongs& rSaveArr,
-    BYTE nSaveFly)
+    sal_uInt8 nSaveFly)
 {
     // 1. Bookmarks
     _SwSaveTypeCountContent aSave;
@@ -1286,9 +1277,9 @@ void _SaveCntntIdx(SwDoc* pDoc,
         if( pNode )
         {
 
-            SwFrm* pFrm = pNode->GetFrm();
+            SwFrm* pFrm = pNode->getLayoutFrm( pDoc->GetCurrentLayout() );
 #if OSL_DEBUG_LEVEL > 1
-            static BOOL bViaDoc = FALSE;
+            static sal_Bool bViaDoc = sal_False;
             if( bViaDoc )
                 pFrm = NULL;
 #endif
@@ -1382,14 +1373,14 @@ void _SaveCntntIdx(SwDoc* pDoc,
                 if( _pStkCrsr )
                 do {
                     lcl_ChkPaM( rSaveArr, nNode, nCntnt, *_pStkCrsr,
-                                aSave, FALSE );
+                                aSave, sal_False );
                     aSave.IncCount();
                 } while ( (_pStkCrsr != 0 ) &&
                     ((_pStkCrsr=(SwPaM *)_pStkCrsr->GetNext()) != PCURSH->GetStkCrsr()) );
 
                 FOREACHPAM_START( PCURSH->_GetCrsr() )
                     lcl_ChkPaM( rSaveArr, nNode, nCntnt, *PCURCRSR,
-                                aSave, FALSE );
+                                aSave, sal_False );
                     aSave.IncCount();
                 FOREACHPAM_END()
 
@@ -1400,10 +1391,10 @@ void _SaveCntntIdx(SwDoc* pDoc,
     {
         aSave.SetTypeAndCount( 0x400, 0 );
         const SwUnoCrsrTbl& rTbl = pDoc->GetUnoCrsrTbl();
-        for( USHORT n = 0; n < rTbl.Count(); ++n )
+        for( sal_uInt16 n = 0; n < rTbl.Count(); ++n )
         {
             FOREACHPAM_START( rTbl[ n ] )
-                lcl_ChkPaM( rSaveArr, nNode, nCntnt, *PCURCRSR, aSave, FALSE );
+                lcl_ChkPaM( rSaveArr, nNode, nCntnt, *PCURCRSR, aSave, sal_False );
                 aSave.IncCount();
             FOREACHPAM_END()
 
@@ -1412,7 +1403,7 @@ void _SaveCntntIdx(SwDoc* pDoc,
             if( pUnoTblCrsr )
             {
                 FOREACHPAM_START( &pUnoTblCrsr->GetSelRing() )
-                    lcl_ChkPaM( rSaveArr, nNode, nCntnt, *PCURCRSR, aSave, FALSE );
+                    lcl_ChkPaM( rSaveArr, nNode, nCntnt, *PCURCRSR, aSave, sal_False );
                     aSave.IncCount();
                 FOREACHPAM_END()
             }
@@ -1423,15 +1414,15 @@ void _SaveCntntIdx(SwDoc* pDoc,
 
 void _RestoreCntntIdx(SwDoc* pDoc,
     SvULongs& rSaveArr,
-    ULONG nNode,
+    sal_uLong nNode,
     xub_StrLen nOffset,
-    BOOL bAuto)
+    sal_Bool bAuto)
 {
     SwCntntNode* pCNd = pDoc->GetNodes()[ nNode ]->GetCntntNode();
     const SwRedlineTbl& rRedlTbl = pDoc->GetRedlineTbl();
     SwSpzFrmFmts* pSpz = pDoc->GetSpzFrmFmts();
     IDocumentMarkAccess* const pMarkAccess = pDoc->getIDocumentMarkAccess();
-    USHORT n = 0;
+    sal_uInt16 n = 0;
     while( n < rSaveArr.Count() )
     {
         _SwSaveTypeCountContent aSave( rSaveArr, n );
@@ -1490,17 +1481,17 @@ void _RestoreCntntIdx(SwDoc* pDoc,
                 {
                     SwFrmFmt *pFrmFmt = (*pSpz)[ aSave.GetCount() ];
                     SfxPoolItem *pAnchor = (SfxPoolItem*)&pFrmFmt->GetAnchor();
-                    pFrmFmt->SwModify::Modify( pAnchor, pAnchor );
+                    pFrmFmt->NotifyClients( pAnchor, pAnchor );
                 }
                 break;
 
             case 0x0800:
             case 0x0801:
                 {
-                    USHORT nCnt = 0;
                     SwCrsrShell* pShell = pDoc->GetEditShell();
                     if( pShell )
                     {
+                        sal_uInt16 nCnt = 0;
                         FOREACHSHELL_START( pShell )
                             SwPaM *_pStkCrsr = PCURSH->GetStkCrsr();
                             if( _pStkCrsr )
@@ -1538,9 +1529,9 @@ void _RestoreCntntIdx(SwDoc* pDoc,
         case 0x0400:
         case 0x0401:
             {
-                USHORT nCnt = 0;
+                sal_uInt16 nCnt = 0;
                 const SwUnoCrsrTbl& rTbl = pDoc->GetUnoCrsrTbl();
-                for( USHORT i = 0; i < rTbl.Count(); ++i )
+                for( sal_uInt16 i = 0; i < rTbl.Count(); ++i )
                 {
                     FOREACHPAM_START( rTbl[ i ] )
                         if( aSave.GetCount() == nCnt )
@@ -1594,7 +1585,7 @@ void _RestoreCntntIdx(SvULongs& rSaveArr,
     const IDocumentMarkAccess* const pMarkAccess = pDoc->getIDocumentMarkAccess();
     SwCntntNode* pCNd = (SwCntntNode*)rNd.GetCntntNode();
 
-    USHORT n = 0;
+    sal_uInt16 n = 0;
     while( n < rSaveArr.Count() )
     {
         _SwSaveTypeCountContent aSave( rSaveArr, n );
@@ -1657,10 +1648,10 @@ void _RestoreCntntIdx(SvULongs& rSaveArr,
             case 0x0800:
             case 0x0801:
                 {
-                    USHORT nCnt = 0;
                     SwCrsrShell* pShell = pDoc->GetEditShell();
                     if( pShell )
                     {
+                        sal_uInt16 nCnt = 0;
                         FOREACHSHELL_START( pShell )
                             SwPaM *_pStkCrsr = PCURSH->GetStkCrsr();
                             if( _pStkCrsr )
@@ -1698,9 +1689,9 @@ void _RestoreCntntIdx(SvULongs& rSaveArr,
             case 0x0400:
             case 0x0401:
                 {
-                    USHORT nCnt = 0;
+                    sal_uInt16 nCnt = 0;
                     const SwUnoCrsrTbl& rTbl = pDoc->GetUnoCrsrTbl();
-                    for( USHORT i = 0; i < rTbl.Count(); ++i )
+                    for( sal_uInt16 i = 0; i < rTbl.Count(); ++i )
                     {
                         FOREACHPAM_START( rTbl[ i ] )
                             if( aSave.GetCount() == nCnt )
@@ -1745,3 +1736,5 @@ void _RestoreCntntIdx(SvULongs& rSaveArr,
         }
     }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
