@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,7 +29,6 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
 
-
 #include <hintids.hxx>
 #include <svl/itemiter.hxx>
 #include <svx/svdobj.hxx>
@@ -43,6 +43,7 @@
 
 #include <ndgrf.hxx>
 #include <doc.hxx>
+#include <IDocumentUndoRedo.hxx>
 #include <ndindex.hxx>
 #include <docary.hxx>
 #include <fmtcntnt.hxx>
@@ -61,29 +62,24 @@
 #include <swundo.hxx>
 #include <swtable.hxx>
 #include <crstate.hxx>
-#include <undobj.hxx>
+#include <UndoCore.hxx>
+#include <UndoAttribute.hxx>
 #include <fmtcnct.hxx>
 #include <dflyobj.hxx>
-
-// --> OD 2009-07-20 #i73249#
 #include <undoflystrattr.hxx>
-// <--
-
-extern USHORT GetHtmlMode( const SwDocShell* );
+#include <switerator.hxx>
 
+extern sal_uInt16 GetHtmlMode( const SwDocShell* );
 
 using namespace ::com::sun::star;
 
-/*-----------------17.02.98 08:35-------------------
-
---------------------------------------------------*/
-USHORT SwDoc::GetFlyCount( FlyCntType eType ) const
+sal_uInt16 SwDoc::GetFlyCount( FlyCntType eType ) const
 {
     const SwSpzFrmFmts& rFmts = *GetSpzFrmFmts();
-    USHORT nSize = rFmts.Count();
-    USHORT nCount = 0;
+    sal_uInt16 nSize = rFmts.Count();
+    sal_uInt16 nCount = 0;
     const SwNodeIndex* pIdx;
-    for ( USHORT i = 0; i < nSize; i++)
+    for ( sal_uInt16 i = 0; i < nSize; i++)
     {
         const SwFrmFmt* pFlyFmt = rFmts[ i ];
         if( RES_FLYFRMFMT == pFlyFmt->Which()
@@ -118,18 +114,15 @@ USHORT SwDoc::GetFlyCount( FlyCntType eType ) const
     return nCount;
 }
 
-/*-----------------17.02.98 08:35-------------------
-
---------------------------------------------------*/
 // If you change this, also update SwXFrameEnumeration in unocoll.
-SwFrmFmt* SwDoc::GetFlyNum( USHORT nIdx, FlyCntType eType )
+SwFrmFmt* SwDoc::GetFlyNum( sal_uInt16 nIdx, FlyCntType eType )
 {
     SwSpzFrmFmts& rFmts = *GetSpzFrmFmts();
     SwFrmFmt* pRetFmt = 0;
-    USHORT nSize = rFmts.Count();
+    sal_uInt16 nSize = rFmts.Count();
     const SwNodeIndex* pIdx;
-    USHORT nCount = 0;
-    for( USHORT i = 0; !pRetFmt && i < nSize; ++i )
+    sal_uInt16 nCount = 0;
+    for( sal_uInt16 i = 0; !pRetFmt && i < nSize; ++i )
     {
         SwFrmFmt* pFlyFmt = rFmts[ i ];
         if( RES_FLYFRMFMT == pFlyFmt->Which()
@@ -161,27 +154,17 @@ SwFrmFmt* SwDoc::GetFlyNum( USHORT nIdx, FlyCntType eType )
     return pRetFmt;
 }
 
-/*  */
-
-/***********************************************************************
-#*	Class	   	:  SwDoc
-#*	Methode	   	:  SetFlyFrmAnchor
-#*	Beschreibung:  Das Ankerattribut des FlyFrms aendert sich.
-#*	Datum	   	:  MA 01. Feb. 94
-#*	Update	   	:  JP 09.03.98
-#***********************************************************************/
-
 Point lcl_FindAnchorLayPos( SwDoc& rDoc, const SwFmtAnchor& rAnch,
                             const SwFrmFmt* pFlyFmt )
 {
     Point aRet;
-    if( rDoc.GetRootFrm() )
+    if( rDoc.GetCurrentViewShell() )	//swmod 071107//swmod 071225
         switch( rAnch.GetAnchorId() )
         {
         case FLY_AS_CHAR:
             if( pFlyFmt && rAnch.GetCntntAnchor() )
             {
-                const SwFrm* pOld = ((SwFlyFrmFmt*)pFlyFmt)->GetFrm( &aRet, FALSE );
+                const SwFrm* pOld = ((SwFlyFrmFmt*)pFlyFmt)->GetFrm( &aRet, sal_False );
                 if( pOld )
                     aRet = pOld->Frm().Pos();
             }
@@ -193,7 +176,7 @@ Point lcl_FindAnchorLayPos( SwDoc& rDoc, const SwFmtAnchor& rAnch,
             {
                 const SwPosition *pPos = rAnch.GetCntntAnchor();
                 const SwCntntNode* pNd = pPos->nNode.GetNode().GetCntntNode();
-                const SwFrm* pOld = pNd ? pNd->GetFrm( &aRet, 0, FALSE ) : 0;
+                const SwFrm* pOld = pNd ? pNd->getLayoutFrm( rDoc.GetCurrentLayout(), &aRet, 0, sal_False ) : 0;
                 if( pOld )
                     aRet = pOld->Frm().Pos();
             }
@@ -204,7 +187,7 @@ Point lcl_FindAnchorLayPos( SwDoc& rDoc, const SwFmtAnchor& rAnch,
             {
                 const SwFlyFrmFmt* pFmt = (SwFlyFrmFmt*)rAnch.GetCntntAnchor()->
                                                 nNode.GetNode().GetFlyFmt();
-                const SwFrm* pOld = pFmt ? pFmt->GetFrm( &aRet, FALSE ) : 0;
+                const SwFrm* pOld = pFmt ? pFmt->GetFrm( &aRet, sal_False ) : 0;
                 if( pOld )
                     aRet = pOld->Frm().Pos();
             }
@@ -212,9 +195,9 @@ Point lcl_FindAnchorLayPos( SwDoc& rDoc, const SwFmtAnchor& rAnch,
 
         case FLY_AT_PAGE:
             {
-                USHORT nPgNum = rAnch.GetPageNum();
-                const SwPageFrm *pPage = (SwPageFrm*)rDoc.GetRootFrm()->Lower();
-                for( USHORT i = 1; (i <= nPgNum) && pPage; ++i,
+                sal_uInt16 nPgNum = rAnch.GetPageNum();
+                const SwPageFrm *pPage = (SwPageFrm*)rDoc.GetCurrentLayout()->Lower();
+                for( sal_uInt16 i = 1; (i <= nPgNum) && pPage; ++i,
                                     pPage = (const SwPageFrm*)pPage->GetNext() )
                     if( i == nPgNum )
                     {
@@ -233,7 +216,7 @@ Point lcl_FindAnchorLayPos( SwDoc& rDoc, const SwFmtAnchor& rAnch,
 #define IGNOREANCHOR 1
 #define DONTMAKEFRMS 2
 
-sal_Int8 SwDoc::SetFlyFrmAnchor( SwFrmFmt& rFmt, SfxItemSet& rSet, BOOL bNewFrms )
+sal_Int8 SwDoc::SetFlyFrmAnchor( SwFrmFmt& rFmt, SfxItemSet& rSet, sal_Bool bNewFrms )
 {
     //Ankerwechsel sind fast immer in alle 'Richtungen' erlaubt.
     //Ausnahme: Absatz- bzw. Zeichengebundene Rahmen duerfen wenn sie in
@@ -271,13 +254,13 @@ sal_Int8 SwDoc::SetFlyFrmAnchor( SwFrmFmt& rFmt, SfxItemSet& rSet, BOOL bNewFrms
         //Verbindung zwischen Attribut und Format.
         const SwPosition *pPos = rOldAnch.GetCntntAnchor();
         SwTxtNode *pTxtNode = pPos->nNode.GetNode().GetTxtNode();
-        ASSERT( pTxtNode->HasHints(), "Missing FlyInCnt-Hint." );
+        OSL_ENSURE( pTxtNode->HasHints(), "Missing FlyInCnt-Hint." );
         const xub_StrLen nIdx = pPos->nContent.GetIndex();
         SwTxtAttr * const  pHnt =
             pTxtNode->GetTxtAttrForCharAt( nIdx, RES_TXTATR_FLYCNT );
-        ASSERT( pHnt && pHnt->Which() == RES_TXTATR_FLYCNT,
+        OSL_ENSURE( pHnt && pHnt->Which() == RES_TXTATR_FLYCNT,
                     "Missing FlyInCnt-Hint." );
-        ASSERT( pHnt && pHnt->GetFlyCnt().GetFrmFmt() == &rFmt,
+        OSL_ENSURE( pHnt && pHnt->GetFlyCnt().GetFrmFmt() == &rFmt,
                     "Wrong TxtFlyCnt-Hint." );
         const_cast<SwFmtFlyCnt&>(pHnt->GetFlyCnt()).SetFlyFmt();
 
@@ -301,16 +284,16 @@ sal_Int8 SwDoc::SetFlyFrmAnchor( SwFrmFmt& rFmt, SfxItemSet& rSet, BOOL bNewFrms
         {
             const SwPosition *pPos = aNewAnch.GetCntntAnchor();
             SwTxtNode *pNd = pPos->nNode.GetNode().GetTxtNode();
-            ASSERT( pNd, "Crsr steht nicht auf TxtNode." );
+            OSL_ENSURE( pNd, "Crsr steht nicht auf TxtNode." );
 
             SwFmtFlyCnt aFmt( static_cast<SwFlyFrmFmt*>(&rFmt) );
             pNd->InsertItem( aFmt, pPos->nContent.GetIndex(), 0 );
         }
 
-        if( SFX_ITEM_SET != rSet.GetItemState( RES_VERT_ORIENT, FALSE, &pItem ))
+        if( SFX_ITEM_SET != rSet.GetItemState( RES_VERT_ORIENT, sal_False, &pItem ))
         {
             SwFmtVertOrient aOldV( rFmt.GetVertOrient() );
-            BOOL bSet = TRUE;
+            sal_Bool bSet = sal_True;
             switch( aOldV.GetVertOrient() )
             {
             case text::VertOrientation::LINE_TOP:     aOldV.SetVertOrient( text::VertOrientation::TOP );   break;
@@ -318,7 +301,7 @@ sal_Int8 SwDoc::SetFlyFrmAnchor( SwFrmFmt& rFmt, SfxItemSet& rSet, BOOL bNewFrms
             case text::VertOrientation::LINE_BOTTOM:  aOldV.SetVertOrient( text::VertOrientation::BOTTOM); break;
             case text::VertOrientation::NONE:         aOldV.SetVertOrient( text::VertOrientation::CENTER); break;
             default:
-                bSet = FALSE;
+                bSet = sal_False;
             }
             if( bSet )
                 rSet.Put( aOldV );
@@ -336,7 +319,7 @@ sal_Int8 SwDoc::SetFlyFrmAnchor( SwFrmFmt& rFmt, SfxItemSet& rSet, BOOL bNewFrms
             //Chg: Wenn sich in den Positionsattributen lediglich die
             //Ausrichtung veraendert (text::RelOrientation::FRAME vs. text::RelOrientation::PRTAREA), dann wird die
             //Position ebenfalls korrigiert.
-            if( SFX_ITEM_SET != rSet.GetItemState( RES_HORI_ORIENT, FALSE, &pItem ))
+            if( SFX_ITEM_SET != rSet.GetItemState( RES_HORI_ORIENT, sal_False, &pItem ))
                 pItem = 0;
 
             SwFmtHoriOrient aOldH( rFmt.GetHoriOrient() );
@@ -357,12 +340,12 @@ sal_Int8 SwDoc::SetFlyFrmAnchor( SwFrmFmt& rFmt, SfxItemSet& rSet, BOOL bNewFrms
                 rSet.Put( aOldH );
             }
 
-            if( SFX_ITEM_SET != rSet.GetItemState( RES_VERT_ORIENT, FALSE, &pItem ))
+            if( SFX_ITEM_SET != rSet.GetItemState( RES_VERT_ORIENT, sal_False, &pItem ))
                 pItem = 0;
             SwFmtVertOrient aOldV( rFmt.GetVertOrient() );
 
-            // OD 2004-05-14 #i28922# - correction: compare <aOldV.GetVertOrient()
-            // with <text::VertOrientation::NONE>
+            // #i28922# - correction: compare <aOldV.GetVertOrient() with
+            // <text::VertOrientation::NONE>
             if( text::VertOrientation::NONE == aOldV.GetVertOrient() && (!pItem ||
                 aOldV.GetPos() == ((SwFmtVertOrient*)pItem)->GetPos() ) )
             {
@@ -389,35 +372,27 @@ sal_Int8 SwDoc::SetFlyFrmAnchor( SwFrmFmt& rFmt, SfxItemSet& rSet, BOOL bNewFrms
     return MAKEFRMS;
 }
 
-BOOL SwDoc::SetFlyFrmAttr( SwFrmFmt& rFlyFmt, SfxItemSet& rSet )
+static bool
+lcl_SetFlyFrmAttr(SwDoc & rDoc,
+        sal_Int8 (SwDoc::*pSetFlyFrmAnchor)(SwFrmFmt &, SfxItemSet &, sal_Bool),
+        SwFrmFmt & rFlyFmt, SfxItemSet & rSet)
 {
-    if( !rSet.Count() )
-        return FALSE;
-
-    ::std::auto_ptr<SwUndoFmtAttrHelper> pSaveUndo;
-    const bool bDoesUndo = DoesUndo();
-
-    if( DoesUndo() )
-    {
-        ClearRedo();
-        pSaveUndo.reset( new SwUndoFmtAttrHelper( rFlyFmt ) );
-        // --> FME 2004-10-13 #i32968#
-        // Inserting columns in the frame causes MakeFrmFmt to put two
-        // objects of type SwUndoFrmFmt on the undo stack. We don't want them.
-        DoUndo( FALSE );
-        // <--
-    }
+    // #i32968# Inserting columns in the frame causes MakeFrmFmt to put two
+    // objects of type SwUndoFrmFmt on the undo stack. We don't want them.
+    ::sw::UndoGuard const undoGuard(rDoc.GetIDocumentUndoRedo());
 
     //Ist das Ankerattribut dabei? Falls ja ueberlassen wir die Verarbeitung
-    //desselben einer Spezialmethode. Sie Returnt TRUE wenn der Fly neu
+    //desselben einer Spezialmethode. Sie Returnt sal_True wenn der Fly neu
     //erzeugt werden muss (z.B. weil ein Wechsel des FlyTyps vorliegt).
-    sal_Int8 nMakeFrms = SFX_ITEM_SET == rSet.GetItemState( RES_ANCHOR, FALSE )?
-                         SetFlyFrmAnchor( rFlyFmt, rSet, FALSE ) : DONTMAKEFRMS;
+    sal_Int8 const nMakeFrms =
+        (SFX_ITEM_SET == rSet.GetItemState( RES_ANCHOR, sal_False ))
+             ?  (rDoc.*pSetFlyFrmAnchor)( rFlyFmt, rSet, sal_False )
+             :  DONTMAKEFRMS;
 
     const SfxPoolItem* pItem;
     SfxItemIter aIter( rSet );
-    SfxItemSet aTmpSet( GetAttrPool(), aFrmFmtSetRange );
-    USHORT nWhich = aIter.GetCurItem()->Which();
+    SfxItemSet aTmpSet( rDoc.GetAttrPool(), aFrmFmtSetRange );
+    sal_uInt16 nWhich = aIter.GetCurItem()->Which();
     do {
         switch( nWhich )
         {
@@ -426,7 +401,7 @@ BOOL SwDoc::SetFlyFrmAttr( SwFrmFmt& rFlyFmt, SfxItemSet& rSet )
         case RES_PAGEDESC:
         case RES_CNTNT:
         case RES_FOOTER:
-            ASSERT( !this, ":-) Unbekanntes Attribut fuer Fly." );
+            OSL_FAIL( ":-) Unbekanntes Attribut fuer Fly." );
             // kein break;
         case RES_CHAIN:
             rSet.ClearItem( nWhich );
@@ -437,7 +412,7 @@ BOOL SwDoc::SetFlyFrmAttr( SwFrmFmt& rFlyFmt, SfxItemSet& rSet )
 
         default:
             if( !IsInvalidItem( aIter.GetCurItem() ) && ( SFX_ITEM_SET !=
-                rFlyFmt.GetAttrSet().GetItemState( nWhich, TRUE, &pItem ) ||
+                rFlyFmt.GetAttrSet().GetItemState( nWhich, sal_True, &pItem ) ||
                 *pItem != *aIter.GetCurItem() ))
                 aTmpSet.Put( *aIter.GetCurItem() );
             break;
@@ -454,24 +429,39 @@ BOOL SwDoc::SetFlyFrmAttr( SwFrmFmt& rFlyFmt, SfxItemSet& rSet )
     if( MAKEFRMS == nMakeFrms )
         rFlyFmt.MakeFrms();
 
+    return aTmpSet.Count() || MAKEFRMS == nMakeFrms;
+}
+
+sal_Bool SwDoc::SetFlyFrmAttr( SwFrmFmt& rFlyFmt, SfxItemSet& rSet )
+{
+    if( !rSet.Count() )
+        return sal_False;
+
+    ::std::auto_ptr<SwUndoFmtAttrHelper> pSaveUndo;
+
+    if (GetIDocumentUndoRedo().DoesUndo())
+    {
+        GetIDocumentUndoRedo().ClearRedo(); // AppendUndo far below, so leave it
+        pSaveUndo.reset( new SwUndoFmtAttrHelper( rFlyFmt ) );
+    }
+
+    bool const bRet =
+        lcl_SetFlyFrmAttr(*this, &SwDoc::SetFlyFrmAnchor, rFlyFmt, rSet);
+
     if ( pSaveUndo.get() )
     {
-        // --> FME 2004-10-13 #i32968#
-        DoUndo( bDoesUndo );
-        // <--
-
         if ( pSaveUndo->GetUndo() )
         {
-            AppendUndo( pSaveUndo->ReleaseUndo() );
+            GetIDocumentUndoRedo().AppendUndo( pSaveUndo->ReleaseUndo() );
         }
     }
 
     SetModified();
 
-    return aTmpSet.Count() || MAKEFRMS == nMakeFrms;
+    return bRet;
 }
 
-// --> OD 2009-07-20 #i73249#
+// #i73249#
 void SwDoc::SetFlyFrmTitle( SwFlyFrmFmt& rFlyFrmFmt,
                             const String& sNewTitle )
 {
@@ -480,13 +470,11 @@ void SwDoc::SetFlyFrmTitle( SwFlyFrmFmt& rFlyFrmFmt,
         return;
     }
 
-    const bool bFormerIsNoDrawUndoObj( IsNoDrawUndoObj() );
-    SetNoDrawUndoObj( true );
+    ::sw::DrawUndoGuard const drawUndoGuard(GetIDocumentUndoRedo());
 
-    if ( DoesUndo() )
+    if (GetIDocumentUndoRedo().DoesUndo())
     {
-        ClearRedo();
-        AppendUndo( new SwUndoFlyStrAttr( rFlyFrmFmt,
+        GetIDocumentUndoRedo().AppendUndo( new SwUndoFlyStrAttr( rFlyFrmFmt,
                                           UNDO_FLYFRMFMT_TITLE,
                                           rFlyFrmFmt.GetObjTitle(),
                                           sNewTitle ) );
@@ -494,8 +482,6 @@ void SwDoc::SetFlyFrmTitle( SwFlyFrmFmt& rFlyFrmFmt,
 
     rFlyFrmFmt.SetObjTitle( sNewTitle, true );
 
-    SetNoDrawUndoObj( bFormerIsNoDrawUndoObj );
-
     SetModified();
 }
 
@@ -507,13 +493,11 @@ void SwDoc::SetFlyFrmDescription( SwFlyFrmFmt& rFlyFrmFmt,
         return;
     }
 
-    const bool bFormerIsNoDrawUndoObj( IsNoDrawUndoObj() );
-    SetNoDrawUndoObj( true );
+    ::sw::DrawUndoGuard const drawUndoGuard(GetIDocumentUndoRedo());
 
-    if ( DoesUndo() )
+    if (GetIDocumentUndoRedo().DoesUndo())
     {
-        ClearRedo();
-        AppendUndo( new SwUndoFlyStrAttr( rFlyFrmFmt,
+        GetIDocumentUndoRedo().AppendUndo( new SwUndoFlyStrAttr( rFlyFrmFmt,
                                           UNDO_FLYFRMFMT_DESCRIPTION,
                                           rFlyFrmFmt.GetObjDescription(),
                                           sNewDescription ) );
@@ -521,40 +505,30 @@ void SwDoc::SetFlyFrmDescription( SwFlyFrmFmt& rFlyFrmFmt,
 
     rFlyFrmFmt.SetObjDescription( sNewDescription, true );
 
-    SetNoDrawUndoObj( bFormerIsNoDrawUndoObj );
-
     SetModified();
 }
-// <--
 
-/***************************************************************************
- *	Methode		:	BOOL SwDoc::SetFrmFmtToFly( SwFlyFrm&, SwFrmFmt& )
- *	Beschreibung:
- *	Erstellt	:	OK 14.04.94 15:40
- *	Aenderung	:	JP 23.04.98
- ***************************************************************************/
-
-BOOL SwDoc::SetFrmFmtToFly( SwFrmFmt& rFmt, SwFrmFmt& rNewFmt,
-                            SfxItemSet* pSet, BOOL bKeepOrient )
+sal_Bool SwDoc::SetFrmFmtToFly( SwFrmFmt& rFmt, SwFrmFmt& rNewFmt,
+                            SfxItemSet* pSet, sal_Bool bKeepOrient )
 {
-    BOOL bChgAnchor = FALSE, bFrmSz = FALSE;
+    sal_Bool bChgAnchor = sal_False, bFrmSz = sal_False;
 
     const SwFmtFrmSize aFrmSz( rFmt.GetFrmSize() );
     const SwFmtVertOrient aVert( rFmt.GetVertOrient() );
     const SwFmtHoriOrient aHori( rFmt.GetHoriOrient() );
 
     SwUndoSetFlyFmt* pUndo = 0;
-    if( DoesUndo() )
+    bool const bUndo = GetIDocumentUndoRedo().DoesUndo();
+    if (bUndo)
     {
-        ClearRedo();
-        AppendUndo( pUndo = new SwUndoSetFlyFmt( rFmt, rNewFmt ) );
-        // --> FME 2004-10-13 #i32968#
-        // Inserting columns in the section causes MakeFrmFmt to put two
-        // objects of type SwUndoFrmFmt on the undo stack. We don't want them.
-        DoUndo( FALSE );
-        // <--
+        pUndo = new SwUndoSetFlyFmt( rFmt, rNewFmt );
+        GetIDocumentUndoRedo().AppendUndo(pUndo);
     }
 
+    // #i32968# Inserting columns in the section causes MakeFrmFmt to put
+    // 2 objects of type SwUndoFrmFmt on the undo stack. We don't want them.
+    ::sw::UndoGuard const undoGuard(GetIDocumentUndoRedo());
+
     //Erstmal die Spalten setzen, sonst gibts nix als Aerger mit dem
     //Set/Reset/Abgleich usw.
     const SfxPoolItem* pItem;
@@ -567,20 +541,20 @@ BOOL SwDoc::SetFrmFmtToFly( SwFrmFmt& rFmt, SwFrmFmt& rNewFmt,
 
         // 1. wenn nicht automatisch -> ignorieren, sonst -> wech
         // 2. wech damit, MB!
-        if( SFX_ITEM_SET == rNewFmt.GetAttrSet().GetItemState( RES_FRM_SIZE, FALSE ))
+        if( SFX_ITEM_SET == rNewFmt.GetAttrSet().GetItemState( RES_FRM_SIZE, sal_False ))
         {
             rFmt.ResetFmtAttr( RES_FRM_SIZE );
-            bFrmSz = TRUE;
+            bFrmSz = sal_True;
         }
 
         const SfxItemSet* pAsk = pSet;
         if( !pAsk ) pAsk = &rNewFmt.GetAttrSet();
-        if( SFX_ITEM_SET == pAsk->GetItemState( RES_ANCHOR, FALSE, &pItem )
+        if( SFX_ITEM_SET == pAsk->GetItemState( RES_ANCHOR, sal_False, &pItem )
             && ((SwFmtAnchor*)pItem)->GetAnchorId() !=
                 rFmt.GetAnchor().GetAnchorId() )
         {
             if( pSet )
-                bChgAnchor = MAKEFRMS == SetFlyFrmAnchor( rFmt, *pSet, FALSE );
+                bChgAnchor = MAKEFRMS == SetFlyFrmAnchor( rFmt, *pSet, sal_False );
             else
             {
                 //JP 23.04.98: muss den FlyFmt-Range haben, denn im SetFlyFrmAnchor
@@ -588,7 +562,7 @@ BOOL SwDoc::SetFrmFmtToFly( SwFrmFmt& rFmt, SwFrmFmt& rNewFmt,
                 SfxItemSet aFlySet( *rNewFmt.GetAttrSet().GetPool(),
                                     rNewFmt.GetAttrSet().GetRanges() );
                 aFlySet.Put( *pItem );
-                bChgAnchor = MAKEFRMS == SetFlyFrmAnchor( rFmt, aFlySet, FALSE);
+                bChgAnchor = MAKEFRMS == SetFlyFrmAnchor( rFmt, aFlySet, sal_False);
             }
         }
     }
@@ -596,9 +570,9 @@ BOOL SwDoc::SetFrmFmtToFly( SwFrmFmt& rFmt, SwFrmFmt& rNewFmt,
     //Hori und Vert nur dann resetten, wenn in der Vorlage eine
     //automatische Ausrichtung eingestellt ist, anderfalls den alten Wert
     //wieder hineinstopfen.
-    //JP 09.06.98: beim Update der RahmenVorlage sollte der Fly NICHT
+    // beim Update der RahmenVorlage sollte der Fly NICHT
     //				seine Orientierng verlieren (diese wird nicht geupdatet!)
-    //OS: #96584# text::HoriOrientation::NONE and text::VertOrientation::NONE are allowed now
+    // text::HoriOrientation::NONE and text::VertOrientation::NONE are allowed now
     if (!bKeepOrient)
     {
         rFmt.ResetFmtAttr(RES_VERT_ORIENT);
@@ -617,15 +591,10 @@ BOOL SwDoc::SetFrmFmtToFly( SwFrmFmt& rFmt, SwFrmFmt& rNewFmt,
         rFmt.MakeFrms();
 
     if( pUndo )
-        rFmt.Remove( pUndo );
+        pUndo->DeRegisterFromFormat( rFmt );
 
     SetModified();
 
-    // --> FME 2004-10-13 #i32968#
-    if ( pUndo )
-        DoUndo( TRUE );
-    // <--
-
     return bChgAnchor;
 }
 
@@ -638,21 +607,12 @@ void SwDoc::GetGrfNms( const SwFlyFrmFmt& rFmt, String* pGrfName,
         pGrfNd->GetFileFilterNms( pGrfName, pFltName );
 }
 
-/*************************************************************************
-|*
-|*	SwDoc::ChgAnchor()
-|*
-|*	Ersterstellung		MA 10. Jan. 95
-|*	Letzte Aenderung	JP 08.07.98
-|*
-*************************************************************************/
-
 sal_Bool SwDoc::ChgAnchor( const SdrMarkList& _rMrkList,
                            RndStdIds _eAnchorType,
                            const sal_Bool _bSameOnly,
                            const sal_Bool _bPosCorr )
 {
-    ASSERT( GetRootFrm(), "Ohne Layout geht gar nichts" );
+    OSL_ENSURE( GetCurrentLayout(), "Ohne Layout geht gar nichts" );
 
     if ( !_rMrkList.GetMarkCount() ||
          _rMrkList.GetMark( 0 )->GetMarkedSdrObj()->GetUpGroup() )
@@ -660,48 +620,46 @@ sal_Bool SwDoc::ChgAnchor( const SdrMarkList& _rMrkList,
         return false;
     }
 
-    StartUndo( UNDO_INSATTR, NULL );
+    GetIDocumentUndoRedo().StartUndo( UNDO_INSATTR, NULL );
 
-    BOOL bUnmark = FALSE;
-    for ( USHORT i = 0; i < _rMrkList.GetMarkCount(); ++i )
+    sal_Bool bUnmark = sal_False;
+    for ( sal_uInt16 i = 0; i < _rMrkList.GetMarkCount(); ++i )
     {
         SdrObject* pObj = _rMrkList.GetMark( i )->GetMarkedSdrObj();
         if ( !pObj->ISA(SwVirtFlyDrawObj) )
         {
             SwDrawContact* pContact = static_cast<SwDrawContact*>(GetUserCall(pObj));
 
-            // OD 27.06.2003 #108784# - consider, that drawing object has
+            // consider, that drawing object has
             // no user call. E.g.: a 'virtual' drawing object is disconnected by
             // the anchor type change of the 'master' drawing object.
             // Continue with next selected object and assert, if this isn't excepted.
             if ( !pContact )
             {
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
                 bool bNoUserCallExcepted =
                         pObj->ISA(SwDrawVirtObj) &&
                         !static_cast<SwDrawVirtObj*>(pObj)->IsConnected();
-                ASSERT( bNoUserCallExcepted, "SwDoc::ChgAnchor(..) - no contact at selected drawing object" );
+                OSL_ENSURE( bNoUserCallExcepted, "SwDoc::ChgAnchor(..) - no contact at selected drawing object" );
 #endif
                 continue;
             }
 
-            // OD 2004-03-29 #i26791#
+            // #i26791#
             const SwFrm* pOldAnchorFrm = pContact->GetAnchorFrm( pObj );
             const SwFrm* pNewAnchorFrm = pOldAnchorFrm;
 
-            // --> OD 2006-03-01 #i54336#
+            // #i54336#
             // Instead of only keeping the index position for an as-character
             // anchored object the complete <SwPosition> is kept, because the
             // anchor index position could be moved, if the object again is
             // anchored as character.
-//            xub_StrLen nIndx = STRING_NOTFOUND;
             const SwPosition* pOldAsCharAnchorPos( 0L );
             const RndStdIds eOldAnchorType = pContact->GetAnchorId();
             if ( !_bSameOnly && eOldAnchorType == FLY_AS_CHAR )
             {
                 pOldAsCharAnchorPos = new SwPosition( pContact->GetCntntAnchor() );
             }
-            // <--
 
             if ( _bSameOnly )
                 _eAnchorType = eOldAnchorType;
@@ -721,7 +679,7 @@ sal_Bool SwDoc::ChgAnchor( const SdrMarkList& _rMrkList,
                                             ? aObjRect.TopRight()
                                             : aPt;
 
-                    // OD 18.06.2003 #108784# - allow drawing objects in header/footer
+                    // allow drawing objects in header/footer
                     pNewAnchorFrm = ::FindAnchor( pOldAnchorFrm, aNewPoint, false );
                     if ( pNewAnchorFrm->IsTxtFrm() && ((SwTxtFrm*)pNewAnchorFrm)->IsFollow() )
                     {
@@ -750,11 +708,11 @@ sal_Bool SwDoc::ChgAnchor( const SdrMarkList& _rMrkList,
                         SwPosition aPos( GetNodes() );
                         Point aPoint( aPt );
                         aPoint.X() -= 1;
-                        GetRootFrm()->GetCrsrOfst( &aPos, aPoint, &aState );
-                        // OD 20.06.2003 #108784# - consider that drawing objects
-                        // can be in header/footer. Thus, <GetFrm()> by left-top-corner
+                        GetCurrentLayout()->GetCrsrOfst( &aPos, aPoint, &aState );
+                        // consider that drawing objects can be in
+                        // header/footer. Thus, <GetFrm()> by left-top-corner
                         pTxtFrm = aPos.nNode.GetNode().
-                                        GetCntntNode()->GetFrm( &aPt, 0, FALSE );
+                                        GetCntntNode()->getLayoutFrm( GetCurrentLayout(), &aPt, 0, sal_False );
                     }
                     const SwFrm *pTmp = ::FindAnchor( pTxtFrm, aPt );
                     pNewAnchorFrm = pTmp->FindFlyFrm();
@@ -772,7 +730,7 @@ sal_Bool SwDoc::ChgAnchor( const SdrMarkList& _rMrkList,
                 }
             case FLY_AT_PAGE:
                 {
-                    pNewAnchorFrm = GetRootFrm()->Lower();
+                    pNewAnchorFrm = GetCurrentLayout()->Lower();
                     while ( pNewAnchorFrm && !pNewAnchorFrm->Frm().IsInside( aPt ) )
                         pNewAnchorFrm = pNewAnchorFrm->GetNext();
                     if ( !pNewAnchorFrm )
@@ -793,7 +751,7 @@ sal_Bool SwDoc::ChgAnchor( const SdrMarkList& _rMrkList,
                 }
                 else 			// Ankerwechsel
                 {
-                    // OD 18.06.2003 #108784# - allow drawing objects in header/footer
+                    // allow drawing objects in header/footer
                     pNewAnchorFrm = ::FindAnchor( pOldAnchorFrm, aPt, false );
                     if( pNewAnchorFrm->IsProtected() )
                     {
@@ -811,7 +769,7 @@ sal_Bool SwDoc::ChgAnchor( const SdrMarkList& _rMrkList,
                     // es muss ein TextNode gefunden werden, denn nur dort
                     // ist ein inhaltsgebundenes DrawObjekt zu verankern
                         SwCrsrMoveState aState( MV_SETONLYTEXT );
-                        GetRootFrm()->GetCrsrOfst( &aPos, aPoint, &aState );
+                        GetCurrentLayout()->GetCrsrOfst( &aPos, aPoint, &aState );	//swmod 080218
                     }
                     else
                     {
@@ -824,32 +782,32 @@ sal_Bool SwDoc::ChgAnchor( const SdrMarkList& _rMrkList,
                     }
                     aNewAnch.SetAnchor( &aPos );
                     SetAttr( aNewAnch, *pContact->GetFmt() );
-                    // OD 2004-04-13 #i26791# - adjust vertical positioning to
-                    // 'center to baseline'
+                    // #i26791# - adjust vertical positioning to 'center to
+                    // baseline'
                     SetAttr( SwFmtVertOrient( 0, text::VertOrientation::CENTER, text::RelOrientation::FRAME ), *pContact->GetFmt() );
                     SwTxtNode *pNd = aPos.nNode.GetNode().GetTxtNode();
-                    ASSERT( pNd, "Cursor not positioned at TxtNode." );
+                    OSL_ENSURE( pNd, "Cursor not positioned at TxtNode." );
 
                     SwFmtFlyCnt aFmt( pContact->GetFmt() );
                     pNd->InsertItem( aFmt, aPos.nContent.GetIndex(), 0 );
                 }
                 break;
             default:
-                ASSERT( !this, "unexpected AnchorId." );
+                OSL_ENSURE( !this, "unexpected AnchorId." );
             }
 
             if ( (FLY_AS_CHAR != _eAnchorType) &&
                  pNewAnchorFrm &&
                  ( !_bSameOnly || pNewAnchorFrm != pOldAnchorFrm ) )
             {
-                // OD 2004-04-06 #i26791# - Direct object positioning no longer
-                // needed. Apply of attributes (method call <SetAttr(..)>) takes
-                // care of the invalidation of the object position.
+                // #i26791# - Direct object positioning no longer needed. Apply
+                // of attributes (method call <SetAttr(..)>) takes care of the
+                // invalidation of the object position.
                 SetAttr( aNewAnch, *pContact->GetFmt() );
                 if ( _bPosCorr )
                 {
-                    // --> OD 2004-08-24 #i33313# - consider not connected
-                    // 'virtual' drawing objects
+                    // #i33313# - consider not connected 'virtual' drawing
+                    // objects
                     if ( pObj->ISA(SwDrawVirtObj) &&
                          !static_cast<SwDrawVirtObj*>(pObj)->IsConnected() )
                     {
@@ -867,7 +825,7 @@ sal_Bool SwDoc::ChgAnchor( const SdrMarkList& _rMrkList,
                 }
             }
 
-            // --> OD 2006-03-01 #i54336#
+            // #i54336#
             if ( pNewAnchorFrm && pOldAsCharAnchorPos )
             {
                 //Bei InCntnt's wird es spannend: Das TxtAttribut muss vernichtet
@@ -876,8 +834,8 @@ sal_Bool SwDoc::ChgAnchor( const SdrMarkList& _rMrkList,
                 //Verbindung zwischen Attribut und Format.
                 const xub_StrLen nIndx( pOldAsCharAnchorPos->nContent.GetIndex() );
                 SwTxtNode* pTxtNode( pOldAsCharAnchorPos->nNode.GetNode().GetTxtNode() );
-                ASSERT( pTxtNode, "<SwDoc::ChgAnchor(..)> - missing previous anchor text node for as-character anchored object" );
-                ASSERT( pTxtNode->HasHints(), "Missing FlyInCnt-Hint." );
+                OSL_ENSURE( pTxtNode, "<SwDoc::ChgAnchor(..)> - missing previous anchor text node for as-character anchored object" );
+                OSL_ENSURE( pTxtNode->HasHints(), "Missing FlyInCnt-Hint." );
                 SwTxtAttr * const pHnt =
                     pTxtNode->GetTxtAttrForCharAt( nIndx, RES_TXTATR_FLYCNT );
                 const_cast<SwFmtFlyCnt&>(pHnt->GetFlyCnt()).SetFlyFmt();
@@ -887,20 +845,15 @@ sal_Bool SwDoc::ChgAnchor( const SdrMarkList& _rMrkList,
                 pTxtNode->DeleteAttributes( RES_TXTATR_FLYCNT, nIndx, nIndx );
                 delete pOldAsCharAnchorPos;
             }
-            // <--
         }
     }
 
-    EndUndo( UNDO_END, NULL );
+    GetIDocumentUndoRedo().EndUndo( UNDO_END, NULL );
     SetModified();
 
     return bUnmark;
 }
 
-
-/* -----------------23.07.98 13:56-------------------
- *
- * --------------------------------------------------*/
 int SwDoc::Chainable( const SwFrmFmt &rSource, const SwFrmFmt &rDest )
 {
     //Die Source darf noch keinen Follow haben.
@@ -937,17 +890,17 @@ int SwDoc::Chainable( const SwFrmFmt &rSource, const SwFrmFmt &rDest )
     if( !pTxtNd )
         return SW_CHAIN_NOT_FOUND;
 
-    const ULONG nFlySttNd = pCntIdx->GetIndex();
+    const sal_uLong nFlySttNd = pCntIdx->GetIndex();
     if( 2 != ( pCntIdx->GetNode().EndOfSectionIndex() - nFlySttNd ) ||
         pTxtNd->GetTxt().Len() )
         return SW_CHAIN_NOT_EMPTY;
 
-    USHORT nArrLen = GetSpzFrmFmts()->Count();
-    for( USHORT n = 0; n < nArrLen; ++n )
+    sal_uInt16 nArrLen = GetSpzFrmFmts()->Count();
+    for( sal_uInt16 n = 0; n < nArrLen; ++n )
     {
         const SwFmtAnchor& rAnchor = (*GetSpzFrmFmts())[ n ]->GetAnchor();
-        ULONG nTstSttNd;
-        // OD 11.12.2003 #i20622# - to-frame anchored objects are allowed.
+        sal_uLong nTstSttNd;
+        // #i20622# - to-frame anchored objects are allowed.
         if ( ((rAnchor.GetAnchorId() == FLY_AT_PARA) ||
               (rAnchor.GetAnchorId() == FLY_AT_CHAR)) &&
              0 != rAnchor.GetCntntAnchor() &&
@@ -968,14 +921,14 @@ int SwDoc::Chainable( const SwFrmFmt &rSource, const SwFrmFmt &rDest )
     // both in the same fly, header, footer or on the page?
     const SwFmtAnchor &rSrcAnchor = rSource.GetAnchor(),
                       &rDstAnchor = rDest.GetAnchor();
-    ULONG nEndOfExtras = GetNodes().GetEndOfExtras().GetIndex();
-    BOOL bAllowed = FALSE;
+    sal_uLong nEndOfExtras = GetNodes().GetEndOfExtras().GetIndex();
+    sal_Bool bAllowed = sal_False;
     if ( FLY_AT_PAGE == rSrcAnchor.GetAnchorId() )
     {
         if ( (FLY_AT_PAGE == rDstAnchor.GetAnchorId()) ||
             ( rDstAnchor.GetCntntAnchor() &&
               rDstAnchor.GetCntntAnchor()->nNode.GetIndex() > nEndOfExtras ))
-            bAllowed = TRUE;
+            bAllowed = sal_True;
     }
     else if( rSrcAnchor.GetCntntAnchor() && rDstAnchor.GetCntntAnchor() )
     {
@@ -994,20 +947,18 @@ int SwDoc::Chainable( const SwFrmFmt &rSource, const SwFrmFmt &rDest )
                 pSttNd == rDstIdx.GetNode().FindHeaderStartNode() ) ||
             ( !pSttNd && rDstIdx.GetIndex() > nEndOfExtras &&
                             rSrcIdx.GetIndex() > nEndOfExtras ))
-            bAllowed = TRUE;
+            bAllowed = sal_True;
     }
 
     return bAllowed ? SW_CHAIN_OK : SW_CHAIN_WRONG_AREA;
 }
-/* -----------------23.07.98 13:56-------------------
- *
- * --------------------------------------------------*/
+
 int SwDoc::Chain( SwFrmFmt &rSource, const SwFrmFmt &rDest )
 {
     int nErr = Chainable( rSource, rDest );
     if ( !nErr )
     {
-        StartUndo( UNDO_CHAINE, NULL );
+        GetIDocumentUndoRedo().StartUndo( UNDO_CHAINE, NULL );
 
         SwFlyFrmFmt& rDestFmt = (SwFlyFrmFmt&)rDest;
 
@@ -1032,8 +983,7 @@ int SwDoc::Chain( SwFrmFmt &rSource, const SwFrmFmt &rDest )
         SwFmtFrmSize aSize( rSource.GetFrmSize() );
         if ( aSize.GetHeightSizeType() != ATT_FIX_SIZE )
         {
-            SwClientIter aIter( rSource );
-            SwFlyFrm *pFly = (SwFlyFrm*)aIter.First( TYPE(SwFlyFrm) );
+            SwFlyFrm *pFly = SwIterator<SwFlyFrm,SwFmt>::FirstElement( rSource );
             if ( pFly )
                 aSize.SetHeight( pFly->Frm().Height() );
             aSize.SetHeightSizeType( ATT_FIX_SIZE );
@@ -1041,28 +991,25 @@ int SwDoc::Chain( SwFrmFmt &rSource, const SwFrmFmt &rDest )
         }
         SetAttr( aSet, rSource );
 
-        EndUndo( UNDO_CHAINE, NULL );
+        GetIDocumentUndoRedo().EndUndo( UNDO_CHAINE, NULL );
     }
     return nErr;
 }
-/* -----------------23.07.98 13:56-------------------
- *
- * --------------------------------------------------*/
+
 void SwDoc::Unchain( SwFrmFmt &rFmt )
 {
     SwFmtChain aChain( rFmt.GetChain() );
     if ( aChain.GetNext() )
     {
-        StartUndo( UNDO_UNCHAIN, NULL );
+        GetIDocumentUndoRedo().StartUndo( UNDO_UNCHAIN, NULL );
         SwFrmFmt *pFollow = aChain.GetNext();
         aChain.SetNext( 0 );
         SetAttr( aChain, rFmt );
         aChain = pFollow->GetChain();
         aChain.SetPrev( 0 );
         SetAttr( aChain, *pFollow );
-        EndUndo( UNDO_UNCHAIN, NULL );
+        GetIDocumentUndoRedo().EndUndo( UNDO_UNCHAIN, NULL );
     }
 }
 
-
-
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
