@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -45,17 +46,18 @@
 #include <dbmgr.hxx>
 #include <swddetbl.hxx>
 #include <hints.hxx>
-
+#include <switerator.hxx>
+#include <fieldhint.hxx>
 
 /*--------------------------------------------------------------------
     Beschreibung: Feldtypen zu einer ResId zaehlen
                   wenn 0 alle zaehlen
  --------------------------------------------------------------------*/
 
-USHORT SwEditShell::GetFldTypeCount(USHORT nResId, BOOL bUsed ) const
+sal_uInt16 SwEditShell::GetFldTypeCount(sal_uInt16 nResId, sal_Bool bUsed ) const
 {
     const SwFldTypes* pFldTypes = GetDoc()->GetFldTypes();
-    const USHORT nSize = pFldTypes->Count();
+    const sal_uInt16 nSize = pFldTypes->Count();
 
     if(nResId == USHRT_MAX)
     {
@@ -63,8 +65,8 @@ USHORT SwEditShell::GetFldTypeCount(USHORT nResId, BOOL bUsed ) const
             return nSize;
         else
         {
-            USHORT nUsed = 0;
-            for ( USHORT i = 0; i < nSize; i++ )
+            sal_uInt16 nUsed = 0;
+            for ( sal_uInt16 i = 0; i < nSize; i++ )
             {
                 if(IsUsed(*(*pFldTypes)[i]))
                     nUsed++;
@@ -74,8 +76,8 @@ USHORT SwEditShell::GetFldTypeCount(USHORT nResId, BOOL bUsed ) const
     }
 
     // Alle Typen mit gleicher ResId
-    USHORT nIdx  = 0;
-    for(USHORT i = 0; i < nSize; ++i)
+    sal_uInt16 nIdx  = 0;
+    for(sal_uInt16 i = 0; i < nSize; ++i)
     {   // Gleiche ResId -> Index erhoehen
         SwFieldType& rFldType = *((*pFldTypes)[i]);
         if(rFldType.Which() == nResId)
@@ -88,10 +90,10 @@ USHORT SwEditShell::GetFldTypeCount(USHORT nResId, BOOL bUsed ) const
     Beschreibung: Feldtypen zu einer ResId finden
                   wenn 0 alle finden
  --------------------------------------------------------------------*/
-SwFieldType* SwEditShell::GetFldType(USHORT nFld, USHORT nResId, BOOL bUsed ) const
+SwFieldType* SwEditShell::GetFldType(sal_uInt16 nFld, sal_uInt16 nResId, sal_Bool bUsed ) const
 {
     const SwFldTypes* pFldTypes = GetDoc()->GetFldTypes();
-    const USHORT nSize = pFldTypes->Count();
+    const sal_uInt16 nSize = pFldTypes->Count();
 
     if(nResId == USHRT_MAX && nFld < nSize)
     {
@@ -99,7 +101,7 @@ SwFieldType* SwEditShell::GetFldType(USHORT nFld, USHORT nResId, BOOL bUsed ) co
             return (*pFldTypes)[nFld];
         else
         {
-            USHORT i, nUsed = 0;
+            sal_uInt16 i, nUsed = 0;
             for ( i = 0; i < nSize; i++ )
             {
                 if(IsUsed(*(*pFldTypes)[i]))
@@ -113,8 +115,8 @@ SwFieldType* SwEditShell::GetFldType(USHORT nFld, USHORT nResId, BOOL bUsed ) co
         }
     }
 
-    USHORT nIdx = 0;
-    for(USHORT i = 0; i < nSize; ++i)
+    sal_uInt16 nIdx = 0;
+    for(sal_uInt16 i = 0; i < nSize; ++i)
     {   // Gleiche ResId -> Index erhoehen
         SwFieldType* pFldType = (*pFldTypes)[i];
         if(pFldType->Which() == nResId)
@@ -133,7 +135,7 @@ SwFieldType* SwEditShell::GetFldType(USHORT nFld, USHORT nResId, BOOL bUsed ) co
 /*--------------------------------------------------------------------
     Beschreibung: Den ersten Typen mit ResId und Namen finden
  --------------------------------------------------------------------*/
-SwFieldType* SwEditShell::GetFldType(USHORT nResId, const String& rName) const
+SwFieldType* SwEditShell::GetFldType(sal_uInt16 nResId, const String& rName) const
 {
     return GetDoc()->GetFldType( nResId, rName, false );
 }
@@ -141,7 +143,7 @@ SwFieldType* SwEditShell::GetFldType(USHORT nResId, const String& rName) const
 /*--------------------------------------------------------------------
     Beschreibung: Feldtypen loeschen
  --------------------------------------------------------------------*/
-void SwEditShell::RemoveFldType(USHORT nFld, USHORT nResId)
+void SwEditShell::RemoveFldType(sal_uInt16 nFld, sal_uInt16 nResId)
 {
     if( USHRT_MAX == nResId )
     {
@@ -150,9 +152,9 @@ void SwEditShell::RemoveFldType(USHORT nFld, USHORT nResId)
     }
 
     const SwFldTypes* pFldTypes = GetDoc()->GetFldTypes();
-    const USHORT nSize = pFldTypes->Count();
-    USHORT nIdx = 0;
-    for( USHORT i = 0; i < nSize; ++i )
+    const sal_uInt16 nSize = pFldTypes->Count();
+    sal_uInt16 nIdx = 0;
+    for( sal_uInt16 i = 0; i < nSize; ++i )
         // Gleiche ResId -> Index erhoehen
         if( (*pFldTypes)[i]->Which() == nResId &&
             nIdx++ == nFld )
@@ -165,15 +167,15 @@ void SwEditShell::RemoveFldType(USHORT nFld, USHORT nResId)
 /*--------------------------------------------------------------------
     Beschreibung: FieldType ueber Name loeschen
  --------------------------------------------------------------------*/
-void SwEditShell::RemoveFldType(USHORT nResId, const String& rStr)
+void SwEditShell::RemoveFldType(sal_uInt16 nResId, const String& rStr)
 {
     const SwFldTypes* pFldTypes = GetDoc()->GetFldTypes();
-    const USHORT nSize = pFldTypes->Count();
+    const sal_uInt16 nSize = pFldTypes->Count();
     const CharClass& rCC = GetAppCharClass();
 
     String aTmp( rCC.lower( rStr ));
 
-    for(USHORT i = 0; i < nSize; ++i)
+    for(sal_uInt16 i = 0; i < nSize; ++i)
     {
         // Gleiche ResId -> Index erhoehen
         SwFieldType* pFldType = (*pFldTypes)[i];
@@ -200,48 +202,15 @@ void SwEditShell::FieldToText( SwFieldType* pType )
     Push();
     SwPaM* pPaM = GetCrsr();
 
-    BOOL bDDEFld = RES_DDEFLD == pType->Which();
-    // Modify-Object gefunden, trage alle Felder ins Array ein
+    SwFieldHint aHint( pPaM );
     SwClientIter aIter( *pType );
-    SwClient * pLast = aIter.GoStart();
+    for ( SwClient* pClient = aIter.GoStart(); pClient; aIter++ )
+    {
+        pPaM->DeleteMark();
+        pClient->SwClientNotifyCall( *pType, aHint );
+     }
 
-    if( pLast ) 	// konnte zum Anfang gesprungen werden ??
-        do {
-            pPaM->DeleteMark();
-            const SwFmtFld* pFmtFld = bDDEFld
-                        ? PTR_CAST( SwFmtFld, pLast )
-                        : (SwFmtFld*)pLast;
-
-            if( pFmtFld )
-            {
-                if( !pFmtFld->GetTxtFld() )
-                    continue;
-
-                // kann keine DDETabelle sein
-                const SwTxtNode& rTxtNode = pFmtFld->GetTxtFld()->GetTxtNode();
-                pPaM->GetPoint()->nNode = rTxtNode;
-                pPaM->GetPoint()->nContent.Assign( (SwTxtNode*)&rTxtNode,
-                                     *pFmtFld->GetTxtFld()->GetStart() );
-
-                // Feldinhalt durch Text ersetzen
-                String const aEntry(
-                    pFmtFld->GetFld()->ExpandField(GetDoc()->IsClipBoard()) );
-                pPaM->SetMark();
-                pPaM->Move( fnMoveForward );
-                GetDoc()->DeleteRange( *pPaM );
-                GetDoc()->InsertString( *pPaM, aEntry );
-            }
-            else if( bDDEFld )
-            {
-                // DDETabelle
-                SwDepend* pDep = (SwDepend*)pLast;
-                SwDDETable* pDDETbl = (SwDDETable*)pDep->GetToTell();
-                pDDETbl->NoDDETable();
-            }
-
-        } while( 0 != ( pLast = aIter++ ));
-
-    Pop( FALSE );
+    Pop( sal_False );
     EndAllAction();
     EndUndo( UNDO_DELETE );
 }
@@ -266,7 +235,7 @@ void SwEditShell::Insert2(SwField& rFld, const bool bForceExpandHints)
 
     FOREACHPAM_START(this)						// fuer jeden PaM
         bool bSuccess(GetDoc()->InsertPoolItem(*PCURCRSR, aFld, nInsertFlags));
-        ASSERT( bSuccess, "Doc->Insert(Field) failed");
+        OSL_ENSURE( bSuccess, "Doc->Insert(Field) failed");
         (void) bSuccess;
     FOREACHPAM_END()					  // fuer jeden PaM
 
@@ -300,7 +269,7 @@ SwField* SwEditShell::GetCurFld() const
     SwTxtFld *pTxtFld = GetDocTxtFld( pCrsr->Start() );
     SwField *pCurFld = NULL;
 
-    /* #108536# Field was only recognized if no selection was
+    /* Field was only recognized if no selection was
         present. Now it is recognized if either the cursor is in the
         field or the selection spans exactly over the field. */
     if( pTxtFld &&
@@ -319,7 +288,7 @@ SwField* SwEditShell::GetCurFld() const
 
     }
 
-    /* #108536# removed handling of multi-selections */
+    /* removed handling of multi-selections */
 
     return pCurFld;
 }
@@ -330,7 +299,6 @@ SwField* SwEditShell::GetCurFld() const
 |*					SwEditShell::UpdateFlds()
 |*
 |*	  Beschreibung	Stehen die PaMs auf Feldern ?
-|*					BP 12.05.92
 |*
 *************************************************************************/
 SwTxtFld* lcl_FindInputFld( SwDoc* pDoc, SwField& rFld )
@@ -342,11 +310,11 @@ SwTxtFld* lcl_FindInputFld( SwDoc* pDoc, SwField& rFld )
         ((SwSetExpField&)rFld).GetInputFlag() ) )
     {
         const SfxPoolItem* pItem;
-        USHORT n, nMaxItems =
-            pDoc->GetAttrPool().GetItemCount( RES_TXTATR_FIELD );
+        sal_uInt32 n, nMaxItems =
+            pDoc->GetAttrPool().GetItemCount2( RES_TXTATR_FIELD );
         for( n = 0; n < nMaxItems; ++n )
             if( 0 != (pItem =
-                      pDoc->GetAttrPool().GetItem( RES_TXTATR_FIELD, n ) )
+                      pDoc->GetAttrPool().GetItem2( RES_TXTATR_FIELD, n ) )
                 && ((SwFmtFld*)pItem)->GetFld() == &rFld )
             {
                 pTFld = ((SwFmtFld*)pItem)->GetTxtFld();
@@ -367,7 +335,7 @@ void SwEditShell::UpdateFlds( SwField &rFld )
         // Cursor-Position.
         SwMsgPoolItem* pMsgHnt = 0;
         SwRefMarkFldUpdate aRefMkHt( GetOut() );
-        USHORT nFldWhich = rFld.GetTyp()->Which();
+        sal_uInt16 nFldWhich = rFld.GetTyp()->Which();
         if( RES_GETREFFLD == nFldWhich )
             pMsgHnt = &aRefMkHt;
 
@@ -375,11 +343,6 @@ void SwEditShell::UpdateFlds( SwField &rFld )
         SwTxtFld *pTxtFld;
         SwFmtFld *pFmtFld;
 
-// 		if( pCrsr->GetNext() == pCrsr && !pCrsr->HasMark() &&
-// 			( 0 != ( pTxtFld = GetDocTxtFld( pCrsr->Start() ) ) ||
-// 			  0 != ( pTxtFld = lcl_FindInputFld( GetDoc(), rFld ) ) ) &&
-// 			( pFmtFld = (SwFmtFld*)&pTxtFld->GetFld())->GetFld()
-// 				->GetTyp()->Which() == rFld.GetTyp()->Which() )
         if ( pCrsr->GetNext() == pCrsr && !pCrsr->HasMark())
         {
             pTxtFld = GetDocTxtFld(pCrsr->Start());
@@ -388,14 +351,14 @@ void SwEditShell::UpdateFlds( SwField &rFld )
                 pTxtFld = lcl_FindInputFld( GetDoc(), rFld);
 
             if (pTxtFld != 0)
-                GetDoc()->UpdateFld(pTxtFld, rFld, pMsgHnt, TRUE); // #111840#
+                GetDoc()->UpdateFld(pTxtFld, rFld, pMsgHnt, sal_True);
         }
 
-        // bOkay (statt return wg. EndAllAction) wird FALSE,
+        // bOkay (statt return wg. EndAllAction) wird sal_False,
         // 1) wenn nur ein Pam mehr als ein Feld enthaelt oder
         // 2) bei gemischten Feldtypen
-        BOOL bOkay = TRUE;
-        BOOL bTblSelBreak = FALSE;
+        sal_Bool bOkay = sal_True;
+        sal_Bool bTblSelBreak = sal_False;
 
         SwMsgPoolItem aHint( RES_TXTATR_FIELD );  // Such-Hint
         FOREACHPAM_START(this)						// fuer jeden PaM
@@ -418,11 +381,11 @@ void SwEditShell::UpdateFlds( SwField &rFld )
                 // Suche nach SwTxtFld ...
                 while(	bOkay
                      && pCurStt->nContent != pCurEnd->nContent
-                     && aPam.Find( aHint, FALSE, fnMoveForward, &aCurPam ) )
+                     && aPam.Find( aHint, sal_False, fnMoveForward, &aCurPam ) )
                 {
                     //	wenn nur ein Pam mehr als ein Feld enthaelt ...
                     if( aPam.Start()->nContent != pCurStt->nContent )
-                        bOkay = FALSE;
+                        bOkay = sal_False;
 
                     if( 0 != (pTxtFld = GetDocTxtFld( pCurStt )) )
                     {
@@ -432,10 +395,10 @@ void SwEditShell::UpdateFlds( SwField &rFld )
                         // bei gemischten Feldtypen
                         if( pCurFld->GetTyp()->Which() !=
                             rFld.GetTyp()->Which() )
-                            bOkay = FALSE;
+                            bOkay = sal_False;
 
                         bTblSelBreak = GetDoc()->UpdateFld(pTxtFld, rFld,
-                                                           pMsgHnt, FALSE); // #111840#
+                                                           pMsgHnt, sal_False);
                     }
                     // Der Suchbereich wird um den gefundenen Bereich
                     // verkuerzt.
@@ -452,7 +415,7 @@ void SwEditShell::UpdateFlds( SwField &rFld )
     EndAllAction();
 }
 
-/*-----------------13.05.92 10:54-------------------
+/*--------------------------------------------------
  Liefert den logischen fuer die Datenbank zurueck
  --------------------------------------------------*/
 
@@ -486,7 +449,7 @@ void SwEditShell::ChangeDBFields( const SvStringsDtor& rOldNames,
 /*--------------------------------------------------------------------
     Beschreibung:  Alle Expression-Felder erneuern
  --------------------------------------------------------------------*/
-void SwEditShell::UpdateExpFlds(BOOL bCloseDB)
+void SwEditShell::UpdateExpFlds(sal_Bool bCloseDB)
 {
     SET_CURR_SHELL( this );
     StartAllAction();
@@ -525,51 +488,47 @@ void SwEditShell::SetFldUpdateFlags( SwFldUpdateFlags eFlags )
     getIDocumentSettingAccess()->setFieldUpdateFlags( eFlags );
 }
 
-SwFldUpdateFlags SwEditShell::GetFldUpdateFlags(BOOL bDocSettings) const
+SwFldUpdateFlags SwEditShell::GetFldUpdateFlags(sal_Bool bDocSettings) const
 {
     return getIDocumentSettingAccess()->getFieldUpdateFlags( !bDocSettings );
 }
 
-void SwEditShell::SetFixFields( BOOL bOnlyTimeDate,
+void SwEditShell::SetFixFields( sal_Bool bOnlyTimeDate,
                                 const DateTime* pNewDateTime )
 {
     SET_CURR_SHELL( this );
-    BOOL bUnLockView = !IsViewLocked();
-    LockView( TRUE );
+    sal_Bool bUnLockView = !IsViewLocked();
+    LockView( sal_True );
     StartAllAction();
     GetDoc()->SetFixFields( bOnlyTimeDate, pNewDateTime );
     EndAllAction();
     if( bUnLockView )
-        LockView( FALSE );
+        LockView( sal_False );
 }
 
-void SwEditShell::SetLabelDoc( BOOL bFlag )
+void SwEditShell::SetLabelDoc( sal_Bool bFlag )
 {
     GetDoc()->set(IDocumentSettingAccess::LABEL_DOCUMENT, bFlag );
 }
 
-BOOL SwEditShell::IsLabelDoc() const
+sal_Bool SwEditShell::IsLabelDoc() const
 {
     return getIDocumentSettingAccess()->get(IDocumentSettingAccess::LABEL_DOCUMENT);
 }
-/* -----------------------------21.12.99 12:53--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwEditShell::ChangeAuthorityData(const SwAuthEntry* pNewData)
 {
     GetDoc()->ChangeAuthorityData(pNewData);
 }
-/* -----------------------------03.08.2001 12:04------------------------------
 
- ---------------------------------------------------------------------------*/
-BOOL SwEditShell::IsAnyDatabaseFieldInDoc()const
+sal_Bool SwEditShell::IsAnyDatabaseFieldInDoc()const
 {
     const SwFldTypes * pFldTypes = GetDoc()->GetFldTypes();
-    const USHORT nSize = pFldTypes->Count();
-    for(USHORT i = 0; i < nSize; ++i)
+    const sal_uInt16 nSize = pFldTypes->Count();
+    for(sal_uInt16 i = 0; i < nSize; ++i)
     {
         SwFieldType& rFldType = *((*pFldTypes)[i]);
-        USHORT nWhich = rFldType.Which();
+        sal_uInt16 nWhich = rFldType.Which();
         if(IsUsed(rFldType))
         {
             switch(nWhich)
@@ -579,18 +538,20 @@ BOOL SwEditShell::IsAnyDatabaseFieldInDoc()const
                 case RES_DBNUMSETFLD:
                 case RES_DBSETNUMBERFLD:
                 {
-                    SwClientIter aIter( rFldType );
-                    SwFmtFld* pFld = (SwFmtFld*)aIter.First( TYPE( SwFmtFld ));
+                    SwIterator<SwFmtFld,SwFieldType> aIter( rFldType );
+                    SwFmtFld* pFld = aIter.First();
                     while(pFld)
                     {
                         if(pFld->IsFldInDoc())
-                            return TRUE;
-                        pFld = (SwFmtFld*)aIter.Next();
+                            return sal_True;
+                        pFld = aIter.Next();
                     }
                 }
                 break;
             }
         }
     }
-    return FALSE;
+    return sal_False;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
