@@ -64,6 +64,7 @@
 #include <SwStyleNameMapper.hxx>
 #include <unofldmid.h>
 #include <numrule.hxx>
+#include <switerator.hxx>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::text;
@@ -72,15 +73,23 @@ using ::rtl::OUString;
 SV_IMPL_PTRARR( _SwSeqFldList, _SeqFldLstElem* )
 
 //-----------------------------------------------------------------------------
-sal_Int16 lcl_SubTypeToAPI(USHORT nSubType)
+sal_Int16 lcl_SubTypeToAPI(sal_uInt16 nSubType)
 {
         sal_Int16 nRet = 0;
         switch(nSubType)
         {
-            case nsSwGetSetExpType::GSE_EXPR	:  	nRet = SetVariableType::VAR /*0*/; break;
-            case nsSwGetSetExpType::GSE_SEQ	    :	nRet = SetVariableType::SEQUENCE /*1*/; break;
-            case nsSwGetSetExpType::GSE_FORMULA :	nRet = SetVariableType::FORMULA /*2*/; break;
-            case nsSwGetSetExpType::GSE_STRING  : 	nRet = SetVariableType::STRING /*3*/; break;
+            case nsSwGetSetExpType::GSE_EXPR:
+                nRet = SetVariableType::VAR;      // 0
+                break;
+            case nsSwGetSetExpType::GSE_SEQ:
+                nRet = SetVariableType::SEQUENCE; // 1
+                break;
+            case nsSwGetSetExpType::GSE_FORMULA:
+                nRet = SetVariableType::FORMULA;  // 2
+                break;
+            case nsSwGetSetExpType::GSE_STRING:
+                nRet = SetVariableType::STRING;   // 3
+                break;
         }
         return nRet;
 }
@@ -97,7 +106,7 @@ sal_Int32 lcl_APIToSubType(const uno::Any& rAny)
             case SetVariableType::FORMULA:  nSet = nsSwGetSetExpType::GSE_FORMULA; break;
             case SetVariableType::STRING:	nSet = nsSwGetSetExpType::GSE_STRING;	break;
             default:
-                DBG_ERROR("wrong value");
+                OSL_FAIL("wrong value");
                 nSet = -1;
         }
         return nSet;
@@ -105,7 +114,7 @@ sal_Int32 lcl_APIToSubType(const uno::Any& rAny)
 
 //-----------------------------------------------------------------------------
 
-void ReplacePoint( String& rTmpName, BOOL bWithCommandType )
+void ReplacePoint( String& rTmpName, sal_Bool bWithCommandType )
 {
     // replace first and last (if bWithCommandType: last two) dot Ersten und letzten Punkt ersetzen, da in Tabellennamen Punkte erlaubt sind
     // since table names may contain dots
@@ -249,7 +258,7 @@ const SwTxtNode* GetBodyTxtNode( const SwDoc& rDoc, SwPosition& rPos,
             {
                 Point aPt( pLayout->Frm().Pos() );
                 aPt.Y()++;		// aus dem Header raus
-                pCntFrm = pPgFrm->GetCntntPos( aPt, FALSE, TRUE, FALSE );
+                pCntFrm = pPgFrm->GetCntntPos( aPt, sal_False, sal_True, sal_False );
                 pTxtNode = GetFirstTxtNode( rDoc, rPos, pCntFrm, aPt );
             }
         }
@@ -277,10 +286,10 @@ SwFieldType* SwGetExpFieldType::Copy() const
     return new SwGetExpFieldType(GetDoc());
 }
 
-void SwGetExpFieldType::Modify( SfxPoolItem*, SfxPoolItem* pNew )
+void SwGetExpFieldType::Modify( const SfxPoolItem*, const SfxPoolItem* pNew )
 {
     if( pNew && RES_DOCPOS_UPDATE == pNew->Which() )
-        SwModify::Modify( 0, pNew );
+        NotifyClients( 0, pNew );
     // sonst nichts weiter expandieren
 }
 
@@ -289,9 +298,9 @@ void SwGetExpFieldType::Modify( SfxPoolItem*, SfxPoolItem* pNew )
  --------------------------------------------------------------------*/
 
 SwGetExpField::SwGetExpField(SwGetExpFieldType* pTyp, const String& rFormel,
-                            USHORT nSub, ULONG nFmt)
+                            sal_uInt16 nSub, sal_uLong nFmt)
     : SwFormulaField( pTyp, nFmt, 0.0 ),
-    bIsInBodyTxt( TRUE ),
+    bIsInBodyTxt( sal_True ),
     nSubType(nSub),
     bLateInitialization( false )
 {
@@ -306,18 +315,15 @@ String SwGetExpField::Expand() const
         return sExpand;
 }
 
-String SwGetExpField::GetCntnt(BOOL bName) const
+String SwGetExpField::GetFieldName() const
 {
-    if ( bName )
-    {
-        String aStr( SwFieldType::GetTypeStr( static_cast<USHORT>(nsSwGetSetExpType::GSE_FORMULA & nSubType
-                                                ? TYP_FORMELFLD
-                                                : TYP_GETFLD ) ));
-        aStr += ' ';
-        aStr += GetFormula();
-        return aStr;
-    }
-    return Expand();
+    String aStr( SwFieldType::GetTypeStr(
+        static_cast<sal_uInt16>(((nsSwGetSetExpType::GSE_FORMULA & nSubType) != 0)
+                                            ? TYP_FORMELFLD
+                                            : TYP_GETFLD ) ));
+    aStr += ' ';
+    aStr += GetFormula();
+    return aStr;
 }
 
 SwField* SwGetExpField::Copy() const
@@ -373,7 +379,7 @@ void SwGetExpField::ChangeExpansion( const SwFrm& rFrm, const SwTxtFld& rFld )
     if(GetSubType() & nsSwGetSetExpType::GSE_STRING)
     {
         SwHash** ppHashTbl;
-        USHORT nSize;
+        sal_uInt16 nSize;
         rDoc.FldsToExpand( ppHashTbl, nSize, aEndFld );
         LookString( ppHashTbl, nSize, GetFormula(), sExpand );
         ::DeleteHashTable( ppHashTbl, nSize );		// HashTabelle loeschen
@@ -403,17 +409,17 @@ void SwGetExpField::SetPar2(const String& rStr)
     SetFormula(rStr);
 }
 
-USHORT SwGetExpField::GetSubType() const
+sal_uInt16 SwGetExpField::GetSubType() const
 {
     return nSubType;
 }
 
-void SwGetExpField::SetSubType(USHORT nType)
+void SwGetExpField::SetSubType(sal_uInt16 nType)
 {
     nSubType = nType;
 }
 
-void SwGetExpField::SetLanguage(USHORT nLng)
+void SwGetExpField::SetLanguage(sal_uInt16 nLng)
 {
     if (nSubType & nsSwExtendedSubType::SUB_CMD)
         SwField::SetLanguage(nLng);
@@ -421,10 +427,7 @@ void SwGetExpField::SetLanguage(USHORT nLng)
         SwValueField::SetLanguage(nLng);
 }
 
-/*-----------------07.03.98 16:08-------------------
-
---------------------------------------------------*/
-bool SwGetExpField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
+bool SwGetExpField::QueryValue( uno::Any& rAny, sal_uInt16 nWhichId ) const
 {
     switch( nWhichId )
     {
@@ -448,7 +451,7 @@ bool SwGetExpField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
         break;
     case FIELD_PROP_BOOL2:
         {
-            BOOL bTmp = 0 != (nSubType & nsSwExtendedSubType::SUB_CMD);
+            sal_Bool bTmp = 0 != (nSubType & nsSwExtendedSubType::SUB_CMD);
             rAny.setValue(&bTmp, ::getBooleanCppuType());
         }
         break;
@@ -460,10 +463,8 @@ bool SwGetExpField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
     }
     return true;
 }
-/*-----------------07.03.98 16:08-------------------
 
---------------------------------------------------*/
-bool SwGetExpField::PutValue( const uno::Any& rAny, USHORT nWhichId )
+bool SwGetExpField::PutValue( const uno::Any& rAny, sal_uInt16 nWhichId )
 {
     sal_Int32 nTmp = 0;
     String sTmp;
@@ -478,7 +479,7 @@ bool SwGetExpField::PutValue( const uno::Any& rAny, USHORT nWhichId )
         break;
     case FIELD_PROP_USHORT1:
          rAny >>= nTmp;
-         nSubType = static_cast<USHORT>(nTmp);
+         nSubType = static_cast<sal_uInt16>(nTmp);
         break;
     case FIELD_PROP_PAR1:
          SetFormula( ::GetString( rAny, sTmp ));
@@ -486,7 +487,7 @@ bool SwGetExpField::PutValue( const uno::Any& rAny, USHORT nWhichId )
     case FIELD_PROP_SUBTYPE:
         nTmp = lcl_APIToSubType(rAny);
         if( nTmp >=0 )
-            SetSubType( static_cast<USHORT>((GetSubType() & 0xff00) | nTmp));
+            SetSubType( static_cast<sal_uInt16>((GetSubType() & 0xff00) | nTmp));
         break;
     case FIELD_PROP_BOOL2:
         if(*(sal_Bool*) rAny.getValue())
@@ -503,20 +504,16 @@ bool SwGetExpField::PutValue( const uno::Any& rAny, USHORT nWhichId )
     return true;
 }
 
-/*-----------------JP: 17.06.93 -------------------
- Set-Expression-Type
- --------------------------------------------------*/
-
-SwSetExpFieldType::SwSetExpFieldType( SwDoc* pDc, const String& rName, USHORT nTyp )
+SwSetExpFieldType::SwSetExpFieldType( SwDoc* pDc, const String& rName, sal_uInt16 nTyp )
     : SwValueFieldType( pDc, RES_SETEXPFLD ),
     sName( rName ),
     pOutlChgNd( 0 ),
     sDelim( String::CreateFromAscii( "." ) ),
     nType(nTyp), nLevel( UCHAR_MAX ),
-    bDeleted( FALSE )
+    bDeleted( sal_False )
 {
     if( ( nsSwGetSetExpType::GSE_SEQ | nsSwGetSetExpType::GSE_STRING ) & nType )
-        EnableFormat(FALSE);	// Numberformatter nicht einsetzen
+        EnableFormat(sal_False);	// Numberformatter nicht einsetzen
 }
 
 SwFieldType* SwSetExpFieldType::Copy() const
@@ -534,20 +531,19 @@ const String& SwSetExpFieldType::GetName() const
     return sName;
 }
 
-void SwSetExpFieldType::Modify( SfxPoolItem*, SfxPoolItem* )
+void SwSetExpFieldType::Modify( const SfxPoolItem*, const SfxPoolItem* )
 {
     return;		// nicht weiter expandieren
 }
 
-void SwSetExpFieldType::SetSeqFormat(ULONG nFmt)
+void SwSetExpFieldType::SetSeqFormat(sal_uLong nFmt)
 {
-    SwClientIter aIter(*this);
-    for( SwFmtFld* pFld = (SwFmtFld*)aIter.First( TYPE(SwFmtFld) );
-            pFld; pFld = (SwFmtFld*)aIter.Next() )
+    SwIterator<SwFmtFld,SwFieldType> aIter(*this);
+    for( SwFmtFld* pFld = aIter.First(); pFld; pFld = aIter.Next() )
         pFld->GetFld()->ChangeFormat( nFmt );
 }
 
-ULONG SwSetExpFieldType::GetSeqFormat()
+sal_uLong SwSetExpFieldType::GetSeqFormat()
 {
     if( !GetDepends() )
         return SVX_NUM_ARABIC;
@@ -556,22 +552,21 @@ ULONG SwSetExpFieldType::GetSeqFormat()
     return pFld->GetFormat();
 }
 
-USHORT SwSetExpFieldType::SetSeqRefNo( SwSetExpField& rFld )
+sal_uInt16 SwSetExpFieldType::SetSeqRefNo( SwSetExpField& rFld )
 {
     if( !GetDepends() || !(nsSwGetSetExpType::GSE_SEQ & nType) )
         return USHRT_MAX;
 
-extern void InsertSort( SvUShorts& rArr, USHORT nIdx, USHORT* pInsPos = 0 );
+extern void InsertSort( SvUShorts& rArr, sal_uInt16 nIdx, sal_uInt16* pInsPos = 0 );
     SvUShorts aArr( 64 );
 
-    USHORT n;
+    sal_uInt16 n;
 
     // dann testmal, ob die Nummer schon vergeben ist oder ob eine neue
     // bestimmt werden muss.
-    SwClientIter aIter( *this );
+    SwIterator<SwFmtFld,SwFieldType> aIter( *this );
     const SwTxtNode* pNd;
-    for( SwFmtFld* pF = (SwFmtFld*)aIter.First( TYPE( SwFmtFld )); pF;
-            pF = (SwFmtFld*)aIter.Next() )
+    for( SwFmtFld* pF = aIter.First(); pF; pF = aIter.Next() )
         if( pF->GetFld() != &rFld && pF->GetTxtFld() &&
             0 != ( pNd = pF->GetTxtFld()->GetpTxtNode() ) &&
             pNd->GetNodes().IsDocNodes() )
@@ -579,7 +574,7 @@ extern void InsertSort( SvUShorts& rArr, USHORT nIdx, USHORT* pInsPos = 0 );
 
 
     // teste erstmal ob die Nummer schon vorhanden ist:
-    USHORT nNum = rFld.GetSeqNumber();
+    sal_uInt16 nNum = rFld.GetSeqNumber();
     if( USHRT_MAX != nNum )
     {
         for( n = 0; n < aArr.Count(); ++n )
@@ -601,15 +596,14 @@ extern void InsertSort( SvUShorts& rArr, USHORT nIdx, USHORT* pInsPos = 0 );
     return n;
 }
 
-USHORT SwSetExpFieldType::GetSeqFldList( SwSeqFldList& rList )
+sal_uInt16 SwSetExpFieldType::GetSeqFldList( SwSeqFldList& rList )
 {
     if( rList.Count() )
         rList.Remove( 0, rList.Count() );
 
-    SwClientIter aIter( *this );
+    SwIterator<SwFmtFld,SwFieldType> aIter( *this );
     const SwTxtNode* pNd;
-    for( SwFmtFld* pF = (SwFmtFld*)aIter.First( TYPE( SwFmtFld )); pF;
-            pF = (SwFmtFld*)aIter.Next() )
+    for( SwFmtFld* pF = aIter.First(); pF; pF = aIter.Next() )
         if( pF->GetTxtFld() &&
             0 != ( pNd = pF->GetTxtFld()->GetpTxtNode() ) &&
             pNd->GetNodes().IsDocNodes() )
@@ -639,24 +633,20 @@ void SwSetExpFieldType::SetChapter( SwSetExpField& rFld, const SwNode& rNd )
                 const SwNodeNum & aNum = *(pTxtNd->GetNum());
 
                 // nur die Nummer besorgen, ohne Pre-/Post-fixstrings
-                String sNumber( pRule->MakeNumString(aNum, FALSE ));
+                String sNumber( pRule->MakeNumString(aNum, sal_False ));
 
                 if( sNumber.Len() )
                     rFld.ChgExpStr(  ( sNumber += sDelim ) += rFld.GetExpStr() );
             }
             else
             {
-                OSL_ENSURE( false,
-                        "<SwSetExpFieldType::SetChapter(..)> - text node with numbering rule, but without number. This is a serious defect -> inform OD" );
+                OSL_FAIL( "<SwSetExpFieldType::SetChapter(..)> - text node with numbering rule, but without number. This is a serious defect -> inform OD" );
             }
         }
     }
 }
 
-/* -----------------24.03.99 09:44-------------------
- *
- * --------------------------------------------------*/
-bool SwSetExpFieldType::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
+bool SwSetExpFieldType::QueryValue( uno::Any& rAny, sal_uInt16 nWhichId ) const
 {
     switch( nWhichId )
     {
@@ -676,12 +666,12 @@ bool SwSetExpFieldType::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
         }
         break;
     default:
-        DBG_ERROR("illegal property");
+        OSL_FAIL("illegal property");
     }
     return true;
 }
 
-bool SwSetExpFieldType::PutValue( const uno::Any& rAny, USHORT nWhichId )
+bool SwSetExpFieldType::PutValue( const uno::Any& rAny, sal_uInt16 nWhichId )
 {
     switch( nWhichId )
     {
@@ -689,7 +679,7 @@ bool SwSetExpFieldType::PutValue( const uno::Any& rAny, USHORT nWhichId )
         {
             sal_Int32 nSet = lcl_APIToSubType(rAny);
             if(nSet >=0)
-                SetType(static_cast<USHORT>(nSet));
+                SetType(static_cast<sal_uInt16>(nSet));
         }
         break;
     case FIELD_PROP_PAR2:
@@ -713,12 +703,12 @@ bool SwSetExpFieldType::PutValue( const uno::Any& rAny, USHORT nWhichId )
         }
         break;
     default:
-        DBG_ERROR("illegal property");
+        OSL_FAIL("illegal property");
     }
     return true;
 }
 
-BOOL SwSeqFldList::InsertSort( _SeqFldLstElem* pNew )
+sal_Bool SwSeqFldList::InsertSort( _SeqFldLstElem* pNew )
 {
     sal_Unicode* p = pNew->sDlgEntry.GetBufferAccess();
     while( *p )
@@ -728,16 +718,16 @@ BOOL SwSeqFldList::InsertSort( _SeqFldLstElem* pNew )
         ++p;
     }
 
-    USHORT nPos;
-    BOOL bRet = SeekEntry( *pNew, &nPos );
+    sal_uInt16 nPos;
+    sal_Bool bRet = SeekEntry( *pNew, &nPos );
     if( !bRet )
         C40_INSERT( _SeqFldLstElem, pNew, nPos );
     return bRet;
 }
 
-BOOL SwSeqFldList::SeekEntry( const _SeqFldLstElem& rNew, USHORT* pP )
+sal_Bool SwSeqFldList::SeekEntry( const _SeqFldLstElem& rNew, sal_uInt16* pP )
 {
-    USHORT nO = Count(), nM, nU = 0;
+    sal_uInt16 nO = Count(), nM, nU = 0;
     if( nO > 0 )
     {
         CollatorWrapper & rCaseColl = ::GetAppCaseCollator(),
@@ -749,7 +739,7 @@ BOOL SwSeqFldList::SeekEntry( const _SeqFldLstElem& rNew, USHORT* pP )
         const String& rTmp2 = rNew.sDlgEntry;
         xub_StrLen nFndPos2 = 0;
         String sNum2( rTmp2.GetToken( 0, ' ', nFndPos2 ));
-        BOOL bIsNum2IsNumeric = rCC.isAsciiNumeric( sNum2 );
+        sal_Bool bIsNum2IsNumeric = rCC.isAsciiNumeric( sNum2 );
         sal_Int32 nNum2 = bIsNum2IsNumeric ? sNum2.ToInt32() : 0;
 
         nO--;
@@ -778,7 +768,7 @@ BOOL SwSeqFldList::SeekEntry( const _SeqFldLstElem& rNew, USHORT* pP )
             if( 0 == nCmp )
             {
                 if( pP ) *pP = nM;
-                return TRUE;
+                return sal_True;
             }
             else if( 0 < nCmp )
                 nU = nM + 1;
@@ -789,7 +779,7 @@ BOOL SwSeqFldList::SeekEntry( const _SeqFldLstElem& rNew, USHORT* pP )
         }
     }
     if( pP ) *pP = nU;
-    return FALSE;
+    return sal_False;
 }
 
 /*--------------------------------------------------------------------
@@ -797,13 +787,13 @@ BOOL SwSeqFldList::SeekEntry( const _SeqFldLstElem& rNew, USHORT* pP )
  --------------------------------------------------------------------*/
 
 SwSetExpField::SwSetExpField(SwSetExpFieldType* pTyp, const String& rFormel,
-                                        ULONG nFmt)
+                                        sal_uLong nFmt)
     : SwFormulaField( pTyp, nFmt, 0.0 ), nSeqNo( USHRT_MAX ),
     nSubType(0)
 {
     SetFormula(rFormel);
     // SubType ignorieren !!!
-    bInput = FALSE;
+    bInput = sal_False;
     if( IsSequenceFld() )
     {
         SwValueField::SetValue(1.0);
@@ -835,35 +825,28 @@ String SwSetExpField::Expand() const
 }
 
 /*--------------------------------------------------------------------
-    Beschreibung: liefert den Namen oder den Inhalt
+    @return the field name
  --------------------------------------------------------------------*/
 
-String SwSetExpField::GetCntnt(BOOL bName) const
+String SwSetExpField::GetFieldName() const
 {
-    if( bName )
+    SwFldTypesEnum const nStrType( (IsSequenceFld())
+                            ? TYP_SEQFLD
+                            : (bInput)
+                                ? TYP_SETINPFLD
+                                : TYP_SETFLD   );
+
+    String aStr( SwFieldType::GetTypeStr( static_cast<sal_uInt16>(nStrType) ) );
+    aStr += ' ';
+    aStr += GetTyp()->GetName();
+
+    // Sequence: without formula
+    if (TYP_SEQFLD != nStrType)
     {
-        USHORT nStrType;
-
-        if( IsSequenceFld() )
-            nStrType = TYP_SEQFLD;
-        else if( bInput )
-            nStrType = TYP_SETINPFLD;
-        else
-            nStrType = TYP_SETFLD;
-
-        String aStr( SwFieldType::GetTypeStr( nStrType ) );
-        aStr += ' ';
-        aStr += GetTyp()->GetName();
-
-        if( TYP_SEQFLD != nStrType )
-        {
-            // Sequence nicht die Formel ausgeben
-            aStr.AppendAscii( RTL_CONSTASCII_STRINGPARAM( " = " ));
-            aStr += GetFormula();
-        }
-        return aStr;
+        aStr.AppendAscii( RTL_CONSTASCII_STRINGPARAM( " = " ) );
+        aStr += GetFormula();
     }
-    return Expand();
+    return aStr;
 }
 
 SwField* SwSetExpField::Copy() const
@@ -882,7 +865,7 @@ SwField* SwSetExpField::Copy() const
     return pTmp;
 }
 
-void SwSetExpField::SetSubType(USHORT nSub)
+void SwSetExpField::SetSubType(sal_uInt16 nSub)
 {
     ((SwSetExpFieldType*)GetTyp())->SetType(nSub & 0xff);
     nSubType = nSub & 0xff00;
@@ -890,7 +873,7 @@ void SwSetExpField::SetSubType(USHORT nSub)
     DBG_ASSERT( (nSub & 0xff) != 3, "SubType ist illegal!" );
 }
 
-USHORT SwSetExpField::GetSubType() const
+sal_uInt16 SwSetExpField::GetSubType() const
 {
     return ((SwSetExpFieldType*)GetTyp())->GetType() | nSubType;
 }
@@ -900,7 +883,7 @@ void SwSetExpField::SetValue( const double& rAny )
     SwValueField::SetValue(rAny);
 
     if( IsSequenceFld() )
-        sExpand = FormatNumber( (USHORT)GetValue(), GetFormat() );
+        sExpand = FormatNumber( (sal_uInt16)GetValue(), GetFormat() );
     else
         sExpand = ((SwValueFieldType*)GetTyp())->ExpandValue( rAny,
                                                 GetFormat(), GetLanguage());
@@ -912,7 +895,7 @@ void SwGetExpField::SetValue( const double& rAny )
     sExpand = ((SwValueFieldType*)GetTyp())->ExpandValue( rAny, GetFormat(),
                                                             GetLanguage());
 }
-/* -----------------14.07.99 12:21-------------------
+/* --------------------------------------------------
     Description: Find the index of the reference text
     following the current field
  --------------------------------------------------*/
@@ -928,9 +911,9 @@ xub_StrLen SwGetExpField::GetReferenceTextPos( const SwFmtFld& rFmt, SwDoc& rDoc
     if(sNodeText.Len())
     {
         //now check if sNodeText starts with a non-alphanumeric character plus a blank
-        USHORT nSrcpt = pBreakIt->GetRealScriptOfText( sNodeText, 0 );
+        sal_uInt16 nSrcpt = pBreakIt->GetRealScriptOfText( sNodeText, 0 );
 
-        static USHORT nIds[] =
+        static sal_uInt16 nIds[] =
         {
             RES_CHRATR_LANGUAGE, RES_CHRATR_LANGUAGE,
             RES_CHRATR_FONT, RES_CHRATR_FONT,
@@ -950,7 +933,7 @@ xub_StrLen SwGetExpField::GetReferenceTextPos( const SwFmtFld& rFmt, SwDoc& rDoc
                 GetWhichOfScript( RES_CHRATR_LANGUAGE, nSrcpt )) ).GetLanguage();
             CharClass aCC( SvxCreateLocale( eLang ));
             sal_Unicode c0 = sNodeText.GetChar(0);
-            BOOL bIsAlphaNum = aCC.isAlphaNumeric( sNodeText, 0 );
+            sal_Bool bIsAlphaNum = aCC.isAlphaNumeric( sNodeText, 0 );
             if( !bIsAlphaNum ||
                 (c0 == ' ' || c0 == '\t'))
             {
@@ -977,7 +960,7 @@ const String& SwSetExpField::GetPar1() const
 
 String SwSetExpField::GetPar2() const
 {
-    USHORT nType = ((SwSetExpFieldType*)GetTyp())->GetType();
+    sal_uInt16 nType = ((SwSetExpFieldType*)GetTyp())->GetType();
 
     if (nType & nsSwGetSetExpType::GSE_STRING)
         return GetFormula();
@@ -986,7 +969,7 @@ String SwSetExpField::GetPar2() const
 
 void SwSetExpField::SetPar2(const String& rStr)
 {
-    USHORT nType = ((SwSetExpFieldType*)GetTyp())->GetType();
+    sal_uInt16 nType = ((SwSetExpFieldType*)GetTyp())->GetType();
 
     if( !(nType & nsSwGetSetExpType::GSE_SEQ) || rStr.Len() )
     {
@@ -1017,25 +1000,21 @@ SwFieldType* SwInputFieldType::Copy() const
  --------------------------------------------------------------------*/
 
 SwInputField::SwInputField(SwInputFieldType* pTyp, const String& rContent,
-                           const String& rPrompt, USHORT nSub, ULONG nFmt) :
+                           const String& rPrompt, sal_uInt16 nSub, sal_uLong nFmt) :
     SwField(pTyp, nFmt), aContent(rContent), aPText(rPrompt), nSubType(nSub)
 {
 }
 
-String SwInputField::GetCntnt(BOOL bName) const
+String SwInputField::GetFieldName() const
 {
-    if ( bName )
+    String aStr(SwField::GetFieldName());
+    if ((nSubType & 0x00ff) == INP_USR)
     {
-        String aStr(SwField::GetCntnt(bName));
-        if ((nSubType & 0x00ff) == INP_USR)
-        {
-            aStr += GetTyp()->GetName();
-            aStr += ' ';
-            aStr += aContent;
-        }
-        return aStr;
+        aStr += GetTyp()->GetName();
+        aStr += ' ';
+        aStr += aContent;
     }
-    return Expand();
+    return aStr;
 }
 
 SwField* SwInputField::Copy() const
@@ -1067,10 +1046,7 @@ String SwInputField::Expand() const
     return sRet;
 }
 
-/*-----------------06.03.98 11:12-------------------
-
---------------------------------------------------*/
-bool SwInputField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
+bool SwInputField::QueryValue( uno::Any& rAny, sal_uInt16 nWhichId ) const
 {
     switch( nWhichId )
     {
@@ -1087,14 +1063,12 @@ bool SwInputField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
         rAny <<= OUString( aToolTip );
         break;
     default:
-        DBG_ERROR("illegal property");
+        OSL_FAIL("illegal property");
     }
     return true;
 }
-/*-----------------06.03.98 11:12-------------------
 
---------------------------------------------------*/
-bool SwInputField::PutValue( const uno::Any& rAny, USHORT nWhichId )
+bool SwInputField::PutValue( const uno::Any& rAny, sal_uInt16 nWhichId )
 {
     switch( nWhichId )
     {
@@ -1111,7 +1085,7 @@ bool SwInputField::PutValue( const uno::Any& rAny, USHORT nWhichId )
         ::GetString( rAny, aToolTip );
         break;
     default:
-        DBG_ERROR("illegal property");
+        OSL_FAIL("illegal property");
     }
     return true;
 }
@@ -1163,24 +1137,22 @@ String SwInputField::GetToolTip() const
     return aToolTip;
 }
 
-BOOL SwInputField::isFormField() const
+sal_Bool SwInputField::isFormField() const
 {
     return aHelp.Len() > 0 || aToolTip.Len() > 0;
 }
 
-USHORT SwInputField::GetSubType() const
+sal_uInt16 SwInputField::GetSubType() const
 {
     return nSubType;
 }
 
-void SwInputField::SetSubType(USHORT nSub)
+void SwInputField::SetSubType(sal_uInt16 nSub)
 {
     nSubType = nSub;
 }
-/*-----------------05.03.98 17:22-------------------
 
---------------------------------------------------*/
-bool SwSetExpField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
+bool SwSetExpField::QueryValue( uno::Any& rAny, sal_uInt16 nWhichId ) const
 {
     switch( nWhichId )
     {
@@ -1207,7 +1179,7 @@ bool SwSetExpField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
             //I18N - if the formula contains only "TypeName+1"
             //and it's one of the initially created sequence fields
             //then the localized names has to be replaced by a programmatic name
-            OUString sMyFormula = SwXFieldMaster::LocalizeFormula(*this, GetFormula(), TRUE);
+            OUString sMyFormula = SwXFieldMaster::LocalizeFormula(*this, GetFormula(), sal_True);
             rAny <<= OUString( sMyFormula );
         }
         break;
@@ -1226,13 +1198,13 @@ bool SwSetExpField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
         break;
     case FIELD_PROP_BOOL3:
         {
-            BOOL bTmp = 0 != (nSubType & nsSwExtendedSubType::SUB_CMD);
+            sal_Bool bTmp = 0 != (nSubType & nsSwExtendedSubType::SUB_CMD);
             rAny.setValue(&bTmp, ::getBooleanCppuType());
         }
         break;
     case FIELD_PROP_BOOL1:
         {
-            BOOL bTmp = GetInputFlag();
+            sal_Bool bTmp = GetInputFlag();
             rAny.setValue(&bTmp, ::getBooleanCppuType());
         }
         break;
@@ -1244,10 +1216,8 @@ bool SwSetExpField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
     }
     return true;
 }
-/*-----------------05.03.98 17:22-------------------
 
---------------------------------------------------*/
-bool SwSetExpField::PutValue( const uno::Any& rAny, USHORT nWhichId )
+bool SwSetExpField::PutValue( const uno::Any& rAny, sal_uInt16 nWhichId )
 {
     sal_Int32 nTmp32 = 0;
     sal_Int16 nTmp16 = 0;
@@ -1270,8 +1240,6 @@ bool SwSetExpField::PutValue( const uno::Any& rAny, USHORT nWhichId )
             if(nTmp16 <= SVX_NUMBER_NONE )
                 SetFormat(nTmp16);
             else {
-                //exception(wrong_value)
-                ;
             }
         }
         break;
@@ -1290,7 +1258,7 @@ bool SwSetExpField::PutValue( const uno::Any& rAny, USHORT nWhichId )
             //I18N - if the formula contains only "TypeName+1"
             //and it's one of the initially created sequence fields
             //then the localized names has to be replaced by a programmatic name
-            OUString sMyFormula = SwXFieldMaster::LocalizeFormula(*this, uTmp, FALSE);
+            OUString sMyFormula = SwXFieldMaster::LocalizeFormula(*this, uTmp, sal_False);
             SetFormula( sMyFormula );
         }
         break;
@@ -1304,7 +1272,7 @@ bool SwSetExpField::PutValue( const uno::Any& rAny, USHORT nWhichId )
     case FIELD_PROP_SUBTYPE:
         nTmp32 = lcl_APIToSubType(rAny);
         if(nTmp32 >= 0)
-            SetSubType(static_cast<USHORT>((GetSubType() & 0xff00) | nTmp32));
+            SetSubType(static_cast<sal_uInt16>((GetSubType() & 0xff00) | nTmp32));
         break;
     case FIELD_PROP_PAR3:
         ::GetString( rAny, aPText );
