@@ -34,7 +34,6 @@
 
 #include "frame.hxx"       // CalcFlyAdjust()
 #include "paratr.hxx"
-#include "txtcfg.hxx"
 #include "itrtxt.hxx"
 #include "porglue.hxx"
 #include "porlay.hxx"
@@ -175,7 +174,7 @@ bool lcl_CheckKashidaPositions( SwScriptInfo& rSI, SwTxtSizeInfo& rInf, SwTxtIte
             }
             else
             {
-                ULONG nOldLayout = rInf.GetOut()->GetLayoutMode();
+                sal_uLong nOldLayout = rInf.GetOut()->GetLayoutMode();
                 rInf.GetOut()->SetLayoutMode ( nOldLayout | TEXT_LAYOUT_BIDI_RTL );
                 nKashidasDropped = rInf.GetOut()->ValidateKashidas ( rInf.GetTxt(), nIdx, nNext - nIdx,
                                                nKashidasInAttr, pKashidaPos + nKashidaIdx,
@@ -428,7 +427,7 @@ SwTwips SwTxtAdjuster::CalcKanaAdj( SwLineLayout* pCurrent )
     SvUShorts *pNewKana = new SvUShorts;
     pCurrent->SetKanaComp( pNewKana );
 
-    const USHORT nNull = 0;
+    const sal_uInt16 nNull = 0;
     MSHORT nKanaIdx = 0;
     long nKanaDiffSum = 0;
     SwTwips nRepaintOfst = 0;
@@ -447,11 +446,11 @@ SwTwips SwTxtAdjuster::CalcKanaAdj( SwLineLayout* pCurrent )
         {
             // get maximum portion width from info structure, calculated
             // during text formatting
-            USHORT nMaxWidthDiff = GetInfo().GetMaxWidthDiff( (ULONG)pPos );
+            sal_uInt16 nMaxWidthDiff = GetInfo().GetMaxWidthDiff( (sal_uLong)pPos );
 
             // check, if information is stored under other key
             if ( !nMaxWidthDiff && pPos == pCurrent->GetFirstPortion() )
-                nMaxWidthDiff = GetInfo().GetMaxWidthDiff( (ULONG)pCurrent );
+                nMaxWidthDiff = GetInfo().GetMaxWidthDiff( (sal_uLong)pCurrent );
 
             // calculate difference between portion width and max. width
             nKanaDiffSum += nMaxWidthDiff;
@@ -466,7 +465,7 @@ SwTwips SwTxtAdjuster::CalcKanaAdj( SwLineLayout* pCurrent )
             if ( nKanaIdx == pCurrent->GetKanaComp().Count() )
                 pCurrent->GetKanaComp().Insert( nNull, nKanaIdx );
 
-            USHORT nRest;
+            sal_uInt16 nRest;
 
             if ( pPos->InTabGrp() )
             {
@@ -491,7 +490,7 @@ SwTwips SwTxtAdjuster::CalcKanaAdj( SwLineLayout* pCurrent )
 
             if( nKanaDiffSum )
             {
-                ULONG nCompress = ( 10000 * nRest ) / nKanaDiffSum;
+                sal_uLong nCompress = ( 10000 * nRest ) / nKanaDiffSum;
 
                 if ( nCompress >= 10000 )
                     // kanas can be expanded to 100%, and there is still
@@ -501,7 +500,7 @@ SwTwips SwTxtAdjuster::CalcKanaAdj( SwLineLayout* pCurrent )
                 else
                     nCompress = 10000 - nCompress;
 
-                ( pCurrent->GetKanaComp() )[ nKanaIdx ] = (USHORT)nCompress;
+                ( pCurrent->GetKanaComp() )[ nKanaIdx ] = (sal_uInt16)nCompress;
                 nKanaDiffSum = 0;
             }
 
@@ -514,7 +513,7 @@ SwTwips SwTxtAdjuster::CalcKanaAdj( SwLineLayout* pCurrent )
 
     // set portion width
     nKanaIdx = 0;
-    USHORT nCompress = ( pCurrent->GetKanaComp() )[ nKanaIdx ];
+    sal_uInt16 nCompress = ( pCurrent->GetKanaComp() )[ nKanaIdx ];
     pPos = pCurrent->GetPortion();
     long nDecompress = 0;
     nKanaDiffSum = 0;
@@ -523,15 +522,15 @@ SwTwips SwTxtAdjuster::CalcKanaAdj( SwLineLayout* pCurrent )
     {
         if ( pPos->InTxtGrp() )
         {
-            const USHORT nMinWidth = pPos->Width();
+            const sal_uInt16 nMinWidth = pPos->Width();
 
             // get maximum portion width from info structure, calculated
             // during text formatting
-            USHORT nMaxWidthDiff = GetInfo().GetMaxWidthDiff( (ULONG)pPos );
+            sal_uInt16 nMaxWidthDiff = GetInfo().GetMaxWidthDiff( (sal_uLong)pPos );
 
             // check, if information is stored under other key
             if ( !nMaxWidthDiff && pPos == pCurrent->GetFirstPortion() )
-                nMaxWidthDiff = GetInfo().GetMaxWidthDiff( (ULONG)pCurrent );
+                nMaxWidthDiff = GetInfo().GetMaxWidthDiff( (sal_uLong)pCurrent );
             nKanaDiffSum += nMaxWidthDiff;
             pPos->Width( nMinWidth +
                        ( ( 10000 - nCompress ) * nMaxWidthDiff ) / 10000 );
@@ -545,7 +544,7 @@ SwTwips SwTxtAdjuster::CalcKanaAdj( SwLineLayout* pCurrent )
                 nKanaDiffSum /= 10000;
             }
 
-            pPos->Width( static_cast<USHORT>(pPos->Width() - nDecompress) );
+            pPos->Width( static_cast<sal_uInt16>(pPos->Width() - nDecompress) );
 
             if ( pPos->InTabGrp() )
                 // set fix width to width
@@ -572,8 +571,8 @@ SwMarginPortion *SwTxtAdjuster::CalcRightMargin( SwLineLayout *pCurrent,
     SwTwips nReal )
 {
     long nRealWidth;
-    const USHORT nRealHeight = GetLineHeight();
-    const USHORT nLineHeight = pCurrent->Height();
+    const sal_uInt16 nRealHeight = GetLineHeight();
+    const sal_uInt16 nLineHeight = pCurrent->Height();
 
     KSHORT nPrtWidth = pCurrent->PrtWidth();
     SwLinePortion *pLast = pCurrent->FindLastPortion();
@@ -730,21 +729,7 @@ void SwTxtAdjuster::CalcAdjLine( SwLineLayout *pCurrent )
         }
         case SVX_ADJUST_BLOCK:
         {
-            // disabled for #i13507#
-            // 8311: In Zeilen mit LineBreaks gibt es keinen Blocksatz!
-/*          if( pCurrent->GetLen() &&
-                CH_BREAK == GetInfo().GetChar( nStart + pCurrent->GetLen() - 1 ) &&
-                !IsLastBlock() )
-            {
-                if( IsLastCenter() )
-                {
-                    CalcFlyAdjust( pCurrent );
-                    pPara->GetRepaint()->SetOfst( 0 );
-                    break;
-                }
-                return;
-            }
-*/          FormatBlock();
+            FormatBlock();
             break;
         }
         default : return;
@@ -882,9 +867,6 @@ void SwTxtAdjuster::CalcDropAdjust()
                         pLeft->MoveAllGlue( pRight );
                     else
                         pLeft->MoveGlue( pRight, nGlue );
-#ifdef DBGTXT
-                    aDbstream << "Drop adjusted: " << nGlue << endl;
-#endif
                 }
             }
         }
