@@ -34,6 +34,7 @@
 #include "dflyobj.hxx"	// SwVirtFlyDrawObj
 #include "pam.hxx"		// SwPosition
 #include "flyfrm.hxx"	// SwFlyInCntFrm
+#include "rootfrm.hxx"
 #include "frmfmt.hxx"	// SwFrmFmt
 #include "viewsh.hxx"
 
@@ -76,7 +77,7 @@ sal_Bool SwFlyPortion::Format( SwTxtFormatInfo &rInf )
 
     // Der Glue wird aufgespannt.
     rInf.GetLast()->FormatEOL( rInf );
-    PrtWidth( static_cast<USHORT>(Fix() - rInf.X() + PrtWidth()) );
+    PrtWidth( static_cast<sal_uInt16>(Fix() - rInf.X() + PrtWidth()) );
     if( !Width() )
     {
         OSL_ENSURE( Width(), "+SwFlyPortion::Format: a fly is a fly is a fly" );
@@ -99,7 +100,7 @@ sal_Bool SwFlyPortion::Format( SwTxtFormatInfo &rInf )
         SetLen( 1 );
     }
 
-    const USHORT nNewWidth = static_cast<USHORT>(rInf.X() + PrtWidth());
+    const sal_uInt16 nNewWidth = static_cast<sal_uInt16>(rInf.X() + PrtWidth());
     if( rInf.Width() <= nNewWidth )
     {
         Truncate();
@@ -129,7 +130,7 @@ sal_Bool SwFlyCntPortion::Format( SwTxtFormatInfo &rInf )
         // KerningPortions at beginning of line, e.g., for grid layout
         // must be considered.
         const SwLinePortion* pLastPor = rInf.GetLast();
-        const USHORT nLeft = ( pLastPor &&
+        const sal_uInt16 nLeft = ( pLastPor &&
                                     ( pLastPor->IsKernPortion() ||
                                       pLastPor->IsErgoSumPortion() ) ) ?
                                pLastPor->Width() :
@@ -209,7 +210,7 @@ xub_StrLen SwTxtFrm::CalcFlyPos( SwFrmFmt* pSearch )
     if( !pHints )
         return STRING_LEN;
     SwTxtAttr* pFound = NULL;
-    for ( USHORT i = 0; i < pHints->Count(); i++)
+    for ( sal_uInt16 i = 0; i < pHints->Count(); i++)
     {
         SwTxtAttr *pHt = pHints->GetTextHint( i );
         if( RES_TXTATR_FLYCNT == pHt->Which() )
@@ -255,7 +256,7 @@ void SwFlyCntPortion::Paint( const SwTxtPaintInfo &rInf ) const
         if( (GetFlyFrm()->IsCompletePaint() ||
              GetFlyFrm()->Frm().IsOver( aRepaintRect )) &&
              SwFlyFrm::IsPaint( (SdrObject*)GetFlyFrm()->GetVirtDrawObj(),
-                                GetFlyFrm()->GetShell() ))
+                                GetFlyFrm()->getRootFrm()->GetCurrShell() ))
         {
             SwRect aRect( GetFlyFrm()->Frm() );
             if( !GetFlyFrm()->IsCompletePaint() )
@@ -365,7 +366,7 @@ void SwFlyCntPortion::SetBase( const SwTxtFrm& rFrm, const Point &rBase,
         pSdrObj = GetDrawContact()->GetDrawObjectByAnchorFrm( rFrm );
         if ( !pSdrObj )
         {
-            OSL_ENSURE( false, "SwFlyCntPortion::SetBase(..) - No drawing object found by <GetDrawContact()->GetDrawObjectByAnchorFrm( rFrm )>" );
+            OSL_FAIL( "SwFlyCntPortion::SetBase(..) - No drawing object found by <GetDrawContact()->GetDrawObjectByAnchorFrm( rFrm )>" );
             pSdrObj = GetDrawContact()->GetMaster();
         }
         // --> OD 2007-11-29 #i65798#
@@ -408,14 +409,14 @@ void SwFlyCntPortion::SetBase( const SwTxtFrm& rFrm, const Point &rBase,
         SwTwips nRelPos = aObjPositioning.GetRelPosY();
         if ( nRelPos < 0 )
         {
-            nAscent = static_cast<USHORT>(-nRelPos);
+            nAscent = static_cast<sal_uInt16>(-nRelPos);
             if( nAscent > Height() )
                 Height( nAscent );
         }
         else
         {
             nAscent = 0;
-            Height( Height() + static_cast<USHORT>(nRelPos) );
+            Height( Height() + static_cast<sal_uInt16>(nRelPos) );
         }
     }
     else
