@@ -64,7 +64,7 @@
 using namespace ::com::sun::star;
 extern sal_Bool IsUnderlineBreak( const SwLinePortion& rPor, const SwFont& rFnt );
 
-/*-----------------10.10.00 15:23-------------------
+/*--------------------------------------------------
  *  class SwMultiPortion
  *
  * A SwMultiPortion is not a simple portion,
@@ -80,11 +80,10 @@ SwMultiPortion::~SwMultiPortion()
 
 void SwMultiPortion::Paint( const SwTxtPaintInfo & ) const
 {
-    OSL_ENSURE( FALSE,
-    "Don't try SwMultiPortion::Paint, try SwTxtPainter::PaintMultiPortion" );
+    OSL_FAIL( "Don't try SwMultiPortion::Paint, try SwTxtPainter::PaintMultiPortion" );
 }
 
-/*-----------------13.10.00 16:21-------------------
+/*--------------------------------------------------
  * Summarize the internal lines to calculate the (external) size.
  * The internal line has to calculate first.
  * --------------------------------------------------*/
@@ -154,7 +153,7 @@ void SwMultiPortion::HandlePortion( SwPortionHandler& rPH ) const
     rPH.Text( GetLen(), GetWhichPor() );
 }
 
-/*-----------------01.11.00 14:21-------------------
+/*--------------------------------------------------
  * SwMultiPortion::ActualizeTabulator()
  * sets the tabulator-flag, if there's any tabulator-portion inside.
  * --------------------------------------------------*/
@@ -179,7 +178,7 @@ void SwMultiPortion::ActualizeTabulator()
     }
 }
 
-/*-----------------16.02.01 12:07-------------------
+/*--------------------------------------------------
  * SwRotatedPortion::SwRotatedPortion(..)
  * --------------------------------------------------*/
 
@@ -213,7 +212,7 @@ SwRotatedPortion::SwRotatedPortion( const SwMultiCreator& rCreate,
  * SwBidiPortion::SwBidiPortion(..)
  * --------------------------------------------------*/
 
-SwBidiPortion::SwBidiPortion( xub_StrLen nEnd, BYTE nLv )
+SwBidiPortion::SwBidiPortion( xub_StrLen nEnd, sal_uInt8 nLv )
     : SwMultiPortion( nEnd ), nLevel( nLv )
 {
     SetBidi();
@@ -265,7 +264,7 @@ xub_StrLen SwBidiPortion::GetSpaceCnt( const SwTxtSizeInfo &rInf ) const
     return nBlanks;
 }
 
-/*-----------------01.11.00 14:22-------------------
+/*--------------------------------------------------
  * SwDoubleLinePortion::SwDoubleLinePortion(..)
  * This constructor is for the continuation of a doubleline portion
  * in the next line.
@@ -294,7 +293,7 @@ SwDoubleLinePortion::SwDoubleLinePortion( SwDoubleLinePortion& rDouble,
     }
 }
 
-/*-----------------01.11.00 14:22-------------------
+/*--------------------------------------------------
  * SwDoubleLinePortion::SwDoubleLinePortion(..)
  * This constructor uses the textattribut to get the right brackets.
  * The textattribut could be a 2-line-attribute or a character- or
@@ -330,7 +329,7 @@ SwDoubleLinePortion::SwDoubleLinePortion( const SwMultiCreator& rCreate,
         pBracket->cPre = 0;
         pBracket->cPost = 0;
     }
-    BYTE nTmp = SW_SCRIPTS;
+    sal_uInt8 nTmp = SW_SCRIPTS;
     if( pBracket->cPre > 255 )
     {
         String aTxt( pBracket->cPre );
@@ -359,7 +358,7 @@ SwDoubleLinePortion::SwDoubleLinePortion( const SwMultiCreator& rCreate,
 }
 
 
-/*-----------------25.10.00 09:51-------------------
+/*--------------------------------------------------
  * SwMultiPortion::PaintBracket paints the wished bracket,
  * if the multiportion has surrounding brackets.
  * The X-position of the SwTxtPaintInfo will be modified:
@@ -387,7 +386,7 @@ void SwDoubleLinePortion::PaintBracket( SwTxtPaintInfo &rInf,
     aBlank.Height( pBracket->nHeight );
     {
         SwFont* pTmpFnt = new SwFont( *rInf.GetFont() );
-        BYTE nAct = bOpen ? pBracket->nPreScript : pBracket->nPostScript;
+        sal_uInt8 nAct = bOpen ? pBracket->nPreScript : pBracket->nPostScript;
         if( SW_SCRIPTS > nAct )
             pTmpFnt->SetActual( nAct );
         pTmpFnt->SetProportion( 100 );
@@ -399,7 +398,7 @@ void SwDoubleLinePortion::PaintBracket( SwTxtPaintInfo &rInf,
         rInf.X( rInf.X() + PreWidth() );
 }
 
-/*-----------------25.10.00 16:26-------------------
+/*--------------------------------------------------
  * SwDoubleLinePortion::SetBrackets creates the bracket-structur
  * and fills it, if not both characters are 0x00.
  * --------------------------------------------------*/
@@ -417,7 +416,7 @@ void SwDoubleLinePortion::SetBrackets( const SwDoubleLinePortion& rDouble )
     }
 }
 
-/*-----------------25.10.00 16:29-------------------
+/*--------------------------------------------------
  * SwDoubleLinePortion::FormatBrackets
  * calculates the size of the brackets => pBracket,
  * reduces the nMaxWidth-parameter ( minus bracket-width )
@@ -434,7 +433,7 @@ void SwDoubleLinePortion::FormatBrackets( SwTxtFormatInfo &rInf, SwTwips& nMaxWi
     if( pBracket->cPre )
     {
         String aStr( pBracket->cPre );
-        BYTE nActualScr = pTmpFnt->GetActual();
+        sal_uInt8 nActualScr = pTmpFnt->GetActual();
         if( SW_SCRIPTS > pBracket->nPreScript )
             pTmpFnt->SetActual( pBracket->nPreScript );
         SwFontSave aSave( rInf, pTmpFnt );
@@ -487,7 +486,7 @@ void SwDoubleLinePortion::FormatBrackets( SwTxtFormatInfo &rInf, SwTwips& nMaxWi
     nMaxWidth += rInf.X();
 }
 
-/*-----------------26.10.00 10:36-------------------
+/*--------------------------------------------------
  * SwDoubleLinePortion::CalcBlanks
  * calculates the number of blanks in each line and
  * the difference of the width of the two lines.
@@ -531,7 +530,7 @@ long SwDoubleLinePortion::CalcSpacing( long nSpaceAdd, const SwTxtSizeInfo & ) c
     return HasTabulator() ? 0 : GetSpaceCnt() * nSpaceAdd / SPACING_PRECISION_FACTOR;
 }
 
-/*-----------------01.11.00 14:29-------------------
+/*--------------------------------------------------
  * SwDoubleLinePortion::ChangeSpaceAdd(..)
  * merges the spaces for text adjustment from the inner and outer part.
  * Inside the doubleline portion the wider line has no spaceadd-array, the
@@ -577,7 +576,7 @@ sal_Bool SwDoubleLinePortion::ChgSpaceAdd( SwLineLayout* pCurr,
     }
     return bRet;
 }
-/*-----------------01.11.00 14:29-------------------
+/*--------------------------------------------------
  * SwDoubleLinePortion::ResetSpaceAdd(..)
  * cancels the manipulation from SwDoubleLinePortion::ChangeSpaceAdd(..)
  * --------------------------------------------------*/
@@ -594,7 +593,7 @@ SwDoubleLinePortion::~SwDoubleLinePortion()
     delete pBracket;
 }
 
-/*-----------------13.11.00 14:50-------------------
+/*--------------------------------------------------
  * SwRubyPortion::SwRubyPortion(..)
  * constructs a ruby portion, i.e. an additional text is displayed
  * beside the main text, e.g. phonetic characters.
@@ -611,7 +610,7 @@ SwRubyPortion::SwRubyPortion( const SwRubyPortion& rRuby, xub_StrLen nEnd ) :
     SetRuby();
 }
 
-/*-----------------13.11.00 14:50-------------------
+/*--------------------------------------------------
  * SwRubyPortion::SwRubyPortion(..)
  * constructs a ruby portion, i.e. an additional text is displayed
  * beside the main text, e.g. phonetic characters.
@@ -678,7 +677,7 @@ SwRubyPortion::SwRubyPortion( const SwMultiCreator& rCreate, const SwFont& rFnt,
         SetDirection( DIR_LEFT2RIGHT );
 }
 
-/*-----------------13.11.00 14:56-------------------
+/*--------------------------------------------------
  * SwRubyPortion::_Adjust(..)
  * In ruby portion there are different alignments for
  * the ruby text and the main text.
@@ -714,11 +713,11 @@ void SwRubyPortion::_Adjust( SwTxtFormatInfo &rInf )
     }
     KSHORT nLeft = 0;	// the space in front of the first letter
     KSHORT nRight = 0;	// the space at the end of the last letter
-    USHORT nSub = 0;
+    sal_uInt16 nSub = 0;
     switch ( nAdjustment )
     {
-        case 1: nRight = static_cast<USHORT>(nLineDiff / 2);    // no break
-        case 2: nLeft  = static_cast<USHORT>(nLineDiff - nRight); break;
+        case 1: nRight = static_cast<sal_uInt16>(nLineDiff / 2);    // no break
+        case 2: nLeft  = static_cast<sal_uInt16>(nLineDiff - nRight); break;
         case 3: nSub   = 1; // no break
         case 4:
         {
@@ -744,12 +743,12 @@ void SwRubyPortion::_Adjust( SwTxtFormatInfo &rInf )
             }
             if( nLineDiff > 1 )
             {
-                nRight = static_cast<USHORT>(nLineDiff / 2);
-                nLeft  = static_cast<USHORT>(nLineDiff - nRight);
+                nRight = static_cast<sal_uInt16>(nLineDiff / 2);
+                nLeft  = static_cast<sal_uInt16>(nLineDiff - nRight);
             }
             break;
         }
-        default: OSL_ENSURE( sal_False, "New ruby adjustment" );
+        default: OSL_FAIL( "New ruby adjustment" );
     }
     if( nLeft || nRight )
     {
@@ -774,7 +773,7 @@ void SwRubyPortion::_Adjust( SwTxtFormatInfo &rInf )
     rInf.SetIdx( nOldIdx );
 }
 
-/*-----------------08.11.00 14:14-------------------
+/*--------------------------------------------------
  * CalcRubyOffset()
  * has to change the nRubyOffset, if there's a fieldportion
  * in the phonetic line.
@@ -808,7 +807,7 @@ void SwRubyPortion::CalcRubyOffset()
     }
 }
 
-/*-----------------13.10.00 16:22-------------------
+/*--------------------------------------------------
  * SwTxtSizeInfo::GetMultiCreator(..)
  * If we (e.g. the position rPos) are inside a two-line-attribute or
  * a ruby-attribute, the attribute will be returned in a SwMultiCreator-struct,
@@ -821,11 +820,11 @@ void SwRubyPortion::CalcRubyOffset()
  * with different brackets interrupts another 2-line-attribute.
  * --------------------------------------------------*/
 
-/*-----------------13.11.00 15:38-------------------
+/*--------------------------------------------------
  * lcl_Has2Lines(..)
  * is a little help function for GetMultiCreator(..)
  * It extracts the 2-line-format from a 2-line-attribute or a character style.
- * The rValue is set to TRUE, if the 2-line-attribute's value is set and
+ * The rValue is set to sal_True, if the 2-line-attribute's value is set and
  * no 2-line-format reference is passed. If there is a 2-line-format reference,
  * then the rValue is set only, if the 2-line-attribute's value is set _and_
  * the 2-line-formats has the same brackets.
@@ -850,11 +849,11 @@ sal_Bool lcl_Has2Lines( const SwTxtAttr& rAttr, const SvxTwoLinesItem* &rpRef,
     return sal_False;
 }
 
-/*-----------------16.02.01 16:39-------------------
+/*--------------------------------------------------
  * lcl_HasRotation(..)
  * is a little help function for GetMultiCreator(..)
  * It extracts the charrotation from a charrotate-attribute or a character style.
- * The rValue is set to TRUE, if the charrotate-attribute's value is set and
+ * The rValue is set to sal_True, if the charrotate-attribute's value is set and
  * no charrotate-format reference is passed.
  * If there is a charrotate-format reference, then the rValue is set only,
  * if the charrotate-attribute's value is set _and_ identical
@@ -885,7 +884,7 @@ SwMultiCreator* SwTxtSizeInfo::GetMultiCreator( xub_StrLen &rPos,
     SwScriptInfo& rSI = ((SwParaPortion*)GetParaPortion())->GetScriptInfo();
 
     // get the last embedding level
-    BYTE nCurrLevel;
+    sal_uInt8 nCurrLevel;
     if ( pMulti )
     {
         OSL_ENSURE( pMulti->IsBidi(), "Nested MultiPortion is not BidiPortion" );
@@ -897,7 +896,7 @@ SwMultiCreator* SwTxtSizeInfo::GetMultiCreator( xub_StrLen &rPos,
         nCurrLevel = GetTxtFrm()->IsRightToLeft() ? 1 : 0;
 
     // check if there is a field at rPos:
-    BYTE nNextLevel = nCurrLevel;
+    sal_uInt8 nNextLevel = nCurrLevel;
     sal_Bool bFldBidi = sal_False;
 
     if ( CH_TXTATR_BREAKWORD == GetChar( rPos ) )
@@ -943,7 +942,7 @@ SwMultiCreator* SwTxtSizeInfo::GetMultiCreator( xub_StrLen &rPos,
     const SvxCharRotateItem* pRotate = NULL;
     const SfxPoolItem* pRotItem;
     if( SFX_ITEM_SET == pFrm->GetTxtNode()->GetSwAttrSet().
-        GetItemState( RES_CHRATR_ROTATE, TRUE, &pRotItem ) &&
+        GetItemState( RES_CHRATR_ROTATE, sal_True, &pRotItem ) &&
         ((SvxCharRotateItem*)pRotItem)->GetValue() )
         pRotate = (SvxCharRotateItem*)pRotItem;
     else
@@ -951,7 +950,7 @@ SwMultiCreator* SwTxtSizeInfo::GetMultiCreator( xub_StrLen &rPos,
     const SvxTwoLinesItem* p2Lines = NULL;
     const SfxPoolItem* pItem;
     if( SFX_ITEM_SET == pFrm->GetTxtNode()->GetSwAttrSet().
-        GetItemState( RES_CHRATR_TWO_LINES, TRUE, &pItem ) &&
+        GetItemState( RES_CHRATR_TWO_LINES, sal_True, &pItem ) &&
         ((SvxTwoLinesItem*)pItem)->GetValue() )
         p2Lines = (SvxTwoLinesItem*)pItem;
     else
@@ -963,10 +962,10 @@ SwMultiCreator* SwTxtSizeInfo::GetMultiCreator( xub_StrLen &rPos,
     const SwTxtAttr *pRuby = NULL;
     sal_Bool bTwo = sal_False;
     sal_Bool bRot = sal_False;
-    USHORT n2Lines = USHRT_MAX;
-    USHORT nRotate = USHRT_MAX;
-    USHORT nCount = pHints ? pHints->Count() : 0;
-    USHORT i;
+    sal_uInt16 n2Lines = USHRT_MAX;
+    sal_uInt16 nRotate = USHRT_MAX;
+    sal_uInt16 nCount = pHints ? pHints->Count() : 0;
+    sal_uInt16 i;
     for( i = 0; i < nCount; ++i )
     {
         const SwTxtAttr *pTmp = (*pHints)[i];
@@ -1023,10 +1022,10 @@ SwMultiCreator* SwTxtSizeInfo::GetMultiCreator( xub_StrLen &rPos,
         {
             pRet->pItem = NULL;
             pRet->pAttr = (*pHints)[n2Lines];
-            aEnd.Insert( *pRet->pAttr->GetEnd(), 0 );
+            aEnd.push_front( *pRet->pAttr->GetEnd() );
             if( pItem )
             {
-                aEnd[ 0 ] = GetTxt().Len();
+                aEnd.front() = GetTxt().Len();
                 bOn = ((SvxTwoLinesItem*)pItem)->GetEndBracket() ==
                         p2Lines->GetEndBracket() &&
                       ((SvxTwoLinesItem*)pItem)->GetStartBracket() ==
@@ -1037,7 +1036,7 @@ SwMultiCreator* SwTxtSizeInfo::GetMultiCreator( xub_StrLen &rPos,
         {
             pRet->pItem = pItem;
             pRet->pAttr = NULL;
-            aEnd.Insert( GetTxt().Len(), 0 );
+            aEnd.push_front( GetTxt().Len() );
         }
         pRet->nId = SW_MC_DOUBLE;
         pRet->nLevel = GetTxtFrm()->IsRightToLeft() ? 1 : 0;
@@ -1066,28 +1065,28 @@ SwMultiCreator* SwTxtSizeInfo::GetMultiCreator( xub_StrLen &rPos,
                 continue;
             if( rPos < *pTmp->GetStart() )
             {
-                // If bOn is FALSE and the next attribute starts later than rPos
+                // If bOn is sal_False and the next attribute starts later than rPos
                 // the winner attribute is interrupted at rPos.
                 // If the start of the next atribute is behind the end of
                 // the last attribute on the aEnd-stack, this is the endposition
                 // on the stack is the end of the 2-line portion.
-                if( !bOn || aEnd[ aEnd.Count()-1 ] < *pTmp->GetStart() )
+                if( !bOn || aEnd.back() < *pTmp->GetStart() )
                     break;
-                // At this moment, bOn is TRUE and the next attribute starts
+                // At this moment, bOn is sal_True and the next attribute starts
                 // behind rPos, so we could move rPos to the next startpoint
                 rPos = *pTmp->GetStart();
                 // We clean up the aEnd-stack, endpositions equal to rPos are
                 // superfluous.
-                while( aEnd.Count() && aEnd[ aEnd.Count()-1 ] <= rPos )
+                while( !aEnd.empty() && aEnd.back() <= rPos )
                 {
                     bOn = !bOn;
-                    aEnd.Remove( aEnd.Count()-1, 1 );
+                    aEnd.pop_back();
                 }
                 // If the endstack is empty, we simulate an attribute with
-                // state TRUE and endposition rPos
-                if( !aEnd.Count() )
+                // state sal_True and endposition rPos
+                if( aEnd.empty() )
                 {
-                    aEnd.Insert( rPos, 0 );
+                    aEnd.push_front( rPos );
                     bOn = sal_True;
                 }
             }
@@ -1099,8 +1098,8 @@ SwMultiCreator* SwTxtSizeInfo::GetMultiCreator( xub_StrLen &rPos,
                 if( bTwo == bOn )
                 {   // .. with the same state, so the last attribute could
                     // be continued.
-                    if( aEnd[ aEnd.Count()-1 ] < *pTmp->GetEnd() )
-                        aEnd[ aEnd.Count()-1 ] = *pTmp->GetEnd();
+                    if( aEnd.back() < *pTmp->GetEnd() )
+                        aEnd.back() = *pTmp->GetEnd();
                 }
                 else
                 {   // .. with a different state.
@@ -1108,17 +1107,17 @@ SwMultiCreator* SwTxtSizeInfo::GetMultiCreator( xub_StrLen &rPos,
                     // If this is smaller than the last on the stack, we put
                     // it on the stack. If it has the same endposition, the last
                     // could be removed.
-                    if( aEnd[ aEnd.Count()-1 ] > *pTmp->GetEnd() )
-                        aEnd.Insert( *pTmp->GetEnd(), aEnd.Count() );
-                    else if( aEnd.Count() > 1 )
-                        aEnd.Remove( aEnd.Count()-1, 1 );
+                    if( aEnd.back() > *pTmp->GetEnd() )
+                        aEnd.push_back( *pTmp->GetEnd() );
+                    else if( aEnd.size() > 1 )
+                        aEnd.pop_back();
                     else
-                        aEnd[ aEnd.Count()-1 ] = *pTmp->GetEnd();
+                        aEnd.back() = *pTmp->GetEnd();
                 }
             }
         }
-        if( bOn && aEnd.Count() )
-            rPos = aEnd[ aEnd.Count()-1 ];
+        if( bOn && !aEnd.empty() )
+            rPos = aEnd.back();
         return pRet;
     }
     if( nRotate < nCount || ( pRotItem && pRotItem == pRotate &&
@@ -1134,7 +1133,7 @@ SwMultiCreator* SwTxtSizeInfo::GetMultiCreator( xub_StrLen &rPos,
         // The bOn flag signs the state of the last 2-line attribute in the
         // aEnd-stack, which could interrupts the winning rotation attribute.
         sal_Bool bOn = pItem ? sal_True : sal_False;
-        aEnd.Insert( GetTxt().Len(), 0 );
+        aEnd.push_front( GetTxt().Len() );
         // n2Lines is the index of the last 2-line-attribute, which contains
         // the actual position.
         i = 0;
@@ -1146,17 +1145,17 @@ SwMultiCreator* SwTxtSizeInfo::GetMultiCreator( xub_StrLen &rPos,
                 continue;
             if( n2Start < *pTmp->GetStart() )
             {
-                if( bOn || aEnd[ aEnd.Count()-1 ] < *pTmp->GetStart() )
+                if( bOn || aEnd.back() < *pTmp->GetStart() )
                     break;
                 n2Start = *pTmp->GetStart();
-                while( aEnd.Count() && aEnd[ aEnd.Count()-1 ] <= n2Start )
+                while( !aEnd.empty() && aEnd.back() <= n2Start )
                 {
                     bOn = !bOn;
-                    aEnd.Remove( aEnd.Count()-1, 1 );
+                    aEnd.pop_back();
                 }
-                if( !aEnd.Count() )
+                if( aEnd.empty() )
                 {
-                    aEnd.Insert( n2Start, 0 );
+                    aEnd.push_front( n2Start );
                     bOn = sal_False;
                 }
             }
@@ -1171,36 +1170,36 @@ SwMultiCreator* SwTxtSizeInfo::GetMultiCreator( xub_StrLen &rPos,
             {
                 if( bTwo == bOn )
                 {
-                    if( aEnd[ aEnd.Count()-1 ] < *pTmp->GetEnd() )
-                        aEnd[ aEnd.Count()-1 ] = *pTmp->GetEnd();
+                    if( aEnd.back() < *pTmp->GetEnd() )
+                        aEnd.back() = *pTmp->GetEnd();
                 }
                 else
                 {
                     bOn = bTwo;
-                    if( aEnd[ aEnd.Count()-1 ] > *pTmp->GetEnd() )
-                        aEnd.Insert( *pTmp->GetEnd(), aEnd.Count() );
-                    else if( aEnd.Count() > 1 )
-                        aEnd.Remove( aEnd.Count()-1, 1 );
+                    if( aEnd.back() > *pTmp->GetEnd() )
+                        aEnd.push_back( *pTmp->GetEnd() );
+                    else if( aEnd.size() > 1 )
+                        aEnd.pop_back();
                     else
-                        aEnd[ aEnd.Count()-1 ] = *pTmp->GetEnd();
+                        aEnd.back() = *pTmp->GetEnd();
                 }
             }
         }
-        if( !bOn && aEnd.Count() )
-            n2Start = aEnd[ aEnd.Count()-1 ];
+        if( !bOn && !aEnd.empty() )
+            n2Start = aEnd.back();
 
-        if( aEnd.Count() )
-            aEnd.Remove( 0, aEnd.Count() );
+        if( !aEnd.empty() )
+            aEnd.clear();
 
         bOn = sal_True;
         if( nRotate < nCount )
         {
             pRet->pItem = NULL;
             pRet->pAttr = (*pHints)[nRotate];
-            aEnd.Insert( *pRet->pAttr->GetEnd(), 0 );
+            aEnd.push_front( *pRet->pAttr->GetEnd() );
             if( pRotItem )
             {
-                aEnd[ 0 ] = GetTxt().Len();
+                aEnd.front() = GetTxt().Len();
                 bOn = ((SvxCharRotateItem*)pRotItem)->GetValue() ==
                         pRotate->GetValue();
             }
@@ -1209,7 +1208,7 @@ SwMultiCreator* SwTxtSizeInfo::GetMultiCreator( xub_StrLen &rPos,
         {
             pRet->pItem = pRotItem;
             pRet->pAttr = NULL;
-            aEnd.Insert( GetTxt().Len(), 0 );
+            aEnd.push_front( GetTxt().Len() );
         }
         i = 0;
         while( i < nCount )
@@ -1219,17 +1218,17 @@ SwMultiCreator* SwTxtSizeInfo::GetMultiCreator( xub_StrLen &rPos,
                 continue;
             if( rPos < *pTmp->GetStart() )
             {
-                if( !bOn || aEnd[ aEnd.Count()-1 ] < *pTmp->GetStart() )
+                if( !bOn || aEnd.back() < *pTmp->GetStart() )
                     break;
                 rPos = *pTmp->GetStart();
-                while( aEnd.Count() && aEnd[ aEnd.Count()-1 ] <= rPos )
+                while( !aEnd.empty() && aEnd.back() <= rPos )
                 {
                     bOn = !bOn;
-                    aEnd.Remove( aEnd.Count()-1, 1 );
+                    aEnd.pop_back();
                 }
-                if( !aEnd.Count() )
+                if( aEnd.empty() )
                 {
-                    aEnd.Insert( rPos, 0 );
+                    aEnd.push_front( rPos );
                     bOn = sal_True;
                 }
             }
@@ -1242,23 +1241,23 @@ SwMultiCreator* SwTxtSizeInfo::GetMultiCreator( xub_StrLen &rPos,
             {
                 if( bTwo == bOn )
                 {
-                    if( aEnd[ aEnd.Count()-1 ] < *pTmp->GetEnd() )
-                        aEnd[ aEnd.Count()-1 ] = *pTmp->GetEnd();
+                    if( aEnd.back() < *pTmp->GetEnd() )
+                        aEnd.back() = *pTmp->GetEnd();
                 }
                 else
                 {
                     bOn = bTwo;
-                    if( aEnd[ aEnd.Count()-1 ] > *pTmp->GetEnd() )
-                        aEnd.Insert( *pTmp->GetEnd(), aEnd.Count() );
-                    else if( aEnd.Count() > 1 )
-                        aEnd.Remove( aEnd.Count()-1, 1 );
+                    if( aEnd.back() > *pTmp->GetEnd() )
+                        aEnd.push_back( *pTmp->GetEnd() );
+                    else if( aEnd.size() > 1 )
+                        aEnd.pop_back();
                     else
-                        aEnd[ aEnd.Count()-1 ] = *pTmp->GetEnd();
+                        aEnd.back() = *pTmp->GetEnd();
                 }
             }
         }
-        if( bOn && aEnd.Count() )
-            rPos = aEnd[ aEnd.Count()-1 ];
+        if( bOn && !aEnd.empty() )
+            rPos = aEnd.back();
         if( rPos > n2Start )
             rPos = n2Start;
         return pRet;
@@ -1266,7 +1265,7 @@ SwMultiCreator* SwTxtSizeInfo::GetMultiCreator( xub_StrLen &rPos,
     return NULL;
 }
 
-/*-----------------01.11.00 14:52-------------------
+/*--------------------------------------------------
  * SwSpaceManipulator
  * is a little helper class to manage the spaceadd-arrays of the text adjustment
  * during a PaintMultiPortion.
@@ -1356,7 +1355,7 @@ SwSpaceManipulator::~SwSpaceManipulator()
     rInfo.SetDirection( nOldDir );
 }
 
-/*-----------------13.10.00 16:24-------------------
+/*--------------------------------------------------
  * SwTxtPainter::PaintMultiPortion manages the paint for a SwMultiPortion.
  * External, for the calling function, it seems to be a normal Paint-function,
  * internal it is like a SwTxtFrm::Paint with multiple DrawTextLines
@@ -1367,13 +1366,11 @@ void SwTxtPainter::PaintMultiPortion( const SwRect &rPaint,
 {
     GETGRID( pFrm->FindPageFrm() )
     const sal_Bool bHasGrid = pGrid && GetInfo().SnapToGrid();
-    USHORT nGridWidth = 0;
-    USHORT nRubyHeight = 0;
+    sal_uInt16 nRubyHeight = 0;
     sal_Bool bRubyTop = sal_False;
 
     if ( bHasGrid )
     {
-        nGridWidth = pGrid->GetBaseHeight();
         nRubyHeight = pGrid->GetRubyHeight();
         bRubyTop = ! pGrid->GetRubyTextBelow();
     }
@@ -1381,7 +1378,7 @@ void SwTxtPainter::PaintMultiPortion( const SwRect &rPaint,
     // do not allow grid mode for first line in ruby portion
     const sal_Bool bRubyInGrid = bHasGrid && rMulti.IsRuby();
 
-    const USHORT nOldHeight = rMulti.Height();
+    const sal_uInt16 nOldHeight = rMulti.Height();
     const sal_Bool bOldGridModeAllowed = GetInfo().SnapToGrid();
 
     if ( bRubyInGrid )
@@ -1391,9 +1388,9 @@ void SwTxtPainter::PaintMultiPortion( const SwRect &rPaint,
     }
 
     SwLayoutModeModifier aLayoutModeModifier( *GetInfo().GetOut() );
-    BYTE nEnvDir = 0;
-    BYTE nThisDir = 0;
-    BYTE nFrmDir = 0;
+    sal_uInt8 nEnvDir = 0;
+    sal_uInt8 nThisDir = 0;
+    sal_uInt8 nFrmDir = 0;
     if ( rMulti.IsBidi() )
     {
         // these values are needed for the calculation of the x coordinate
@@ -1512,7 +1509,7 @@ void SwTxtPainter::PaintMultiPortion( const SwRect &rPaint,
         {
             if( rMulti.HasRotation() )
             {
-                const USHORT nAdjustment = ( pLay->Height() - pPor->Height() ) / 2 +
+                const sal_uInt16 nAdjustment = ( pLay->Height() - pPor->Height() ) / 2 +
                                             pPor->GetAscent();
                 if( rMulti.IsRevers() )
                     GetInfo().X( nOfst - nAdjustment );
@@ -1745,7 +1742,7 @@ void lcl_TruncateMultiPortion( SwMultiPortion& rMulti, SwTxtFormatInfo& rInf,
  * SwTxtFrm::_Format with multiple BuildPortions
  *---------------------------------------------------------------------------*/
 
-BOOL SwTxtFormatter::BuildMultiPortion( SwTxtFormatInfo &rInf,
+sal_Bool SwTxtFormatter::BuildMultiPortion( SwTxtFormatInfo &rInf,
     SwMultiPortion& rMulti )
 {
     SwTwips nMaxWidth = rInf.Width();
@@ -1869,27 +1866,21 @@ BOOL SwTxtFormatter::BuildMultiPortion( SwTxtFormatInfo &rInf,
 
     SwLinePortion *pNextFirst = NULL;
     SwLinePortion *pNextSecond = NULL;
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
 
     GETGRID( pFrm->FindPageFrm() )
     const sal_Bool bHasGrid = pGrid && GRID_LINES_CHARS == pGrid->GetGridType();
 
-    USHORT nGridWidth = 0;
-    USHORT nRubyHeight = 0;
     sal_Bool bRubyTop = sal_False;
 
     if ( bHasGrid )
-    {
-        nGridWidth = pGrid->GetBaseHeight();
-        nRubyHeight = pGrid->GetRubyHeight();
         bRubyTop = ! pGrid->GetRubyTextBelow();
-    }
 
     do
     {
         pCurr = &rMulti.GetRoot();
         nStart = nStartIdx;
-        bRet = FALSE;
+        bRet = sal_False;
         FormatReset( aInf );
         aInf.X( nTmpX );
         aInf.Width( KSHORT(nActWidth) );
@@ -2017,7 +2008,7 @@ BOOL SwTxtFormatter::BuildMultiPortion( SwTxtFormatInfo &rInf,
         }
         delete pNextFirst;
         pNextFirst = NULL;
-    } while ( TRUE );
+    } while ( sal_True );
 
     pMulti = pOldMulti;
 
@@ -2186,7 +2177,7 @@ BOOL SwTxtFormatter::BuildMultiPortion( SwTxtFormatInfo &rInf,
     return bRet;
 }
 
-/*-----------------08.11.00 09:29-------------------
+/*--------------------------------------------------
  * SwTxtFormatter::MakeRestPortion(..)
  * When a fieldportion at the end of line breaks and needs a following
  * fieldportion in the next line, then the "restportion" of the formatinfo
@@ -2296,6 +2287,9 @@ SwLinePortion* SwTxtFormatter::MakeRestPortion( const SwLineLayout* pLine,
         pCreate = GetInfo().GetMultiCreator( --nMultiPos, 0 );
     }
 
+    if (!pCreate)
+        return pRest;
+
     if( pRest || nMultiPos > nPosition || ( pHelpMulti->IsRuby() &&
         ((SwRubyPortion*)pHelpMulti)->GetRubyOffset() < STRING_LEN ) )
     {
@@ -2350,7 +2344,7 @@ SwLinePortion* SwTxtFormatter::MakeRestPortion( const SwLineLayout* pLine,
 
 
 
-/*-----------------23.10.00 10:47-------------------
+/*--------------------------------------------------
  * SwTxtCursorSave notes the start and current line of a SwTxtCursor,
  * sets them to the values for GetCrsrOfst inside a multiportion
  * and restores them in the destructor.
@@ -2359,7 +2353,7 @@ SwLinePortion* SwTxtFormatter::MakeRestPortion( const SwLineLayout* pLine,
 SwTxtCursorSave::SwTxtCursorSave( SwTxtCursor* pTxtCursor,
                                   SwMultiPortion* pMulti,
                                   SwTwips nY,
-                                  USHORT& nX,
+                                  sal_uInt16& nX,
                                   xub_StrLen nCurrStart,
                                   long nSpaceAdd )
 {
@@ -2378,7 +2372,7 @@ SwTxtCursorSave::SwTxtCursorSave( SwTxtCursor* pTxtCursor,
     {
         bSpaceChg = pMulti->ChgSpaceAdd( pTxtCursor->pCurr, nSpaceAdd );
 
-        USHORT nSpaceCnt;
+        sal_uInt16 nSpaceCnt;
         if ( pMulti->IsDouble() )
         {
             pTxtCursor->SetPropFont( 50 );
@@ -2393,7 +2387,7 @@ SwTxtCursorSave::SwTxtCursorSave( SwTxtCursor* pTxtCursor,
         }
 
         if( nSpaceAdd > 0 && !pMulti->HasTabulator() )
-            pTxtCursor->pCurr->Width( static_cast<USHORT>(nWidth + nSpaceAdd * nSpaceCnt / SPACING_PRECISION_FACTOR ) );
+            pTxtCursor->pCurr->Width( static_cast<sal_uInt16>(nWidth + nSpaceAdd * nSpaceCnt / SPACING_PRECISION_FACTOR ) );
 
         // For a BidiPortion we have to calculate the offset from the
         // end of the portion
