@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -70,9 +71,6 @@ TYPEINIT1_AUTOFACTORY(SwFmtAutoFmt, SfxPoolItem);
 /*************************************************************************
 |*
 |*    class SwFmtCharFmt
-|*    Beschreibung
-|*    Ersterstellung    JP 23.11.90
-|*    Letzte Aenderung  JP 09.08.94
 |*
 *************************************************************************/
 
@@ -100,7 +98,7 @@ SwFmtCharFmt::~SwFmtCharFmt() {}
 
 int SwFmtCharFmt::operator==( const SfxPoolItem& rAttr ) const
 {
-    ASSERT( SfxPoolItem::operator==( rAttr ), "keine gleichen Attribute" );
+    OSL_ENSURE( SfxPoolItem::operator==( rAttr ), "keine gleichen Attribute" );
     return GetCharFmt() == ((SwFmtCharFmt&)rAttr).GetCharFmt();
 }
 
@@ -114,43 +112,40 @@ SfxPoolItem* SwFmtCharFmt::Clone( SfxItemPool* ) const
 
 
 // weiterleiten an das TextAttribut
-void SwFmtCharFmt::Modify( SfxPoolItem* pOld, SfxPoolItem* pNew )
+void SwFmtCharFmt::Modify( const SfxPoolItem* pOld, const SfxPoolItem* pNew )
 {
     if( pTxtAttr )
-        pTxtAttr->Modify( pOld, pNew );
+        pTxtAttr->ModifyNotification( pOld, pNew );
 }
 
 
 
 // weiterleiten an das TextAttribut
-BOOL SwFmtCharFmt::GetInfo( SfxPoolItem& rInfo ) const
+sal_Bool SwFmtCharFmt::GetInfo( SfxPoolItem& rInfo ) const
 {
-    return pTxtAttr ? pTxtAttr->GetInfo( rInfo ) : FALSE;
+    return pTxtAttr ? pTxtAttr->GetInfo( rInfo ) : sal_False;
 }
-BOOL SwFmtCharFmt::QueryValue( uno::Any& rVal, BYTE ) const
+bool SwFmtCharFmt::QueryValue( uno::Any& rVal, sal_uInt8 ) const
 {
     String sCharFmtName;
     if(GetCharFmt())
         SwStyleNameMapper::FillProgName(GetCharFmt()->GetName(), sCharFmtName,  nsSwGetPoolIdFromName::GET_POOLID_CHRFMT, sal_True );
     rVal <<= OUString( sCharFmtName );
-    return TRUE;
+    return true;
 }
-BOOL SwFmtCharFmt::PutValue( const uno::Any& , BYTE   )
+bool SwFmtCharFmt::PutValue( const uno::Any& , sal_uInt8   )
 {
-    DBG_ERROR("Zeichenvorlage kann mit PutValue nicht gesetzt werden!");
-    return FALSE;
+    OSL_FAIL("Zeichenvorlage kann mit PutValue nicht gesetzt werden!");
+    return false;
 }
 
 /*************************************************************************
 |*
 |*    class SwFmtAutoFmt
-|*    Beschreibung
-|*    Ersterstellung    AMA 12.05.06
-|*    Letzte Aenderung  AMA 12.05.06
 |*
 *************************************************************************/
 
-SwFmtAutoFmt::SwFmtAutoFmt( USHORT nInitWhich )
+SwFmtAutoFmt::SwFmtAutoFmt( sal_uInt16 nInitWhich )
     : SfxPoolItem( nInitWhich )
 {
 }
@@ -166,7 +161,7 @@ SwFmtAutoFmt::~SwFmtAutoFmt()
 
 int SwFmtAutoFmt::operator==( const SfxPoolItem& rAttr ) const
 {
-    ASSERT( SfxPoolItem::operator==( rAttr ), "different attributes" );
+    OSL_ENSURE( SfxPoolItem::operator==( rAttr ), "different attributes" );
     return mpHandle == ((SwFmtAutoFmt&)rAttr).mpHandle;
 }
 
@@ -175,25 +170,22 @@ SfxPoolItem* SwFmtAutoFmt::Clone( SfxItemPool* ) const
     return new SwFmtAutoFmt( *this );
 }
 
-BOOL SwFmtAutoFmt::QueryValue( uno::Any& rVal, BYTE ) const
+bool SwFmtAutoFmt::QueryValue( uno::Any& rVal, sal_uInt8 ) const
 {
     String sCharFmtName = StylePool::nameOf( mpHandle );
     rVal <<= OUString( sCharFmtName );
-    return TRUE;
+    return true;
 }
 
-BOOL SwFmtAutoFmt::PutValue( const uno::Any& , BYTE )
+bool SwFmtAutoFmt::PutValue( const uno::Any& , sal_uInt8 )
 {
     //the format is not renameable via API
-    return FALSE;
+    return false;
 }
 
 /*************************************************************************
 |*
 |*    class SwFmtINetFmt
-|*    Beschreibung
-|*    Ersterstellung    AMA 02.08.96
-|*    Letzte Aenderung  AMA 02.08.96
 |*
 *************************************************************************/
 
@@ -241,8 +233,8 @@ SwFmtINetFmt::~SwFmtINetFmt()
 
 int SwFmtINetFmt::operator==( const SfxPoolItem& rAttr ) const
 {
-    ASSERT( SfxPoolItem::operator==( rAttr ), "keine gleichen Attribute" );
-    BOOL bRet = SfxPoolItem::operator==( (SfxPoolItem&) rAttr )
+    OSL_ENSURE( SfxPoolItem::operator==( rAttr ), "keine gleichen Attribute" );
+    sal_Bool bRet = SfxPoolItem::operator==( (SfxPoolItem&) rAttr )
                 && aURL == ((SwFmtINetFmt&)rAttr).aURL
                 && aName == ((SwFmtINetFmt&)rAttr).aName
                 && aTargetFrame == ((SwFmtINetFmt&)rAttr).aTargetFrame
@@ -252,7 +244,7 @@ int SwFmtINetFmt::operator==( const SfxPoolItem& rAttr ) const
                 && nVisitedId == ((SwFmtINetFmt&)rAttr).nVisitedId;
 
     if( !bRet )
-        return FALSE;
+        return sal_False;
 
     const SvxMacroTableDtor* pOther = ((SwFmtINetFmt&)rAttr).pMacroTbl;
     if( !pMacroTbl )
@@ -265,19 +257,19 @@ int SwFmtINetFmt::operator==( const SfxPoolItem& rAttr ) const
 
     // Anzahl unterschiedlich => auf jeden Fall ungleich
     if( rOwn.Count() != rOther.Count() )
-        return FALSE;
+        return sal_False;
 
     // einzeln vergleichen; wegen Performance ist die Reihenfolge wichtig
-    for( USHORT nNo = 0; nNo < rOwn.Count(); ++nNo )
+    for( sal_uInt16 nNo = 0; nNo < rOwn.Count(); ++nNo )
     {
         const SvxMacro *pOwnMac = rOwn.GetObject(nNo);
         const SvxMacro *pOtherMac = rOther.GetObject(nNo);
         if ( 	rOwn.GetKey(pOwnMac) != rOther.GetKey(pOtherMac)  ||
                 pOwnMac->GetLibName() != pOtherMac->GetLibName() ||
                 pOwnMac->GetMacName() != pOtherMac->GetMacName() )
-            return FALSE;
+            return sal_False;
     }
-    return TRUE;
+    return sal_True;
 }
 
 
@@ -304,7 +296,7 @@ void SwFmtINetFmt::SetMacroTbl( const SvxMacroTableDtor* pNewTbl )
 
 
 
-void SwFmtINetFmt::SetMacro( USHORT nEvent, const SvxMacro& rMacro )
+void SwFmtINetFmt::SetMacro( sal_uInt16 nEvent, const SvxMacro& rMacro )
 {
     if( !pMacroTbl )
         pMacroTbl = new SvxMacroTableDtor;
@@ -321,7 +313,7 @@ void SwFmtINetFmt::SetMacro( USHORT nEvent, const SvxMacro& rMacro )
 
 
 
-const SvxMacro* SwFmtINetFmt::GetMacro( USHORT nEvent ) const
+const SvxMacro* SwFmtINetFmt::GetMacro( sal_uInt16 nEvent ) const
 {
     const SvxMacro* pRet = 0;
     if( pMacroTbl && pMacroTbl->IsKeyValid( nEvent ) )
@@ -331,9 +323,9 @@ const SvxMacro* SwFmtINetFmt::GetMacro( USHORT nEvent ) const
 
 
 
-BOOL SwFmtINetFmt::QueryValue( uno::Any& rVal, BYTE nMemberId ) const
+bool SwFmtINetFmt::QueryValue( uno::Any& rVal, sal_uInt8 nMemberId ) const
 {
-    BOOL bRet = TRUE;
+    bool bRet = true;
     XubString sVal;
     nMemberId &= ~CONVERT_TWIPS;
     switch(nMemberId)
@@ -379,9 +371,9 @@ BOOL SwFmtINetFmt::QueryValue( uno::Any& rVal, BYTE nMemberId ) const
     rVal <<= OUString(sVal);
     return bRet;
 }
-BOOL SwFmtINetFmt::PutValue( const uno::Any& rVal, BYTE nMemberId  )
+bool SwFmtINetFmt::PutValue( const uno::Any& rVal, sal_uInt8 nMemberId  )
 {
-    BOOL bRet = TRUE;
+    bool bRet = true;
     nMemberId &= ~CONVERT_TWIPS;
 
     // all properties except HyperlinkEvents are of type string, hence
@@ -403,14 +395,14 @@ BOOL SwFmtINetFmt::PutValue( const uno::Any& rVal, BYTE nMemberId  )
         else
         {
             // wrong type!
-            bRet = FALSE;
+            bRet = false;
         }
     }
     else
     {
         // all string properties:
         if(rVal.getValueType() != ::getCppuType((rtl::OUString*)0))
-            return FALSE;
+            return false;
         XubString sVal = *(rtl::OUString*)rVal.getValue();
         switch(nMemberId)
         {
@@ -441,7 +433,7 @@ BOOL SwFmtINetFmt::PutValue( const uno::Any& rVal, BYTE nMemberId  )
             }
             break;
             default:
-                bRet = FALSE;
+                bRet = false;
         }
     }
     return bRet;
@@ -490,7 +482,7 @@ SwFmtRuby& SwFmtRuby::operator=( const SwFmtRuby& rAttr )
 
 int SwFmtRuby::operator==( const SfxPoolItem& rAttr ) const
 {
-    ASSERT( SfxPoolItem::operator==( rAttr ), "keine gleichen Attribute" );
+    OSL_ENSURE( SfxPoolItem::operator==( rAttr ), "keine gleichen Attribute" );
     return sRubyTxt == ((SwFmtRuby&)rAttr).sRubyTxt &&
            sCharFmtName == ((SwFmtRuby&)rAttr).sCharFmtName &&
            nCharFmtId == ((SwFmtRuby&)rAttr).nCharFmtId &&
@@ -503,10 +495,10 @@ SfxPoolItem* SwFmtRuby::Clone( SfxItemPool* ) const
     return new SwFmtRuby( *this );
 }
 
-BOOL SwFmtRuby::QueryValue( uno::Any& rVal,
-                            BYTE nMemberId ) const
+bool SwFmtRuby::QueryValue( uno::Any& rVal,
+                            sal_uInt8 nMemberId ) const
 {
-    BOOL bRet = TRUE;
+    bool bRet = true;
     nMemberId &= ~CONVERT_TWIPS;
     switch( nMemberId )
     {
@@ -526,14 +518,14 @@ BOOL SwFmtRuby::QueryValue( uno::Any& rVal,
         }
         break;
         default:
-            bRet = FALSE;
+            bRet = false;
     }
     return bRet;
 }
-BOOL SwFmtRuby::PutValue( const uno::Any& rVal,
-                            BYTE nMemberId  )
+bool SwFmtRuby::PutValue( const uno::Any& rVal,
+                            sal_uInt8 nMemberId  )
 {
-    BOOL bRet = TRUE;
+    bool bRet = true;
     nMemberId &= ~CONVERT_TWIPS;
     switch( nMemberId )
     {
@@ -551,7 +543,7 @@ BOOL SwFmtRuby::PutValue( const uno::Any& rVal,
             if(nSet >= 0 && nSet <= text::RubyAdjust_INDENT_BLOCK)
                 nAdjustment = nSet;
             else
-                bRet = sal_False;
+                bRet = false;
         }
         break;
         case MID_RUBY_ABOVE:
@@ -573,7 +565,7 @@ BOOL SwFmtRuby::PutValue( const uno::Any& rVal,
         }
         break;
         default:
-            bRet = FALSE;
+            bRet = false;
     }
     return bRet;
 }
@@ -583,29 +575,29 @@ BOOL SwFmtRuby::PutValue( const uno::Any& rVal,
  class SwFmtMeta
  ************************************************************************/
 
-SwFmtMeta * SwFmtMeta::CreatePoolDefault(const USHORT i_nWhich)
+SwFmtMeta * SwFmtMeta::CreatePoolDefault(const sal_uInt16 i_nWhich)
 {
     return new SwFmtMeta(i_nWhich);
 }
 
-SwFmtMeta::SwFmtMeta(const USHORT i_nWhich)
+SwFmtMeta::SwFmtMeta(const sal_uInt16 i_nWhich)
     : SfxPoolItem( i_nWhich )
     , m_pMeta()
     , m_pTxtAttr( 0 )
 {
-    ASSERT((RES_TXTATR_META == i_nWhich) || (RES_TXTATR_METAFIELD == i_nWhich),
+   OSL_ENSURE((RES_TXTATR_META == i_nWhich) || (RES_TXTATR_METAFIELD == i_nWhich),
             "ERROR: SwFmtMeta: invalid which id!");
 }
 
 SwFmtMeta::SwFmtMeta( ::boost::shared_ptr< ::sw::Meta > const & i_pMeta,
-                        const USHORT i_nWhich )
+                        const sal_uInt16 i_nWhich )
     : SfxPoolItem( i_nWhich )
     , m_pMeta( i_pMeta )
     , m_pTxtAttr( 0 )
 {
-    ASSERT((RES_TXTATR_META == i_nWhich) || (RES_TXTATR_METAFIELD == i_nWhich),
+   OSL_ENSURE((RES_TXTATR_META == i_nWhich) || (RES_TXTATR_METAFIELD == i_nWhich),
             "ERROR: SwFmtMeta: invalid which id!");
-    ASSERT(m_pMeta, "SwFmtMeta: no Meta ?");
+    OSL_ENSURE(m_pMeta, "SwFmtMeta: no Meta ?");
     // DO NOT call m_pMeta->SetFmtMeta(this) here; only from SetTxtAttr!
 }
 
@@ -613,13 +605,14 @@ SwFmtMeta::~SwFmtMeta()
 {
     if (m_pMeta && (m_pMeta->GetFmtMeta() == this))
     {
+        NotifyChangeTxtNode(0);
         m_pMeta->SetFmtMeta(0);
     }
 }
 
 int SwFmtMeta::operator==( const SfxPoolItem & i_rOther ) const
 {
-    ASSERT( SfxPoolItem::operator==( i_rOther ), "i just copied this assert" );
+    OSL_ENSURE( SfxPoolItem::operator==( i_rOther ), "i just copied this assert" );
     return SfxPoolItem::operator==( i_rOther )
         && (m_pMeta == static_cast<SwFmtMeta const &>( i_rOther ).m_pMeta);
 }
@@ -633,16 +626,24 @@ SfxPoolItem * SwFmtMeta::Clone( SfxItemPool * /*pPool*/ ) const
 
 void SwFmtMeta::SetTxtAttr(SwTxtMeta * const i_pTxtAttr)
 {
-    ASSERT(!(m_pTxtAttr && i_pTxtAttr),
+    OSL_ENSURE(!(m_pTxtAttr && i_pTxtAttr),
         "SwFmtMeta::SetTxtAttr: already has text attribute?");
-    ASSERT(  m_pTxtAttr || i_pTxtAttr ,
+    OSL_ENSURE(  m_pTxtAttr || i_pTxtAttr ,
         "SwFmtMeta::SetTxtAttr: no attribute to remove?");
     m_pTxtAttr = i_pTxtAttr;
-    ASSERT(m_pMeta, "inserted SwFmtMeta has no sw::Meta?");
+    OSL_ENSURE(m_pMeta, "inserted SwFmtMeta has no sw::Meta?");
     // the sw::Meta must be able to find the current text attribute!
-    if (i_pTxtAttr && m_pMeta)
+    if (m_pMeta)
     {
-        m_pMeta->SetFmtMeta(this);
+        if (i_pTxtAttr)
+        {
+            m_pMeta->SetFmtMeta(this);
+        }
+        else if (m_pMeta->GetFmtMeta() == this)
+        {   // text attribute gone => de-register from text node!
+            NotifyChangeTxtNode(0);
+            m_pMeta->SetFmtMeta(0);
+        }
     }
 }
 
@@ -650,36 +651,22 @@ void SwFmtMeta::NotifyChangeTxtNode(SwTxtNode *const pTxtNode)
 {
     // N.B.: do not reset m_pTxtAttr here: see call in nodes.cxx,
     // where the hint is not deleted!
-    ASSERT(m_pMeta, "NotifyRemoval: no meta ?");
-    if (m_pMeta)
-    {
-        if (!pTxtNode)
-        {
-            SwPtrMsgPoolItem aMsgHint( RES_REMOVE_UNO_OBJECT,
-                &static_cast<SwModify&>(*m_pMeta) ); // cast to base class!
-            m_pMeta->Modify(&aMsgHint, &aMsgHint);
-        }
-        else
-        {   // do not call Modify, that would call SwXMeta::Modify!
-            m_pMeta->NotifyChangeTxtNode();
-        }
+    OSL_ENSURE(m_pMeta, "SwFmtMeta::NotifyChangeTxtNode: no Meta?");
+    if (m_pMeta && (m_pMeta->GetFmtMeta() == this))
+    {   // do not call Modify, that would call SwXMeta::Modify!
+        m_pMeta->NotifyChangeTxtNode(pTxtNode);
     }
 }
 
-// UGLY: this really awful method fixes up an inconsistent state,
-// and if it is not called when copying, total chaos will undoubtedly ensue
-void SwFmtMeta::DoCopy(SwFmtMeta & rOriginalMeta)
+// this SwFmtMeta has been cloned and points at the same sw::Meta as the source
+// this method copies the sw::Meta
+void SwFmtMeta::DoCopy(::sw::MetaFieldManager & i_rTargetDocManager,
+        SwTxtNode & i_rTargetTxtNode)
 {
-    ASSERT(m_pMeta, "DoCopy called for SwFmtMeta with no sw::Meta?");
+    OSL_ENSURE(m_pMeta, "DoCopy called for SwFmtMeta with no sw::Meta?");
     if (m_pMeta)
     {
         const ::boost::shared_ptr< ::sw::Meta> pOriginal( m_pMeta );
-        // UGLY: original sw::Meta now points at _this_ due to being already
-        // inserted via MakeTxtAttr! so fix it up to point at the original item
-        // (maybe would be better to tell MakeTxtAttr that it creates a copy?)
-        pOriginal->SetFmtMeta(&rOriginalMeta);
-        // force pOriginal to register in original text node!
-        pOriginal->NotifyChangeTxtNode();
         if (RES_TXTATR_META == Which())
         {
             m_pMeta.reset( new ::sw::Meta(this) );
@@ -688,14 +675,13 @@ void SwFmtMeta::DoCopy(SwFmtMeta & rOriginalMeta)
         {
             ::sw::MetaField *const pMetaField(
                 static_cast< ::sw::MetaField* >(pOriginal.get()));
-            SwDoc * const pTargetDoc( GetTxtAttr()->GetTxtNode()->GetDoc() );
-            m_pMeta = pTargetDoc->GetMetaFieldManager().makeMetaField( this,
+            m_pMeta = i_rTargetDocManager.makeMetaField( this,
                 pMetaField->m_nNumberFormat, pMetaField->IsFixedLanguage() );
         }
+        // Meta must have a text node before calling RegisterAsCopyOf
+        m_pMeta->NotifyChangeTxtNode(& i_rTargetTxtNode);
         // this cannot be done in Clone: a Clone is not necessarily a copy!
         m_pMeta->RegisterAsCopyOf(*pOriginal);
-        // force copy Meta to register in target text node!
-        m_pMeta->NotifyChangeTxtNode();
     }
 }
 
@@ -724,35 +710,44 @@ SwTxtMeta * Meta::GetTxtAttr() const
 
 SwTxtNode * Meta::GetTxtNode() const
 {
-    SwTxtMeta * const pTxtAttr( GetTxtAttr() );
-    return (pTxtAttr) ? pTxtAttr->GetTxtNode() : 0;
+    return m_pTxtNode;
 }
 
-void Meta::NotifyChangeTxtNode()
+void Meta::NotifyChangeTxtNodeImpl()
 {
-    SwTxtNode * const pTxtNode( GetTxtNode() );
-    if (pTxtNode && (GetRegisteredIn() != pTxtNode))
+    if (m_pTxtNode && (GetRegisteredIn() != m_pTxtNode))
     {
-        pTxtNode->Add(this);
+        m_pTxtNode->Add(this);
     }
-    else if (!pTxtNode && GetRegisteredIn())
+    else if (!m_pTxtNode && GetRegisteredIn())
     {
-        const_cast<SwModify *>(GetRegisteredIn())->Remove(this);
+        GetRegisteredInNonConst()->Remove(this);
+    }
+}
+
+void Meta::NotifyChangeTxtNode(SwTxtNode *const pTxtNode)
+{
+    m_pTxtNode = pTxtNode;
+    NotifyChangeTxtNodeImpl();
+    if (!pTxtNode) // text node gone? invalidate UNO object!
+    {
+        SwPtrMsgPoolItem aMsgHint( RES_REMOVE_UNO_OBJECT,
+            &static_cast<SwModify&>(*this) ); // cast to base class!
+        this->Modify(&aMsgHint, &aMsgHint);
     }
 }
 
 // SwClient
-void Meta::Modify( SfxPoolItem *pOld, SfxPoolItem *pNew )
+void Meta::Modify( const SfxPoolItem *pOld, const SfxPoolItem *pNew )
 {
-    NotifyChangeTxtNode();
-    SwModify::Modify(pOld, pNew);
+    NotifyClients(pOld, pNew);
     if (pOld && (RES_REMOVE_UNO_OBJECT == pOld->Which()))
     {   // invalidate cached uno object
         SetXMeta(uno::Reference<rdf::XMetadatable>(0));
     }
 }
 
-// sw::Metadatable
+// sfx2::Metadatable
 ::sfx2::IXmlIdRegistry& Meta::GetRegistry()
 {
     SwTxtNode * const pTxtNode( GetTxtNode() );
@@ -820,7 +815,7 @@ void MetaField::GetPrefixAndSuffix(
             getPrefixAndSuffix(xModel, xMetaField, o_pPrefix, o_pSuffix);
         }
     } catch (uno::Exception) {
-        OSL_ENSURE(false, "exception?");
+        OSL_FAIL("exception?");
     }
 }
 
@@ -906,3 +901,5 @@ MetaFieldManager::getMetaFields()
 
 } // namespace sw
 
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
