@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -27,8 +28,6 @@
 
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil -*- */
-
 
 #include <tools/stream.hxx>
 #include <hintids.hxx>
@@ -48,12 +47,12 @@
 #include <pagedesc.hxx>
 #include <breakit.hxx>
 #include <swerror.h>
-#ifndef _STATSTR_HRC
 #include <statstr.hrc>          // ResId fuer Statusleiste
-#endif
 #include <mdiexp.hxx>           // ...Percent()
 #include <poolfmt.hxx>
 
+#include "vcl/metric.hxx"
+
 #define ASC_BUFFLEN 4096
 
 class SwASCIIParser
@@ -65,10 +64,10 @@ class SwASCIIParser
     const SwAsciiOptions& rOpt;
     SfxItemSet* pItemSet;
     long nFileSize;
-    USHORT nScript;
+    sal_uInt16 nScript;
     bool bNewDoc;
 
-    ULONG ReadChars();
+    sal_uLong ReadChars();
     void InsertText( const String& rStr );
 
 public:
@@ -76,28 +75,27 @@ public:
                             int bReadNewDoc, const SwAsciiOptions& rOpts );
     ~SwASCIIParser();
 
-    ULONG CallParser();
+    sal_uLong CallParser();
 };
 
 
 // Aufruf fuer die allg. Reader-Schnittstelle
-ULONG AsciiReader::Read( SwDoc &rDoc, const String&, SwPaM &rPam, const String & )
+sal_uLong AsciiReader::Read( SwDoc &rDoc, const String&, SwPaM &rPam, const String & )
 {
     if( !pStrm )
     {
-        ASSERT( !this, "ASCII-Read ohne Stream" );
+        OSL_ENSURE( !this, "ASCII-Read ohne Stream" );
         return ERR_SWG_READ_ERROR;
     }
 
-    //JP 18.01.96: Alle Ueberschriften sind normalerweise ohne
-    //              Kapitelnummer. Darum hier explizit abschalten
-    //              weil das Default jetzt wieder auf AN ist.
+    // Alle Ueberschriften sind normalerweise ohne Kapitelnummer.
+    // Darum hier explizit abschalten weil das Default jetzt wieder auf AN ist.
     if( !bInsertMode )
         Reader::SetNoOutlineNum( rDoc );
 
     SwASCIIParser* pParser = new SwASCIIParser( &rDoc, rPam, *pStrm,
                                         !bInsertMode, aOpt.GetASCIIOpts() );
-    ULONG nRet = pParser->CallParser();
+    sal_uLong nRet = pParser->CallParser();
 
     delete pParser;
     // after Read reset the options
@@ -107,7 +105,8 @@ ULONG AsciiReader::Read( SwDoc &rDoc, const String&, SwPaM &rPam, const String &
 
 SwASCIIParser::SwASCIIParser(SwDoc* pD, const SwPaM& rCrsr, SvStream& rIn,
     int bReadNewDoc, const SwAsciiOptions& rOpts)
-    : pDoc(pD), rInput(rIn), rOpt(rOpts), nScript(0), bNewDoc(bReadNewDoc)
+    : pDoc(pD), rInput(rIn), rOpt(rOpts), nFileSize(0), nScript(0)
+    , bNewDoc(bReadNewDoc)
 {
     pPam = new SwPaM( *rCrsr.GetPoint() );
     pArr = new sal_Char [ ASC_BUFFLEN + 2 ];
@@ -129,24 +128,14 @@ SwASCIIParser::SwASCIIParser(SwDoc* pD, const SwPaM& rCrsr, SvStream& rIn,
     }
     if( rOpt.GetFontName().Len() )
     {
-        bool bDelete = false;
-        const SfxFont* pFnt = 0;
+        Font aTextFont( rOpt.GetFontName(), Size( 0, 10 ) );
         if( pDoc->getPrinter( false ) )
-            pFnt = pDoc->getPrinter( false )->GetFontByName( rOpt.GetFontName() );
-
-        if( !pFnt )
-        {
-            pFnt = new SfxFont( FAMILY_DONTKNOW, rOpt.GetFontName() );
-            bDelete = true;
-        }
-        SvxFontItem aFont( pFnt->GetFamily(), pFnt->GetName(),
-                        aEmptyStr, pFnt->GetPitch(), pFnt->GetCharSet(), RES_CHRATR_FONT );
+            aTextFont = pDoc->getPrinter( false )->GetFontMetric( aTextFont );
+        SvxFontItem aFont( aTextFont.GetFamily(), aTextFont.GetName(),
+                           aEmptyStr, aTextFont.GetPitch(), aTextFont.GetCharSet(), RES_CHRATR_FONT );
         pItemSet->Put( aFont );
         pItemSet->Put( aFont, RES_CHRATR_CJK_FONT );
         pItemSet->Put( aFont, RES_CHRATR_CTL_FONT );
-
-        if( bDelete )
-            delete (SfxFont*)pFnt;
     }
 }
 
@@ -159,7 +148,7 @@ SwASCIIParser::~SwASCIIParser()
 
 
 // Aufruf des Parsers
-ULONG SwASCIIParser::CallParser()
+sal_uLong SwASCIIParser::CallParser()
 {
     rInput.Seek(STREAM_SEEK_TO_END);
     rInput.ResetError();
@@ -190,7 +179,7 @@ ULONG SwASCIIParser::CallParser()
             pDoc->SetTxtFmtColl(*pPam, pColl);
     }
 
-    ULONG nError = ReadChars();
+    sal_uLong nError = ReadChars();
 
     if( pItemSet )
     {
@@ -257,7 +246,7 @@ ULONG SwASCIIParser::CallParser()
                                     pInsPam->GetCntntNode(), nSttCntnt );
 
                 // !!!!!
-                ASSERT( !this, "Have to change - hard attr. to para. style" );
+                OSL_ENSURE( !this, "Have to change - hard attr. to para. style" );
                 pDoc->InsertItemSet( *pInsPam, *pItemSet, 0 );
             }
         }
@@ -271,7 +260,7 @@ ULONG SwASCIIParser::CallParser()
     return nError;
 }
 
-ULONG SwASCIIParser::ReadChars()
+sal_uLong SwASCIIParser::ReadChars()
 {
     sal_Unicode *pStt = 0, *pEnd = 0, *pLastStt = 0;
     long nReadCnt = 0, nLineLen = 0;
@@ -286,11 +275,11 @@ ULONG SwASCIIParser::ReadChars()
         aEmpty.GetLanguage() == rOpt.GetLanguage() &&
         aEmpty.GetParaFlags() == rOpt.GetParaFlags())
     {
-        ULONG nLen, nOrig;
+        sal_uLong nLen, nOrig;
         nOrig = nLen = rInput.Read(pArr, ASC_BUFFLEN);
         CharSet eCharSet;
         bool bRet = SwIoSystem::IsDetectableText(pArr, nLen, &eCharSet, &bSwapUnicode);
-        ASSERT(bRet, "Autodetect of text import without nag dialog must "
+        OSL_ENSURE(bRet, "Autodetect of text import without nag dialog must "
             "have failed");
         if (bRet && eCharSet != RTL_TEXTENCODING_DONTKNOW)
         {
@@ -310,7 +299,7 @@ ULONG SwASCIIParser::ReadChars()
         if( currentCharSet == RTL_TEXTENCODING_DONTKNOW )
                 currentCharSet = RTL_TEXTENCODING_ASCII_US;
         hConverter = rtl_createTextToUnicodeConverter( currentCharSet );
-        ASSERT( hConverter, "no string convert avaiable" );
+        OSL_ENSURE( hConverter, "no string convert avaiable" );
         if (!hConverter)
             return ERROR_SW_READ_BASE;
         bSwapUnicode = false;
@@ -318,12 +307,12 @@ ULONG SwASCIIParser::ReadChars()
     }
     else if (pUseMe != &aEmpty)  //Already successfully figured out type
     {
-        rInput.StartReadingUnicodeText();
+        rInput.StartReadingUnicodeText( currentCharSet );
         bSwapUnicode = rInput.IsEndianSwap();
     }
 
     String sWork;
-    ULONG nArrOffset = 0;
+    sal_uLong nArrOffset = 0;
 
     do {
         if( pStt >= pEnd )
@@ -332,14 +321,13 @@ ULONG SwASCIIParser::ReadChars()
                 InsertText( String( pLastStt ));
 
             // lese einen neuen Block ein
-            ULONG lGCount;
+            sal_uLong lGCount;
             if( SVSTREAM_OK != rInput.GetError() || 0 == (lGCount =
                         rInput.Read( pArr + nArrOffset,
                                      ASC_BUFFLEN - nArrOffset )))
                 break;		// aus der WHILE-Schleife heraus
 
             /*
-            #98380#
             If there was some unconverted bytes on the last cycle then they
             were put at the beginning of the array, so total bytes available
             to convert this cycle includes them. If we found 0 following bytes
@@ -378,7 +366,7 @@ ULONG SwASCIIParser::ReadChars()
                 if( bSwapUnicode )
                 {
                     sal_Char* pF = pArr, *pN = pArr + 1;
-                    for( ULONG n = 0; n < lGCount; n += 2, pF += 2, pN += 2 )
+                    for( sal_uLong n = 0; n < lGCount; n += 2, pF += 2, pN += 2 )
                     {
                         sal_Char c = *pF;
                         *pF = *pN;
@@ -398,7 +386,7 @@ ULONG SwASCIIParser::ReadChars()
                     pLastStt = ++pStt;
                 cLastCR = 0;
                 nLineLen = 0;
-                // JP 03.04.96: das letze am Ende nehmen wir nicht
+                // das letze am Ende nehmen wir nicht
                 if( !rInput.IsEof() || !(pEnd == pStt ||
                     ( !*pEnd && pEnd == pStt+1 ) ) )
                     pDoc->SplitNode( *pPam->GetPoint(), false );
@@ -408,12 +396,6 @@ ULONG SwASCIIParser::ReadChars()
         bool bIns = true, bSplitNode = false;
         switch( *pStt )
         {
-//JP 12.11.2001: task 94636 - don't ignore all behind the zero character,
-//							  change it to the default "control character"
-//		case 0:
-//					pEnd = pStt;
-//					bIns = false ;
-//					break;
 
         case 0x0a:	if( LINEEND_LF == pUseMe->GetParaFlags() )
                     {
@@ -421,7 +403,7 @@ ULONG SwASCIIParser::ReadChars()
                         *pStt = 0;
                         ++pStt;
 
-                        // JP 03.04.96: das letze am Ende nehmen wir nicht
+                        // das letze am Ende nehmen wir nicht
                         if( !rInput.IsEof() || pEnd != pStt )
                             bSplitNode = true;
                     }
@@ -447,7 +429,7 @@ ULONG SwASCIIParser::ReadChars()
                         else
                             bChkSplit = true;
 
-                            // JP 03.04.96: das letze am Ende nehmen wir nicht
+                            // das letze am Ende nehmen wir nicht
                         if( bChkSplit && ( !rInput.IsEof() || pEnd != pStt ))
                             bSplitNode = true;
                     }
@@ -459,8 +441,6 @@ ULONG SwASCIIParser::ReadChars()
                         *pStt++ = 0;
                         if( nLineLen )
                         {
-                            // Change to charset system!!!!
-                            //rOpt.GetCharSet();
                             InsertText( String( pLastStt ));
                         }
                         pDoc->SplitNode( *pPam->GetPoint(), false );
@@ -532,4 +512,4 @@ void SwASCIIParser::InsertText( const String& rStr )
         nScript |= pBreakIt->GetAllScriptsOfText( rStr );
 }
 
-/* vi:set tabstop=4 shiftwidth=4 expandtab: */
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
