@@ -92,29 +92,29 @@ static RTF_FLD_TYPES _WhichFld( String& rName, String& rNext )
 {
     // Strings sind PascalStrings; Laenge steht an 1. Stellen, dadurch wird
     // sich der Aufruf von strlen erspart!!!
-    sal_Char __READONLY_DATA sTOC[]=		"\x03""toc";
-    sal_Char __READONLY_DATA sIMPORT[]= 	"\x06""import";
-    sal_Char __READONLY_DATA sINDEX[]=		"\x05""index";
-    sal_Char __READONLY_DATA sSYMBOL[]= 	"\x06""symbol";
-    sal_Char __READONLY_DATA sPAGE[]=		"\x04""page";
-    sal_Char __READONLY_DATA sNUMPAGES[]=   "\x08""numpages";
-    sal_Char __READONLY_DATA sDATE[]=		"\x04""date";
-    sal_Char __READONLY_DATA sTIME[]=		"\x04""time";
-    sal_Char __READONLY_DATA sDATA[]=		"\x04""data";
-    sal_Char __READONLY_DATA sMERGEFLD[]=	"\x0A""mergefield";
-    sal_Char __READONLY_DATA sIMPORT2[]=	"\x0E""includepicture";
-    sal_Char __READONLY_DATA sHYPERLINK[]=	"\x09""hyperlink";
-    sal_Char __READONLY_DATA sREF[]=		"\x03""ref";
-    sal_Char __READONLY_DATA sPAGEREF[]=	"\x07""pageref";
-    sal_Char __READONLY_DATA sEQ[]=			"\x02""eq";
-    sal_Char __READONLY_DATA sINCLUDETEXT[]="\x0B""includetext";
+    sal_Char const sTOC[]=		"\x03""toc";
+    sal_Char const sIMPORT[]= 	"\x06""import";
+    sal_Char const sINDEX[]=		"\x05""index";
+    sal_Char const sSYMBOL[]= 	"\x06""symbol";
+    sal_Char const sPAGE[]=		"\x04""page";
+    sal_Char const sNUMPAGES[]=   "\x08""numpages";
+    sal_Char const sDATE[]=		"\x04""date";
+    sal_Char const sTIME[]=		"\x04""time";
+    sal_Char const sDATA[]=		"\x04""data";
+    sal_Char const sMERGEFLD[]=	"\x0A""mergefield";
+    sal_Char const sIMPORT2[]=	"\x0E""includepicture";
+    sal_Char const sHYPERLINK[]=	"\x09""hyperlink";
+    sal_Char const sREF[]=		"\x03""ref";
+    sal_Char const sPAGEREF[]=	"\x07""pageref";
+    sal_Char const sEQ[]=			"\x02""eq";
+    sal_Char const sINCLUDETEXT[]="\x0B""includetext";
 
     struct _Dummy_RTF_FLD_TYPES
     {
         RTF_FLD_TYPES eFldType;
         const sal_Char* pFldNm;
     };
-    __READONLY_DATA _Dummy_RTF_FLD_TYPES aFldNmArr[RTFFLD_INCLUDETEXT + 1] = {
+    const _Dummy_RTF_FLD_TYPES aFldNmArr[RTFFLD_INCLUDETEXT + 1] = {
             {RTFFLD_TOC,         sTOC},
             {RTFFLD_IMPORT,      sIMPORT},
             {RTFFLD_INDEX,       sINDEX},
@@ -155,7 +155,6 @@ static RTF_FLD_TYPES _WhichFld( String& rName, String& rNext )
             ( !nFndPos || !isalpha(sNm.GetChar( static_cast< xub_StrLen >(nFndPos-1) )) ) &&
             ( nFndPos+nLen == sNm.Len() || !isalpha(sNm.GetChar( static_cast< xub_StrLen >(nFndPos+nLen) ) ) ) )
         {
-//			rName = sNm.Copy( nFndPos, nLen );
             rName = rName.Copy( nFndPos, static_cast< xub_StrLen >(nLen) );
             nFndPos += nTokenStt + static_cast< xub_StrLen >(nLen);
             while( rNext.GetChar( nFndPos ) == ' ' )    ++nFndPos;
@@ -167,7 +166,7 @@ static RTF_FLD_TYPES _WhichFld( String& rName, String& rNext )
     return RTFFLD_UNKNOWN;		// nichts gefunden.
 }
 
-static USHORT CheckNumberFmtStr( const String& rNStr )
+static sal_uInt16 CheckNumberFmtStr( const String& rNStr )
 {
     const static sal_Char* aNumberTypeTab[] =
     {
@@ -184,12 +183,12 @@ static USHORT CheckNumberFmtStr( const String& rNStr )
     OSL_ENSURE(sizeof(aNumberTypeTab) / sizeof(sal_Char *)
            >= SVX_NUM_PAGEDESC - SVX_NUM_CHARS_UPPER_LETTER, "impossible");
 
-    for (USHORT n = SVX_NUM_CHARS_UPPER_LETTER;  n <= SVX_NUM_PAGEDESC; ++n)
+    for (sal_uInt16 n = SVX_NUM_CHARS_UPPER_LETTER;  n <= SVX_NUM_PAGEDESC; ++n)
     {
         const sal_Char* pCmp = aNumberTypeTab[n - SVX_NUM_CHARS_UPPER_LETTER];
         int nLen = *pCmp++;
         if( rNStr.EqualsAscii( pCmp, 0, static_cast< xub_StrLen >(nLen) ))
-            return static_cast< USHORT >(2 <= n ? n : (n + SVX_NUM_CHARS_UPPER_LETTER_N));
+            return static_cast< sal_uInt16 >(2 <= n ? n : (n + SVX_NUM_CHARS_UPPER_LETTER_N));
     }
     return SVX_NUM_PAGEDESC;		// default-Wert
 }
@@ -202,7 +201,7 @@ public:
     RtfFieldSwitch( const String& rParam );
     sal_Unicode GetSwitch( String& rParam );
 
-    BOOL IsAtEnd() const 				{ return nCurPos >= sParam.Len(); }
+    sal_Bool IsAtEnd() const 				{ return nCurPos >= sParam.Len(); }
     xub_StrLen GetCurPos() const 		{ return nCurPos; }
     void Erase( xub_StrLen nEndPos ) 	{ sParam.Erase( 0, nEndPos ); }
     void Insert( const String& rIns ) 	{ sParam.Insert( rIns, 0 ); }
@@ -233,7 +232,7 @@ sal_Unicode RtfFieldSwitch::GetSwitch( String& rParam )
 
     // dann alles in Hochkommatas oder bis zum naechsten // als
     // Param returnen
-    USHORT nOffset;
+    sal_uInt16 nOffset;
     if( '"' != c && '\'' != c )
         c = '\\', nOffset = 0;
     else
@@ -291,7 +290,7 @@ void lcl_ScanEquationField( const String& rStr, RTF_EquationData& rData,
         else if( 1 < nSubSupFlag )
             nSubSupFlag = 0;
 
-        BOOL bCheckBracket = FALSE;
+        sal_Bool bCheckBracket = sal_False;
         switch( cKey )
         {
         case 0:
@@ -325,7 +324,7 @@ void lcl_ScanEquationField( const String& rStr, RTF_EquationData& rData,
                 2 == nSubSupFlag )
             {
                 rData.nUp = sParam.Copy( 1 ).ToInt32();
-                bCheckBracket = TRUE;
+                bCheckBracket = sal_True;
             }
             break;
 
@@ -334,12 +333,12 @@ void lcl_ScanEquationField( const String& rStr, RTF_EquationData& rData,
                 2 == nSubSupFlag )
             {
                 rData.nDown = sParam.Copy( 1 ).ToInt32();
-                bCheckBracket = TRUE;
+                bCheckBracket = sal_True;
             }
             break;
 
         default:
-            bCheckBracket = TRUE;
+            bCheckBracket = sal_True;
             cKey = 0;
             break;
         }
@@ -407,9 +406,6 @@ int SwRTFParser::MakeFieldInst( String& rFieldStr )
         break;
     case RTFFLD_IMPORT:
         {
-//JP 11.03.96: vertraegt sich nicht so ganz mit Internet!
-//			  if( STRING_NOTFOUND != ( nPos = aSaveStr.Search( '.' )))
-//				  aSaveStr.Erase( nPos+4 );
 
             aSaveStr.EraseLeadingAndTrailingChars();
             if( aSaveStr.Len() )
@@ -425,7 +421,7 @@ int SwRTFParser::MakeFieldInst( String& rFieldStr )
                     INetURLObject(GetBaseURL()), aSaveStr,
                     URIHelper::GetMaybeFileHdl() );
             }
-//			SkipGroup();		// ueberlese den Rest
+
         }
         break;
 
@@ -486,15 +482,15 @@ int SwRTFParser::MakeFieldInst( String& rFieldStr )
                 aSaveStr.SearchAndReplaceAscii( "AM", aEmptyStr );
                 aSaveStr.SearchAndReplaceAscii( "PM", aEmptyStr );
 
-                // #117892# M.M. Put the word date and time formatter stuff in a common area
+                // Put the word date and time formatter stuff in a common area
                 // and get the rtf filter to use it
                 SwField *pFld = 0;
                 short nNumFmtType = NUMBERFORMAT_UNDEFINED;
-                ULONG nFmtIdx = NUMBERFORMAT_UNDEFINED;
+                sal_uLong nFmtIdx = NUMBERFORMAT_UNDEFINED;
 
-                USHORT rLang(0);
+                sal_uInt16 rLang(0);
                 RES_CHRATR eLang = maPageDefaults.mbRTLdoc ? RES_CHRATR_CTL_LANGUAGE : RES_CHRATR_LANGUAGE;
-                const SvxLanguageItem *pLang = (SvxLanguageItem*)&pDoc->GetAttrPool().GetDefaultItem( static_cast< USHORT >(eLang) );
+                const SvxLanguageItem *pLang = (SvxLanguageItem*)&pDoc->GetAttrPool().GetDefaultItem( static_cast< sal_uInt16 >(eLang) );
                 rLang = pLang ? pLang->GetValue() : LANGUAGE_ENGLISH_US;
 
                 SvNumberFormatter* pFormatter = pDoc->GetNumberFormatter();
@@ -502,7 +498,7 @@ int SwRTFParser::MakeFieldInst( String& rFieldStr )
 
                 if( pFormatter )
                 {
-                    nFmtIdx = sw::ms::MSDateTimeFormatToSwFormat(aSaveStr, pFormatter, rLang, bHijri);
+                    nFmtIdx = sw::ms::MSDateTimeFormatToSwFormat(aSaveStr, pFormatter, rLang, bHijri, rLang);
                     if (nFmtIdx)
                         nNumFmtType = pFormatter->GetType(nFmtIdx);
                 }
@@ -535,7 +531,7 @@ int SwRTFParser::MakeFieldInst( String& rFieldStr )
             // werden:
             //	\\data -> Datenbank-Name als Field
             //	DATA -> Datenbank-Info
-            BOOL bField = rFieldStr.GetChar( 0 ) != 'D';
+            sal_Bool bField = rFieldStr.GetChar( 0 ) != 'D';
 
             // nur der Name interressiert
             if( STRING_NOTFOUND != (nPos = aSaveStr.Search( '.' )) )
@@ -571,11 +567,11 @@ int SwRTFParser::MakeFieldInst( String& rFieldStr )
             // loesche fuehrende Blanks
             if( IsNewGroup() )
                 GetAttrSet();
-            SetNewGroup( TRUE );
+            SetNewGroup( sal_True );
 
             SfxItemSet& rSet = GetAttrSet();
 
-            BOOL bCharIns = FALSE;
+            sal_Bool bCharIns = sal_False;
             RtfFieldSwitch aRFS( aSaveStr );
             while( !aRFS.IsAtEnd() )
             {
@@ -591,7 +587,7 @@ int SwRTFParser::MakeFieldInst( String& rFieldStr )
                             if( nChar )
                             {
                                 pDoc->InsertString( *pPam, nChar );
-                                bCharIns = TRUE;
+                                bCharIns = sal_True;
                             }
                         }
                         break;
@@ -621,7 +617,7 @@ int SwRTFParser::MakeFieldInst( String& rFieldStr )
                     case 's': case 'S':
                         // Fontsize setzen
                         {
-                            const USHORT nVal = (USHORT)(sParam.ToInt32() * 20);
+                            const sal_uInt16 nVal = (sal_uInt16)(sParam.ToInt32() * 20);
                             rSet.Put( SvxFontHeightItem( nVal,
                                                 100, RES_CHRATR_FONTSIZE ));
                         }
@@ -630,7 +626,7 @@ int SwRTFParser::MakeFieldInst( String& rFieldStr )
             }
 
             if( !IsNewGroup() ) AttrGroupEnd();
-            SetNewGroup( FALSE );
+            SetNewGroup( sal_False );
 
             SkipGroup();		// ueberlese den Rest
         }
@@ -687,7 +683,6 @@ int SwRTFParser::MakeFieldInst( String& rFieldStr )
                 case 1:		aData.nJustificationCode = 3;	break;
                 case 2:		aData.nJustificationCode = 4;	break;
                 case 4:		aData.nJustificationCode = 2;	break;
-//				case 3:
                 default:	aData.nJustificationCode = 0;	break;
                 }
 
@@ -699,22 +694,22 @@ int SwRTFParser::MakeFieldInst( String& rFieldStr )
                 if( !pCharFmt )
                 {
                     //Make a guess at which of asian of western we should be setting
-                    USHORT nScript;
+                    sal_uInt16 nScript;
                     if (pBreakIt->GetBreakIter().is())
                         nScript = pBreakIt->GetBreakIter()->getScriptType( aData.sUp, 0);
                     else
                         nScript = i18n::ScriptType::ASIAN;
 
-                    USHORT nFntHWhich = GetWhichOfScript( RES_CHRATR_FONTSIZE, nScript ),
+                    sal_uInt16 nFntHWhich = GetWhichOfScript( RES_CHRATR_FONTSIZE, nScript ),
                            nFntWhich = GetWhichOfScript( RES_CHRATR_FONT, nScript );
 
                     //Check to see if we already have a ruby charstyle that this fits
-                    for(USHORT i=0; i < aRubyCharFmts.Count(); ++i )
+                    for(sal_uInt16 i=0; i < aRubyCharFmts.Count(); ++i )
                     {
                         SwCharFmt *pFmt = (SwCharFmt *)aRubyCharFmts[i];
                         const SvxFontHeightItem &rF = (const SvxFontHeightItem &)
                                                     pFmt->GetFmtAttr( nFntHWhich );
-                        if( rF.GetHeight() == USHORT(aData.nFontSize * 10 ))
+                        if( rF.GetHeight() == sal_uInt16(aData.nFontSize * 10 ))
                         {
                             const SvxFontItem &rFI = (const SvxFontItem &)
                                                     pFmt->GetFmtAttr( nFntWhich );
@@ -752,7 +747,7 @@ int SwRTFParser::MakeFieldInst( String& rFieldStr )
                 //Set the charstyle and justification
                 aRuby.SetCharFmtName( pCharFmt->GetName() );
                 aRuby.SetCharFmtId( pCharFmt->GetPoolFmtId() );
-                aRuby.SetAdjustment( (USHORT)aData.nJustificationCode );
+                aRuby.SetAdjustment( (sal_uInt16)aData.nJustificationCode );
 
                 // im FieldStr steht der anzuzeigenden Text, im
                 pDoc->InsertString( *pPam, aData.sText );
@@ -891,7 +886,7 @@ void SwRTFParser::ReadXEField()
     bReadSwFly = false; //#it may be that any uses of this need to be removed and replaced
     int nNumOpenBrakets = 1;
     String sFieldStr;
-    BYTE cCh;
+    sal_uInt8 cCh;
 
     int nToken;
     while (nNumOpenBrakets && IsParserWorking())
@@ -915,7 +910,7 @@ void SwRTFParser::ReadXEField()
                     if( SFX_ITEM_SET == rSet.GetItemState( RES_CHRATR_HIDDEN, sal_True, &pItem ) )
                     {
                         SvxCharHiddenItem aCharHidden(*(SvxCharHiddenItem*)pItem);
-                        aCharHidden.SetValue(FALSE);
+                        aCharHidden.SetValue(sal_False);
                         rSet.Put(aCharHidden);
                     }
 
@@ -999,9 +994,9 @@ void SwRTFParser::ReadField()
     bReadSwFly = false; //#it may be that any uses of this need to be removed and replaced
     int nRet = 0;
     int nNumOpenBrakets = 1;		// die erste wurde schon vorher erkannt !!
-    int bFldInst = FALSE, bFldRslt = FALSE;
+    int bFldInst = sal_False, bFldRslt = sal_False;
     String sFieldStr, sFieldNm;
-    BYTE cCh;
+    sal_uInt8 cCh;
 
     int nToken;
     while (nNumOpenBrakets && IsParserWorking())
@@ -1096,7 +1091,7 @@ void SwRTFParser::ReadField()
                 {
                     if(nRet == RTFFLD_PAGEREF)
                     {
-                        // #17371 Nasty hack to get a pageref within a hyperlink working
+                        // Nasty hack to get a pageref within a hyperlink working
                         sNestedFieldStr = sFieldStr;
                     }
 
@@ -1133,11 +1128,11 @@ void SwRTFParser::ReadField()
             break;
 
         case RTF_FLDINST:
-            bFldInst = TRUE;
+            bFldInst = sal_True;
             break;
 
         case RTF_FLDRSLT:
-            bFldRslt = TRUE;
+            bFldRslt = sal_True;
             break;
 
         case RTF_U:
