@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -27,14 +28,17 @@
 
 #include "docxexport.hxx"
 #include "docxexportfilter.hxx"
+#include "docxattributeoutput.hxx"
 
 #include <com/sun/star/document/XDocumentPropertiesSupplier.hpp>
 #include <com/sun/star/document/XDocumentProperties.hpp>
 #include <com/sun/star/i18n/ScriptType.hdl>
+#include <com/sun/star/frame/XModel.hpp>
 
-#include <oox/core/tokens.hxx>
+#include <oox/token/tokens.hxx>
 #include <oox/export/drawingml.hxx>
 #include <oox/export/vmlexport.hxx>
+#include <oox/export/chartexport.hxx>
 
 #include <map>
 #include <algorithm>
@@ -60,8 +64,10 @@
 #include <rtl/ustrbuf.hxx>
 #include <vcl/font.hxx>
 
+using namespace sax_fastparser;
 using namespace ::comphelper;
 using namespace ::com::sun::star;
+using namespace ::oox;
 
 using oox::vml::VMLExport;
 
@@ -82,7 +88,7 @@ MSWordSections& DocxExport::Sections() const
     return *m_pSections;
 }
 
-bool DocxExport::CollapseScriptsforWordOk( USHORT nScript, USHORT nWhich )
+bool DocxExport::CollapseScriptsforWordOk( sal_uInt16 nScript, sal_uInt16 nWhich )
 {
     // TODO FIXME is this actually true for docx? - this is ~copied from WW8
     if ( nScript == i18n::ScriptType::ASIAN )
@@ -186,8 +192,8 @@ bool DocxExport::DisallowInheritingOutlineNumbering( const SwFmt& rFmt )
     return bRet;
 }
 
-void DocxExport::WriteHeadersFooters( BYTE nHeadFootFlags,
-        const SwFrmFmt& rFmt, const SwFrmFmt& rLeftFmt, const SwFrmFmt& rFirstPageFmt, BYTE /*nBreakCode*/ )
+void DocxExport::WriteHeadersFooters( sal_uInt8 nHeadFootFlags,
+        const SwFrmFmt& rFmt, const SwFrmFmt& rLeftFmt, const SwFrmFmt& rFirstPageFmt, sal_uInt8 /*nBreakCode*/ )
 {
     // headers
     if ( nHeadFootFlags & nsHdFtFlags::WW8_HEADER_EVEN )
@@ -209,24 +215,27 @@ void DocxExport::WriteHeadersFooters( BYTE nHeadFootFlags,
     if ( nHeadFootFlags & nsHdFtFlags::WW8_FOOTER_FIRST )
         WriteHeaderFooter( rFirstPageFmt, false, "first" );
 
-#if OSL_DEBUG_LEVEL > 0
+    if ( nHeadFootFlags & ( nsHdFtFlags::WW8_FOOTER_EVEN | nsHdFtFlags::WW8_HEADER_EVEN ))
+        settings.evenAndOddHeaders = true;
+
+#if OSL_DEBUG_LEVEL > 1
     fprintf( stderr, "DocxExport::WriteHeadersFooters() - nBreakCode introduced, but ignored\n" );
 #endif
 }
 
-void DocxExport::OutputField( const SwField* pFld, ww::eField eFldType, const String& rFldCmd, BYTE nMode )
+void DocxExport::OutputField( const SwField* pFld, ww::eField eFldType, const String& rFldCmd, sal_uInt8 nMode )
 {
     m_pAttrOutput->WriteField_Impl( pFld, eFldType, rFldCmd, nMode );
 }
 
-void DocxExport::WriteFormData( const ::sw::mark::IFieldmark& /*rFieldmark*/ )
+void DocxExport::WriteFormData( const ::sw::mark::IFieldmark& rFieldmark )
 {
-    OSL_TRACE( "TODO DocxExport::WriteFormData()\n" );
+    m_pAttrOutput->WriteFormData_Impl( rFieldmark );
 }
 
 void DocxExport::WriteHyperlinkData( const ::sw::mark::IFieldmark& /*rFieldmark*/ )
 {
-#if OSL_DEBUG_LEVEL > 0
+#if OSL_DEBUG_LEVEL > 1
     fprintf( stderr, "TODO DocxExport::WriteHyperlinkData()\n" );
 #endif
 }
@@ -291,6 +300,33 @@ void DocxExport::DoFormText(const SwInputField* /*pFld*/)
     OSL_TRACE( "TODO DocxExport::ForFormText()\n" );
 }
 
+rtl::OString DocxExport::OutputChart( uno::Reference< frame::XModel >& xModel, sal_Int32 nCount )
+{
+    rtl::OUString aFileName = rtl::OUStringBuffer()
+                                .appendAscii("charts/chart")
+                                .append(nCount)
+                                .appendAscii( ".xml" )
+                                .makeStringAndClear();
+
+    OUString sId = m_pFilter->addRelation( m_pDocumentFS->getOutputStream(),
+                    S( "http://schemas.openxmlformats.org/officeDocument/2006/relationships/chart" ),
+                    aFileName );
+
+    aFileName = rtl::OUStringBuffer()
+                  .appendAscii("word/charts/chart")
+                  .append(nCount)
+                  .appendAscii( ".xml" )
+                  .makeStringAndClear();
+
+    ::sax_fastparser::FSHelperPtr pChartFS =
+        m_pFilter->openFragmentStreamWithSerializer( aFileName,
+            S( "application/vnd.openxmlformats-officedocument.drawingml.chart" ) );
+
+    oox::drawingml::ChartExport aChartExport( XML_w, pChartFS, xModel, m_pFilter, oox::drawingml::DrawingML::DOCUMENT_DOCX );
+    aChartExport.ExportContent();
+    return ::rtl::OUStringToOString( sId, RTL_TEXTENCODING_UTF8 );
+}
+
 void DocxExport::ExportDocument_Impl()
 {
     InitStyles();
@@ -306,6 +342,8 @@ void DocxExport::ExportDocument_Impl()
 
     WriteFonts();
 
+    WriteSettings();
+
     delete pStyles, pStyles = NULL;
     delete m_pSections, m_pSections = NULL;
 }
@@ -316,7 +354,7 @@ void DocxExport::OutputPageSectionBreaks( const SwTxtNode& )
 }
 
 
-void DocxExport::AppendSection( const SwPageDesc *pPageDesc, const SwSectionFmt* pFmt, ULONG nLnNum )
+void DocxExport::AppendSection( const SwPageDesc *pPageDesc, const SwSectionFmt* pFmt, sal_uLong nLnNum )
 {
     AttrOutput().SectionBreak( msword::PageBreak, m_pSections->CurrentSectionInfo() );
     m_pSections->AppendSection( pPageDesc, pFmt, nLnNum );
@@ -346,7 +384,7 @@ void DocxExport::OutputEndNode( const SwEndNode& rEndNode )
             if( !pParentFmt )
                 pParentFmt = (SwSectionFmt*)0xFFFFFFFF;
 
-            ULONG nRstLnNum;
+            sal_uLong nRstLnNum;
             if( rNd.IsCntntNode() )
                 nRstLnNum = const_cast< SwCntntNode* >( rNd.GetCntntNode() )->GetSwAttrSet().GetLineNumber().GetStartValue();
             else
@@ -373,7 +411,12 @@ void DocxExport::OutputOLENode( const SwOLENode& )
     OSL_TRACE( "TODO DocxExport::OutputOLENode( const SwOLENode& )\n" );
 }
 
-ULONG DocxExport::ReplaceCr( BYTE )
+void DocxExport::OutputLinkedOLE( const OUString& )
+{
+    // Nothing to implement here: WW8 only
+}
+
+sal_uLong DocxExport::ReplaceCr( sal_uInt8 )
 {
     // Completely unused for Docx export... only here for code sharing 
     // purpose with binary export
@@ -389,9 +432,9 @@ void DocxExport::PrepareNewPageDesc( const SfxItemSet* pSet,
     AttrOutput().SectionBreak( msword::PageBreak, m_pSections->CurrentSectionInfo() );
 
     const SwSectionFmt* pFmt = GetSectionFormat( rNd );
-    const ULONG nLnNm = GetSectionLineNo( pSet, rNd );
+    const sal_uLong nLnNm = GetSectionLineNo( pSet, rNd );
 
-    ASSERT( pNewPgDescFmt || pNewPgDesc, "Neither page desc format nor page desc provided." );
+    OSL_ENSURE( pNewPgDescFmt || pNewPgDesc, "Neither page desc format nor page desc provided." );
 
     if ( pNewPgDescFmt )
     {
@@ -517,9 +560,7 @@ void DocxExport::WriteHeaderFooter( const SwFmt& rFmt, bool bHeader, const char*
         pFS = m_pFilter->openFragmentStreamWithSerializer( OUStringBuffer().appendAscii( "word/" ).append( aName ).makeStringAndClear(),
                     S( "application/vnd.openxmlformats-officedocument.wordprocessingml.header+xml" ) );
 
-        pFS->startElementNS( XML_w, XML_hdr,
-                FSNS( XML_xmlns, XML_w ), "http://schemas.openxmlformats.org/wordprocessingml/2006/main",
-                FSEND );
+        pFS->startElementNS( XML_w, XML_hdr, MainXmlNamespaces( pFS ));
     }
     else
     {
@@ -532,9 +573,7 @@ void DocxExport::WriteHeaderFooter( const SwFmt& rFmt, bool bHeader, const char*
         pFS = m_pFilter->openFragmentStreamWithSerializer( OUStringBuffer().appendAscii( "word/" ).append( aName ).makeStringAndClear(),
                     S( "application/vnd.openxmlformats-officedocument.wordprocessingml.footer+xml" ) );
 
-        pFS->startElementNS( XML_w, XML_ftr,
-                FSNS( XML_xmlns, XML_w ), "http://schemas.openxmlformats.org/wordprocessingml/2006/main",
-                FSEND );
+        pFS->startElementNS( XML_w, XML_ftr, MainXmlNamespaces( pFS ));
     }
 
     // switch the serializer to redirect the output to word/styles.xml
@@ -608,6 +647,28 @@ void DocxExport::WriteProperties( )
     m_pFilter->exportDocumentProperties( xDocProps );
 }
 
+void DocxExport::WriteSettings()
+{
+    if( !settings.hasData())
+        return;
+    m_pFilter->addRelation( m_pDocumentFS->getOutputStream(),
+            S( "http://schemas.openxmlformats.org/officeDocument/2006/relationships/settings" ),
+            S( "settings.xml" ) );
+
+    ::sax_fastparser::FSHelperPtr pFS = m_pFilter->openFragmentStreamWithSerializer(
+            S( "word/settings.xml" ),
+            S( "application/vnd.openxmlformats-officedocument.wordprocessingml.settings+xml" ) );
+
+    pFS->startElementNS( XML_w, XML_settings,
+            FSNS( XML_xmlns, XML_w ), "http://schemas.openxmlformats.org/wordprocessingml/2006/main",
+            FSEND );
+
+    if( settings.evenAndOddHeaders )
+        pFS->singleElementNS( XML_w, XML_evenAndOddHeaders, FSEND );
+
+    pFS->endElementNS( XML_w, XML_settings );
+}
+
 VMLExport& DocxExport::VMLExporter()
 {
     return *m_pVMLExport;
@@ -616,14 +677,7 @@ VMLExport& DocxExport::VMLExporter()
 void DocxExport::WriteMainText()
 {
     // setup the namespaces
-    m_pDocumentFS->startElementNS( XML_w, XML_document,
-            FSNS( XML_xmlns, XML_o ), "urn:schemas-microsoft-com:office:office",
-            FSNS( XML_xmlns, XML_r ), "http://schemas.openxmlformats.org/officeDocument/2006/relationships",
-            FSNS( XML_xmlns, XML_v ), "urn:schemas-microsoft-com:vml",
-            FSNS( XML_xmlns, XML_w ), "http://schemas.openxmlformats.org/wordprocessingml/2006/main",
-            FSNS( XML_xmlns, XML_w10 ), "urn:schemas-microsoft-com:office:word",
-            FSNS( XML_xmlns, XML_wp ), "http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing",
-            FSEND );
+    m_pDocumentFS->startElementNS( XML_w, XML_document, MainXmlNamespaces( m_pDocumentFS ));
 
     // body
     m_pDocumentFS->startElementNS( XML_w, XML_body, FSEND );
@@ -643,6 +697,25 @@ void DocxExport::WriteMainText()
     m_pDocumentFS->endElementNS( XML_w, XML_document );
 }
 
+XFastAttributeListRef DocxExport::MainXmlNamespaces( FSHelperPtr serializer )
+{
+    FastAttributeList* pAttr = serializer->createAttrList();
+    pAttr->add( FSNS( XML_xmlns, XML_o ), "urn:schemas-microsoft-com:office:office" );
+    pAttr->add( FSNS( XML_xmlns, XML_r ), "http://schemas.openxmlformats.org/officeDocument/2006/relationships" );
+    pAttr->add( FSNS( XML_xmlns, XML_v ), "urn:schemas-microsoft-com:vml" );
+    pAttr->add( FSNS( XML_xmlns, XML_w ), "http://schemas.openxmlformats.org/wordprocessingml/2006/main" );
+    pAttr->add( FSNS( XML_xmlns, XML_w10 ), "urn:schemas-microsoft-com:office:word" );
+    pAttr->add( FSNS( XML_xmlns, XML_wp ), "http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing" );
+    return XFastAttributeListRef( pAttr );
+}
+
+bool DocxExport::ignoreAttributeForStyles( sal_uInt16 nWhich ) const
+{
+    if( nWhich == RES_TEXTGRID )
+        return true; // w:docGrid is written only to document.xml, not to styles.xml
+    return MSWordExportBase::ignoreAttributeForStyles( nWhich );
+}
+
 DocxExport::DocxExport( DocxExportFilter *pFilter, SwDoc *pDocument, SwPaM *pCurrentPam, SwPaM *pOriginalPam )
     : MSWordExportBase( pDocument, pCurrentPam, pOriginalPam ),
       m_pFilter( pFilter ),
@@ -680,4 +753,16 @@ DocxExport::~DocxExport()
     delete m_pDrawingML, m_pDrawingML = NULL;
 }
 
-/* vi:set tabstop=4 shiftwidth=4 expandtab: */
+DocxSettingsData::DocxSettingsData()
+: evenAndOddHeaders( false )
+{
+}
+
+bool DocxSettingsData::hasData() const
+{
+    if( evenAndOddHeaders )
+        return true;
+    return false;
+}
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
