@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -31,6 +32,7 @@
 
 #include <tools/stream.hxx>
 #include <unotools/syslocale.hxx>
+#include <svl/cjkoptions.hxx>
 
 #include "swtypes.hxx"
 #include "hintids.hxx"
@@ -46,34 +48,42 @@
 #include <unomid.h>
 
 using namespace utl;
-using namespace rtl;
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 
+using ::rtl::OUString;
+
 
 void SwMasterUsrPref::SetUsrPref(const SwViewOption &rCopy)
 {
     *((SwViewOption*)this) = rCopy;
 }
 
-SwMasterUsrPref::SwMasterUsrPref(BOOL bWeb) :
+SwMasterUsrPref::SwMasterUsrPref(sal_Bool bWeb) :
     eFldUpdateFlags(AUTOUPD_OFF),
     nLinkUpdateMode(0),
     bIsHScrollMetricSet(sal_False),
     bIsVScrollMetricSet(sal_False),
     nDefTab( MM50 * 4 ),
     bIsSquaredPageMode(sal_False),
-    bApplyCharUnit(sal_False),
     aContentConfig(bWeb, *this),
     aLayoutConfig(bWeb, *this),
     aGridConfig(bWeb, *this),
     aCursorConfig(*this),
-    pWebColorConfig(bWeb ? new SwWebColorConfig(*this) : 0)
+    pWebColorConfig(bWeb ? new SwWebColorConfig(*this) : 0),
+    bApplyCharUnit(sal_False)
 {
     MeasurementSystem eSystem = SvtSysLocale().GetLocaleData().getMeasurementSystemEnum();
+    SvtCJKOptions aCJKOptions;
     eUserMetric = MEASURE_METRIC == eSystem ? FUNIT_CM : FUNIT_INCH;
-    eHScrollMetric = eUserMetric;
-    eVScrollMetric = eUserMetric;
+
+    sal_Bool bCJKEnabled = aCJKOptions.IsAsianTypographyEnabled();
+    bApplyCharUnit = bCJKEnabled;
+    eHScrollMetric = bApplyCharUnit ? FUNIT_CHAR : eUserMetric;
+    eVScrollMetric = bApplyCharUnit ? FUNIT_LINE : eUserMetric;
+
+    bIsHScrollMetricSet = bApplyCharUnit;
+    bIsVScrollMetricSet = bApplyCharUnit;
 
     aContentConfig.Load();
     aLayoutConfig.Load();
@@ -82,16 +92,12 @@ SwMasterUsrPref::SwMasterUsrPref(BOOL bWeb) :
     if(pWebColorConfig)
         pWebColorConfig->Load();
 }
-/* -----------------------------13.02.01 09:48--------------------------------
 
- ---------------------------------------------------------------------------*/
 SwMasterUsrPref::~SwMasterUsrPref()
 {
     delete pWebColorConfig;
 }
-/*-- 28.09.00 09:55:32---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 Sequence<OUString> SwContentViewConfig::GetPropertyNames()
 {
     static const char* aPropNames[] =
@@ -108,13 +114,13 @@ Sequence<OUString> SwContentViewConfig::GetPropertyNames()
         "NonprintingCharacter/Space",               //  9
         "NonprintingCharacter/Break",               // 10
         "NonprintingCharacter/ProtectedSpace",      // 11
-            "NonprintingCharacter/Tab",             // 12 //not in Writer/Web
-            "NonprintingCharacter/HiddenText",      // 13
-            "NonprintingCharacter/HiddenParagraph", // 14
-            "NonprintingCharacter/HiddenCharacter",      // 15
-            "Update/Link",                          // 16
-            "Update/Field",                         // 17
-            "Update/Chart"                          // 18
+        "NonprintingCharacter/Tab",             // 12 //not in Writer/Web
+        "NonprintingCharacter/HiddenText",      // 13
+        "NonprintingCharacter/HiddenParagraph", // 14
+        "NonprintingCharacter/HiddenCharacter",      // 15
+        "Update/Link",                          // 16
+        "Update/Field",                         // 17
+        "Update/Chart"                          // 18
 
 
     };
@@ -127,10 +133,8 @@ Sequence<OUString> SwContentViewConfig::GetPropertyNames()
     }
     return aNames;
 }
-/*-- 28.09.00 09:55:33---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
-SwContentViewConfig::SwContentViewConfig(BOOL bIsWeb, SwMasterUsrPref& rPar) :
+SwContentViewConfig::SwContentViewConfig(sal_Bool bIsWeb, SwMasterUsrPref& rPar) :
     ConfigItem(bIsWeb ? C2U("Office.WriterWeb/Content") :  C2U("Office.Writer/Content")),
     rParent(rPar),
     bWeb(bIsWeb)
@@ -138,22 +142,16 @@ SwContentViewConfig::SwContentViewConfig(BOOL bIsWeb, SwMasterUsrPref& rPar) :
     Load();
     EnableNotification( GetPropertyNames() );
 }
-/*-- 28.09.00 09:55:33---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SwContentViewConfig::~SwContentViewConfig()
 {
 }
-/*-- 09.02.07 09:55:33---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwContentViewConfig::Notify( const Sequence< OUString > & /*rPropertyNames*/ )
 {
     Load();
 }
-/*-- 28.09.00 09:55:33---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwContentViewConfig::Commit()
 {
     Sequence<OUString> aNames = GetPropertyNames();
@@ -163,7 +161,7 @@ void SwContentViewConfig::Commit()
 
     for(int nProp = 0; nProp < aNames.getLength(); nProp++)
     {
-        sal_Bool bVal = FALSE;
+        sal_Bool bVal = sal_False;
         switch(nProp)
         {
             case  0: bVal = rParent.IsGraphic();	break;// "Display/GraphicObject",
@@ -191,15 +189,13 @@ void SwContentViewConfig::Commit()
     }
     PutProperties(aNames, aValues);
 }
-/*-- 28.09.00 09:55:34---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwContentViewConfig::Load()
 {
     Sequence<OUString> aNames = GetPropertyNames();
     Sequence<Any> aValues = GetProperties(aNames);
     const Any* pValues = aValues.getConstArray();
-    DBG_ASSERT(aValues.getLength() == aNames.getLength(), "GetProperties failed");
+    OSL_ENSURE(aValues.getLength() == aNames.getLength(), "GetProperties failed");
     if(aValues.getLength() == aNames.getLength())
     {
         for(int nProp = 0; nProp < aNames.getLength(); nProp++)
@@ -229,45 +225,45 @@ void SwContentViewConfig::Load()
                     {
                         sal_Int32 nSet = 0;
                         pValues[nProp] >>= nSet;
-                        rParent.SetUpdateLinkMode(nSet, TRUE);
+                        rParent.SetUpdateLinkMode(nSet, sal_True);
                     }
                     break;// "Update/Link",
-                    case 17: rParent.SetUpdateFields(bSet, TRUE); break;// "Update/Field",
-                    case 18: rParent.SetUpdateCharts(bSet, TRUE); break;// "Update/Chart"
+                    case 17: rParent.SetUpdateFields(bSet, sal_True); break;// "Update/Field",
+                    case 18: rParent.SetUpdateCharts(bSet, sal_True); break;// "Update/Chart"
                 }
             }
         }
     }
 }
-/*-- 28.09.00 09:55:34---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 Sequence<OUString> SwLayoutViewConfig::GetPropertyNames()
 {
     static const char* aPropNames[] =
     {
-        "Line/Guide",                       // 0
-        "Line/SimpleControlPoint",          // 1
-        "Line/LargeControlPoint",           // 2
-        "Window/HorizontalScroll",          // 3
-        "Window/VerticalScroll",            // 4
-        "Window/ShowRulers",                // 5
-        "Window/HorizontalRuler",           // 6
-        "Window/VerticalRuler",             // 7
-        "Window/HorizontalRulerUnit",       // 8
-        "Window/VerticalRulerUnit",         // 9
-        "Window/SmoothScroll",              //10
-        "Zoom/Value",                       //11
-        "Zoom/Type",                        //12
-        "Other/MeasureUnit",                //13
-        "Other/TabStop",                    //14
-        "Window/IsVerticalRulerRight",      //15
-        "ViewLayout/Columns",               //16
-        "ViewLayout/BookMode",              //17
-        "Other/IsSquaredPageMode",        //18
-        "Other/ApplyCharUnit"               //19
+        "Line/Guide",                           // 0
+        "Line/SimpleControlPoint",              // 1
+        "Line/LargeControlPoint",               // 2
+        "Window/HorizontalScroll",              // 3
+        "Window/VerticalScroll",                // 4
+        "Window/ShowRulers",                    // 5
+        "Window/HorizontalRuler",               // 6
+        "Window/VerticalRuler",                 // 7
+        "Window/HorizontalRulerUnit",           // 8
+        "Window/VerticalRulerUnit",             // 9
+        "Window/SmoothScroll",                  //10
+        "Zoom/Value",                           //11
+        "Zoom/Type",                            //12
+        "Other/IsAlignMathObjectsToBaseline",   //13
+        "Other/MeasureUnit",                    //14
+        // below properties are not available in WriterWeb
+        "Other/TabStop",                        //15
+        "Window/IsVerticalRulerRight",          //16
+        "ViewLayout/Columns",                   //17
+        "ViewLayout/BookMode",                  //18
+        "Other/IsSquaredPageMode"               //19
+        "Other/ApplyCharUnit"                   //20
     };
-    const int nCount = bWeb ? 14 : 20;
+    const int nCount = bWeb ? 15 : 21;
     Sequence<OUString> aNames(nCount);
     OUString* pNames = aNames.getArray();
     for(int i = 0; i < nCount; i++)
@@ -276,25 +272,19 @@ Sequence<OUString> SwLayoutViewConfig::GetPropertyNames()
     }
     return aNames;
 }
-/*-- 28.09.00 09:55:34---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
-SwLayoutViewConfig::SwLayoutViewConfig(BOOL bIsWeb, SwMasterUsrPref& rPar) :
+SwLayoutViewConfig::SwLayoutViewConfig(sal_Bool bIsWeb, SwMasterUsrPref& rPar) :
     ConfigItem(bIsWeb ? C2U("Office.WriterWeb/Layout") :  C2U("Office.Writer/Layout"),
         CONFIG_MODE_DELAYED_UPDATE|CONFIG_MODE_RELEASE_TREE),
     rParent(rPar),
     bWeb(bIsWeb)
 {
 }
-/*-- 28.09.00 09:55:35---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SwLayoutViewConfig::~SwLayoutViewConfig()
 {
 }
-/*-- 28.09.00 09:55:36---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwLayoutViewConfig::Commit()
 {
     Sequence<OUString> aNames = GetPropertyNames();
@@ -304,59 +294,60 @@ void SwLayoutViewConfig::Commit()
 
     for(int nProp = 0; nProp < aNames.getLength(); nProp++)
     {
-        sal_Bool bSet;
+        Any &rVal = pValues[nProp];
         switch(nProp)
         {
-            case  0: bSet = rParent.IsCrossHair(); break;// "Line/Guide",
-            case  1: bSet = rParent.IsSolidMarkHdl(); break;// "Line/SimpleControlPoint",
-            case  2: bSet = rParent.IsBigMarkHdl(); break;// "Line/LargeControlPoint",
-            case  3: bSet = rParent.IsViewHScrollBar(); break;// "Window/HorizontalScroll",
-            case  4: bSet = rParent.IsViewVScrollBar(); break;// "Window/VerticalScroll",
-            case  5: bSet = rParent.IsViewAnyRuler(); break; // "Window/ShowRulers"
-            // #i14593# use IsView*Ruler(TRUE) instead of IsView*Ruler()
+            case  0: rVal <<= (sal_Bool) rParent.IsCrossHair(); break;              // "Line/Guide",
+            case  1: rVal <<= (sal_Bool) rParent.IsSolidMarkHdl(); break;           // "Line/SimpleControlPoint",
+            case  2: rVal <<= (sal_Bool) rParent.IsBigMarkHdl(); break;             // "Line/LargeControlPoint",
+            case  3: rVal <<= (sal_Bool) rParent.IsViewHScrollBar(); break;         // "Window/HorizontalScroll",
+            case  4: rVal <<= (sal_Bool) rParent.IsViewVScrollBar(); break;         // "Window/VerticalScroll",
+            case  5: rVal <<= (sal_Bool) rParent.IsViewAnyRuler(); break;           // "Window/ShowRulers"
+            // #i14593# use IsView*Ruler(sal_True) instead of IsView*Ruler()
             // this preserves the single ruler states even if "Window/ShowRulers" is off
-            case  6: bSet = rParent.IsViewHRuler(TRUE); break;// "Window/HorizontalRuler",
-            case  7: bSet = rParent.IsViewVRuler(TRUE); break;// "Window/VerticalRuler",
+            case  6: rVal <<= (sal_Bool) rParent.IsViewHRuler(sal_True); break;         // "Window/HorizontalRuler",
+            case  7: rVal <<= (sal_Bool) rParent.IsViewVRuler(sal_True); break;         // "Window/VerticalRuler",
             case  8:
                 if(rParent.bIsHScrollMetricSet)
-                    pValues[nProp] <<= (sal_Int32)rParent.eHScrollMetric; // "Window/HorizontalRulerUnit"
+                    rVal <<= (sal_Int32)rParent.eHScrollMetric;                     // "Window/HorizontalRulerUnit"
             break;
             case  9:
                 if(rParent.bIsVScrollMetricSet)
-                    pValues[nProp] <<= (sal_Int32)rParent.eVScrollMetric; // "Window/VerticalRulerUnit"
+                    rVal <<= (sal_Int32)rParent.eVScrollMetric;                     // "Window/VerticalRulerUnit"
             break;
-            case 10: bSet = rParent.IsSmoothScroll(); break;// "Window/SmoothScroll",
-            case 11: pValues[nProp] <<= (sal_Int32)rParent.GetZoom(); break;// "Zoom/Value",
-            case 12: pValues[nProp] <<= (sal_Int32)rParent.GetZoomType(); break;// "Zoom/Type",
-            case 13: pValues[nProp] <<= (sal_Int32)rParent.GetMetric(); break;// "Other/MeasureUnit",
-            case 14: pValues[nProp] <<= static_cast<sal_Int32>(TWIP_TO_MM100(rParent.GetDefTab())); break;// "Other/TabStop",
-            case 15: bSet = rParent.IsVRulerRight(); break;// "Window/IsVerticalRulerRight",
-            case 16: pValues[nProp] <<= (sal_Int32)rParent.GetViewLayoutColumns(); break;// "ViewLayout/Columns",
-            case 17: bSet = rParent.IsViewLayoutBookMode(); break;// "ViewLayout/BookMode",
-            case 18: bSet = rParent.IsSquaredPageMode(); break;// "Other/IsSquaredPageMode",
-            case 19: bSet = rParent.IsApplyCharUnit(); break;// "Other/ApplyCharUnit",
+            case 10: rVal <<= (sal_Bool) rParent.IsSmoothScroll(); break;           // "Window/SmoothScroll",
+            case 11: rVal <<= (sal_Int32)rParent.GetZoom(); break;                  // "Zoom/Value",
+            case 12: rVal <<= (sal_Int32)rParent.GetZoomType(); break;              // "Zoom/Type",
+            case 13: rVal <<= (sal_Bool) rParent.IsAlignMathObjectsToBaseline(); break;      // "Other/IsAlignMathObjectsToBaseline"
+            case 14: rVal <<= (sal_Int32)rParent.GetMetric(); break;                // "Other/MeasureUnit",
+            case 15: rVal <<= static_cast<sal_Int32>(TWIP_TO_MM100(rParent.GetDefTab())); break;// "Other/TabStop",
+            case 16: rVal <<= (sal_Bool) rParent.IsVRulerRight(); break;            // "Window/IsVerticalRulerRight",
+            case 17: rVal <<= (sal_Int32)rParent.GetViewLayoutColumns(); break;     // "ViewLayout/Columns",
+            case 18: rVal <<= (sal_Bool) rParent.IsViewLayoutBookMode(); break;     // "ViewLayout/BookMode",
+            case 19: rVal <<= (sal_Bool) rParent.IsSquaredPageMode(); break;        // "Other/IsSquaredPageMode",
+            case 20: rVal <<= (sal_Bool) rParent.IsApplyCharUnit(); break;        // "Other/IsSquaredPageMode",
         }
-        if(nProp < 8 || nProp == 10 || nProp == 15 || nProp == 17 || nProp == 18 || nProp == 19 )
-            pValues[nProp].setValue(&bSet, ::getBooleanCppuType());
     }
     PutProperties(aNames, aValues);
 }
-/*-- 28.09.00 09:55:36---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwLayoutViewConfig::Load()
 {
     Sequence<OUString> aNames = GetPropertyNames();
     Sequence<Any> aValues = GetProperties(aNames);
     const Any* pValues = aValues.getConstArray();
-    DBG_ASSERT(aValues.getLength() == aNames.getLength(), "GetProperties failed");
+    OSL_ENSURE(aValues.getLength() == aNames.getLength(), "GetProperties failed");
     if(aValues.getLength() == aNames.getLength())
     {
         for(int nProp = 0; nProp < aNames.getLength(); nProp++)
         {
             if(pValues[nProp].hasValue())
             {
-                sal_Bool bSet = nProp < 8 || nProp == 10 || nProp == 17 || nProp == 18 || nProp == 19 ? *(sal_Bool*)pValues[nProp].getValue() : sal_False;
+                sal_Int32   nInt32Val   = 0;
+                sal_Bool    bSet        = sal_False;
+                pValues[nProp] >>= nInt32Val;
+                pValues[nProp] >>= bSet;
+
                 switch(nProp)
                 {
                     case  0: rParent.SetCrossHair(bSet); break;// "Line/Guide",
@@ -370,59 +361,26 @@ void SwLayoutViewConfig::Load()
                     case  8:
                     {
                         rParent.bIsHScrollMetricSet = sal_True;
-                        sal_Int32 nUnit = 0;
-                        pValues[nProp] >>= nUnit;
-                        rParent.eHScrollMetric = ((FieldUnit)nUnit);  // "Window/HorizontalRulerUnit"
+                        rParent.eHScrollMetric = ((FieldUnit)nInt32Val);  // "Window/HorizontalRulerUnit"
                     }
                     break;
                     case  9:
                     {
                         rParent.bIsVScrollMetricSet = sal_True;
-                        sal_Int32 nUnit = 0;
-                        pValues[nProp] >>= nUnit;
-                        rParent.eVScrollMetric = ((FieldUnit)nUnit); // "Window/VerticalRulerUnit"
+                        rParent.eVScrollMetric = ((FieldUnit)nInt32Val); // "Window/VerticalRulerUnit"
                     }
                     break;
                     case 10: rParent.SetSmoothScroll(bSet); break;// "Window/SmoothScroll",
-                    case 11:
-                    {
-                        sal_Int32 nVal = 0;
-                        pValues[nProp] >>= nVal;
-                        rParent.SetZoom( static_cast< USHORT >(nVal) );
-                    }
-                    break;// "Zoom/Value",
-                    case 12:
-                    {
-                        sal_Int32 nVal = 0;
-                        pValues[nProp] >>= nVal;
-                        rParent.SetZoomType( static_cast< SvxZoomType >(nVal) );
-                    }
-                    break;// "Zoom/Type",
-                    case 13:
-                    {
-                        sal_Int32 nUnit = 0;
-                        pValues[nProp] >>= nUnit;
-                        rParent.SetMetric((FieldUnit)nUnit, TRUE);
-                    }
-                    break;// "Other/MeasureUnit",
-                    case 14:
-                    {
-                        sal_Int32 nTab = 0;
-                        pValues[nProp] >>= nTab;
-                        rParent.SetDefTab(MM100_TO_TWIP(nTab), TRUE);
-                    }
-                    break;// "Other/TabStop",
-                    case 15: rParent.SetVRulerRight(bSet); break;// "Window/IsVerticalRulerRight",
-                    case 16:
-                    {
-                        sal_Int32 nColumns = 0;
-                        pValues[nProp] >>= nColumns;
-                        rParent.SetViewLayoutColumns( static_cast<USHORT>(nColumns) );
-                    }
-                    break;// "ViewLayout/Columns",
-                    case 17: rParent.SetViewLayoutBookMode(bSet); break;// "ViewLayout/BookMode",
-                    case 18: rParent.SetDefaultPageMode(bSet,TRUE); break;// "Other/IsSquaredPageMode",
-                    case 19: rParent.SetApplyCharUnit(bSet); break;// "Other/ApplyUserChar"
+                    case 11: rParent.SetZoom( static_cast< sal_uInt16 >(nInt32Val) ); break;// "Zoom/Value",
+                    case 12: rParent.SetZoomType( static_cast< SvxZoomType >(nInt32Val) ); break;// "Zoom/Type",
+                    case 13: rParent.SetAlignMathObjectsToBaseline(bSet); break;// "Other/IsAlignMathObjectsToBaseline"
+                    case 14: rParent.SetMetric((FieldUnit)nInt32Val, sal_True); break;// "Other/MeasureUnit",
+                    case 15: rParent.SetDefTab(MM100_TO_TWIP(nInt32Val), sal_True); break;// "Other/TabStop",
+                    case 16: rParent.SetVRulerRight(bSet); break;// "Window/IsVerticalRulerRight",
+                    case 17: rParent.SetViewLayoutColumns( static_cast<sal_uInt16>(nInt32Val) ); break;// "ViewLayout/Columns",
+                    case 18: rParent.SetViewLayoutBookMode(bSet); break;// "ViewLayout/BookMode",
+                    case 19: rParent.SetDefaultPageMode(bSet,sal_True); break;// "Other/IsSquaredPageMode",
+                    case 20: rParent.SetApplyCharUnit(bSet); break;// "Other/ApplyUserChar"
                 }
             }
         }
@@ -431,9 +389,6 @@ void SwLayoutViewConfig::Load()
 
 void SwLayoutViewConfig::Notify( const ::com::sun::star::uno::Sequence< rtl::OUString >& ) {}
 
-/* -----------------------------19.01.01 13:07--------------------------------
-
- ---------------------------------------------------------------------------*/
 Sequence<OUString> SwGridConfig::GetPropertyNames()
 {
     static const char* aPropNames[] =
@@ -455,25 +410,19 @@ Sequence<OUString> SwGridConfig::GetPropertyNames()
     }
     return aNames;
 }
-/* -----------------------------19.01.01 13:07--------------------------------
 
- ---------------------------------------------------------------------------*/
-SwGridConfig::SwGridConfig(BOOL bIsWeb, SwMasterUsrPref& rPar) :
+SwGridConfig::SwGridConfig(sal_Bool bIsWeb, SwMasterUsrPref& rPar) :
     ConfigItem(bIsWeb ? C2U("Office.WriterWeb/Grid") :  C2U("Office.Writer/Grid"),
         CONFIG_MODE_DELAYED_UPDATE|CONFIG_MODE_RELEASE_TREE),
     rParent(rPar),
     bWeb(bIsWeb)
 {
 }
-/* -----------------------------19.01.01 13:07--------------------------------
 
- ---------------------------------------------------------------------------*/
 SwGridConfig::~SwGridConfig()
 {
 }
-/* -----------------------------19.01.01 13:07--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwGridConfig::Commit()
 {
     Sequence<OUString> aNames = GetPropertyNames();
@@ -499,15 +448,13 @@ void SwGridConfig::Commit()
     }
     PutProperties(aNames, aValues);
 }
-/* -----------------------------19.01.01 13:07--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwGridConfig::Load()
 {
     Sequence<OUString> aNames = GetPropertyNames();
     Sequence<Any> aValues = GetProperties(aNames);
     const Any* pValues = aValues.getConstArray();
-    DBG_ASSERT(aValues.getLength() == aNames.getLength(), "GetProperties failed");
+    OSL_ENSURE(aValues.getLength() == aNames.getLength(), "GetProperties failed");
     if(aValues.getLength() == aNames.getLength())
     {
         Size aSnap(rParent.GetSnapSize());
@@ -537,9 +484,6 @@ void SwGridConfig::Load()
 
 void SwGridConfig::Notify( const ::com::sun::star::uno::Sequence< rtl::OUString >& ) {}
 
-/* -----------------------------19.01.01 13:07--------------------------------
-
- ---------------------------------------------------------------------------*/
 Sequence<OUString> SwCursorConfig::GetPropertyNames()
 {
     static const char* aPropNames[] =
@@ -552,27 +496,21 @@ Sequence<OUString> SwCursorConfig::GetPropertyNames()
     Sequence<OUString> aNames(nCount);
     OUString* pNames = aNames.getArray();
     for(int i = 0; i < nCount; i++)
-        pNames[i] = C2U(aPropNames[i]);
+        pNames[i] = rtl::OUString::createFromAscii(aPropNames[i]);
     return aNames;
 }
-/* -----------------------------19.01.01 13:07--------------------------------
 
- ---------------------------------------------------------------------------*/
 SwCursorConfig::SwCursorConfig(SwMasterUsrPref& rPar) :
     ConfigItem(C2U("Office.Writer/Cursor"),
         CONFIG_MODE_DELAYED_UPDATE|CONFIG_MODE_RELEASE_TREE),
     rParent(rPar)
 {
 }
-/* -----------------------------19.01.01 13:07--------------------------------
 
- ---------------------------------------------------------------------------*/
 SwCursorConfig::~SwCursorConfig()
 {
 }
-/* -----------------------------19.01.01 13:07--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwCursorConfig::Commit()
 {
     Sequence<OUString> aNames = GetPropertyNames();
@@ -594,15 +532,13 @@ void SwCursorConfig::Commit()
     }
     PutProperties(aNames, aValues);
 }
-/* -----------------------------19.01.01 13:07--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwCursorConfig::Load()
 {
     Sequence<OUString> aNames = GetPropertyNames();
     Sequence<Any> aValues = GetProperties(aNames);
     const Any* pValues = aValues.getConstArray();
-    DBG_ASSERT(aValues.getLength() == aNames.getLength(), "GetProperties failed");
+    OSL_ENSURE(aValues.getLength() == aNames.getLength(), "GetProperties failed");
     if(aValues.getLength() == aNames.getLength())
     {
 
@@ -619,7 +555,7 @@ void SwCursorConfig::Load()
                 switch(nProp)
                 {
                     case  0: rParent.SetShadowCursor(bSet); 		break;//  "DirectCursor/UseDirectCursor",
-                    case  1: rParent.SetShdwCrsrFillMode((BYTE)nSet); break;//  "DirectCursor/Insert",
+                    case  1: rParent.SetShdwCrsrFillMode((sal_uInt8)nSet); break;//  "DirectCursor/Insert",
                     case  2: rParent.SetCursorInProtectedArea(bSet); break;// "Option/ProtectedArea"
                 }
             }
@@ -630,9 +566,6 @@ void SwCursorConfig::Load()
 
 void SwCursorConfig::Notify( const ::com::sun::star::uno::Sequence< rtl::OUString >& ) {}
 
-/*-- 28.09.00 09:55:33---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 SwWebColorConfig::SwWebColorConfig(SwMasterUsrPref& rPar) :
     ConfigItem(C2U("Office.WriterWeb/Background"),
         CONFIG_MODE_DELAYED_UPDATE|CONFIG_MODE_RELEASE_TREE),
@@ -641,15 +574,11 @@ SwWebColorConfig::SwWebColorConfig(SwMasterUsrPref& rPar) :
 {
     aPropNames.getArray()[0] = C2U("Color");
 }
-/*-- 28.09.00 09:55:33---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SwWebColorConfig::~SwWebColorConfig()
 {
 }
-/*-- 28.09.00 09:55:33---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwWebColorConfig::Commit()
 {
     Sequence<Any> aValues(aPropNames.getLength());
@@ -666,14 +595,11 @@ void SwWebColorConfig::Commit()
 
 void SwWebColorConfig::Notify( const ::com::sun::star::uno::Sequence< rtl::OUString >& ) {}
 
-/*-- 28.09.00 09:55:34---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 void SwWebColorConfig::Load()
 {
     Sequence<Any> aValues = GetProperties(aPropNames);
     const Any* pValues = aValues.getConstArray();
-    DBG_ASSERT(aValues.getLength() == aPropNames.getLength(), "GetProperties failed");
+    OSL_ENSURE(aValues.getLength() == aPropNames.getLength(), "GetProperties failed");
     if(aValues.getLength() == aPropNames.getLength())
     {
         for(int nProp = 0; nProp < aPropNames.getLength(); nProp++)
@@ -693,3 +619,4 @@ void SwWebColorConfig::Load()
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
