@@ -37,7 +37,6 @@
 
 #include <rsc/rscsfx.hxx>
 #include <com/sun/star/text/XDocumentIndexesSupplier.hpp>
-#include <com/sun/star/text/XDocumentIndex.hpp>
 #include <com/sun/star/text/XTextSectionsSupplier.hpp>
 #include <com/sun/star/style/BreakType.hpp>
 #include <com/sun/star/text/XTextFieldsSupplier.hpp>
@@ -95,7 +94,7 @@ void lcl_SetProp( uno::Reference< XPropertySetInfo > & xInfo,
                            uno::Reference< XPropertySet > & xProps,
                          const char* pPropName, const String& rValue)
 {
-    OUString uPropName(C2U(pPropName));
+    OUString uPropName(rtl::OUString::createFromAscii(pPropName));
     if(xInfo->hasPropertyByName(uPropName))
     {
         uno::Any aValue;
@@ -106,16 +105,16 @@ void lcl_SetProp( uno::Reference< XPropertySetInfo > & xInfo,
 
 void lcl_SetProp( uno::Reference< XPropertySetInfo > & xInfo,
                            uno::Reference< XPropertySet > & xProps,
-                           USHORT nId, const String& rValue)
+                           sal_uInt16 nId, const String& rValue)
 {
     lcl_SetProp( xInfo, xProps, SW_PROP_NAME_STR(nId), rValue);
 }
 
 void lcl_SetProp( uno::Reference< XPropertySetInfo > & xInfo,
                            uno::Reference< XPropertySet > & xProps,
-                           USHORT nId, sal_Int16 nValue )
+                           sal_uInt16 nId, sal_Int16 nValue )
 {
-    OUString uPropName(C2U(SW_PROP_NAME_STR(nId)));
+    OUString uPropName(rtl::OUString::createFromAscii(SW_PROP_NAME_STR(nId)));
     if(xInfo->hasPropertyByName(uPropName))
     {
         uno::Any aValue;
@@ -127,9 +126,9 @@ void lcl_SetProp( uno::Reference< XPropertySetInfo > & xInfo,
 void lcl_SetBOOLProp(
                 uno::Reference< beans::XPropertySetInfo > & xInfo,
                 uno::Reference< beans::XPropertySet > & xProps,
-                USHORT nId, sal_Bool bValue )
+                sal_uInt16 nId, sal_Bool bValue )
 {
-    OUString uPropName(C2U(SW_PROP_NAME_STR(nId)));
+    OUString uPropName(rtl::OUString::createFromAscii(SW_PROP_NAME_STR(nId)));
     if(xInfo->hasPropertyByName(uPropName))
     {
         uno::Any aValue;
@@ -147,7 +146,7 @@ IMPL_LINK( SwMultiTOXTabDialog, CreateExample_Hdl, void*, EMPTYARG )
         SwXTextDocument* pDoc = reinterpret_cast<SwXTextDocument*>(xDocTunnel->getSomething(SwXTextDocument::getUnoTunnelId()));
 
         if( pDoc )
-            pDoc->GetDocShell()->_LoadStyles( *rSh.GetView().GetDocShell(), TRUE );
+            pDoc->GetDocShell()->_LoadStyles( *rSh.GetView().GetDocShell(), sal_True );
 
          uno::Reference< lang::XMultiServiceFactory >  xFact(
                                              xModel, uno::UNO_QUERY);
@@ -179,7 +178,7 @@ IMPL_LINK( SwMultiTOXTabDialog, CreateExample_Hdl, void*, EMPTYARG )
     }
     catch(Exception&)
     {
-        OSL_ENSURE(false, "::CreateExample() - exception caught");
+        OSL_FAIL("::CreateExample() - exception caught");
     }
     return 0;
 }
@@ -190,7 +189,7 @@ void SwMultiTOXTabDialog::CreateOrUpdateExample(
     if(!pExampleFrame || !pExampleFrame->IsInitialized())
         return;
 
-    const char* __FAR_DATA IndexServiceNames[] =
+    const char* IndexServiceNames[] =
     {
         "com.sun.star.text.DocumentIndex",
         "com.sun.star.text.UserIndex",
@@ -228,7 +227,7 @@ void SwMultiTOXTabDialog::CreateOrUpdateExample(
          uno::Reference< text::XTextRange >  xRg(xCrsr, uno::UNO_QUERY);
             xCrsr->getText()->insertTextContent(xRg, xContent, sal_False);
         }
-        OUString uIsVisible(C2U(SW_PROP_NAME_STR(UNO_NAME_IS_VISIBLE)));
+        OUString uIsVisible(rtl::OUString::createFromAscii(SW_PROP_NAME_STR(UNO_NAME_IS_VISIBLE)));
         for(sal_uInt16 i = 0 ; i <= TOX_AUTHORITIES; i++)
         {
          uno::Reference< beans::XPropertySet >  xSectPr(pxIndexSectionsArr[i]->xContainerSection, uno::UNO_QUERY);
@@ -236,7 +235,7 @@ void SwMultiTOXTabDialog::CreateOrUpdateExample(
 
             if(xSectPr.is())
             {
-                BOOL bTemp = i == nTOXIndex;
+                sal_Bool bTemp = i == nTOXIndex;
                 aVal.setValue(&bTemp, ::getBooleanCppuType());
                 xSectPr->setPropertyValue(uIsVisible, aVal);
             }
@@ -254,10 +253,10 @@ void SwMultiTOXTabDialog::CreateOrUpdateExample(
 
             //stylenames
             sal_uInt16  nContentOptions = rDesc.GetContentOptions();
-            if(xInfo->hasPropertyByName(C2U(SW_PROP_NAME_STR(UNO_NAME_LEVEL_PARAGRAPH_STYLES))))
+            if(xInfo->hasPropertyByName(rtl::OUString::createFromAscii(SW_PROP_NAME_STR(UNO_NAME_LEVEL_PARAGRAPH_STYLES))))
             {
                 sal_Bool bOn = 0!=(nContentOptions&nsSwTOXElement::TOX_TEMPLATE    );
-                uno::Any aStyleNames(xIdxProps->getPropertyValue(C2U(SW_PROP_NAME_STR(UNO_NAME_LEVEL_PARAGRAPH_STYLES))));
+                uno::Any aStyleNames(xIdxProps->getPropertyValue(rtl::OUString::createFromAscii(SW_PROP_NAME_STR(UNO_NAME_LEVEL_PARAGRAPH_STYLES))));
                 uno::Reference< container::XIndexReplace >  xAcc;
                 aStyleNames >>= xAcc;
 
@@ -330,7 +329,7 @@ void SwMultiTOXTabDialog::CreateOrUpdateExample(
                 nEndLevel = pForm->GetFormMax() - 1;
             }
 
-            if(xInfo->hasPropertyByName(C2U(SW_PROP_NAME_STR(UNO_NAME_LEVEL_FORMAT))))
+            if(xInfo->hasPropertyByName(rtl::OUString::createFromAscii(SW_PROP_NAME_STR(UNO_NAME_LEVEL_FORMAT))))
             {
                 for(sal_uInt16 nCurrLevel = nStartLevel; nCurrLevel <= nEndLevel; nCurrLevel++)
                 {
@@ -404,7 +403,7 @@ void SwMultiTOXTabDialog::CreateOrUpdateExample(
                         if(TOKEN_TAB_STOP == aToken.eTokenType)
                         {
                             pPropValArr[2].Name = C2U("TabStopRightAligned");
-                            BOOL bTemp = SVX_TAB_ADJUST_END == aToken.eTabAlign;
+                            sal_Bool bTemp = SVX_TAB_ADJUST_END == aToken.eTabAlign;
                             pPropValArr[2].Value.setValue(&bTemp, ::getBooleanCppuType());
                             pPropValArr[3].Name = C2U("TabStopFillCharacter");
                             pPropValArr[3].Value <<= OUString(aToken.cTabFillChar);
@@ -423,11 +422,11 @@ void SwMultiTOXTabDialog::CreateOrUpdateExample(
                         pValues[nTokenIndex] = aPropVals;
                         nTokenIndex++;
 
-                        aIt++; // #i24377#
+                        ++aIt; // #i24377#
                     }
                     aSequPropVals.realloc(nTokenIndex);
 
-                    uno::Any aFormatAccess = xIdxProps->getPropertyValue(C2U(SW_PROP_NAME_STR(UNO_NAME_LEVEL_FORMAT)));
+                    uno::Any aFormatAccess = xIdxProps->getPropertyValue(rtl::OUString::createFromAscii(SW_PROP_NAME_STR(UNO_NAME_LEVEL_FORMAT)));
                     OSL_ENSURE(aFormatAccess.getValueType() == ::getCppuType((uno::Reference<container::XIndexReplace>*)0),
                         "wrong property type");
 
@@ -473,7 +472,7 @@ void SwMultiTOXTabDialog::CreateOrUpdateExample(
     }
     catch(Exception&)
     {
-        OSL_ENSURE(false, "::CreateExample() - exception caught");
+        OSL_FAIL("::CreateExample() - exception caught");
     }
 }
 
