@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -33,20 +34,14 @@
 
 
 #include <hintids.hxx>
-#ifndef _VIEW_HXX
 #include <view.hxx>
-#endif
 #include <wrtsh.hxx>
 #include <swundo.hxx>         // fuer Undo-Ids
-#ifndef _GLOBALS_HRC
 #include <globals.hrc>
-#endif
 #include <splargs.hxx>
 
 
-#ifndef _MSGBOX_HXX //autogen
 #include <vcl/msgbox.hxx>
-#endif
 #include <editeng/unolingu.hxx>
 #include <editeng/langitem.hxx>
 #include <editeng/fontitem.hxx>
@@ -67,11 +62,8 @@
 #include <ndtxt.hxx>
 #include <fmtruby.hxx>
 #include <breakit.hxx>
-#include <docsh.hxx>
 
-#ifndef _OLMENU_HRC
 #include <olmenu.hrc>
-#endif
 
 #include <unomid.h>
 
@@ -196,11 +188,6 @@ SwHHCWrapper::~SwHHCWrapper()
         }
 
     }
-
-/*
-    if( bInfoBox )
-        InfoBox(&pView->GetEditWin(), String(SW_RES(STR_SPELL_OK)) ).Execute();
-*/
 }
 
 
@@ -230,10 +217,10 @@ void SwHHCWrapper::SelectNewUnit_impl( sal_Int32 nUnitStart, sal_Int32 nUnitEnd
     pCrsr->DeleteMark();
 
     rWrtShell.Right( CRSR_SKIP_CHARS, /*bExpand*/ sal_False,
-                  (USHORT) (nUnitOffset + nUnitStart), sal_True );
+                  (sal_uInt16) (nUnitOffset + nUnitStart), sal_True );
     pCrsr->SetMark();
     rWrtShell.Right( CRSR_SKIP_CHARS, /*bExpand*/ sal_True,
-                  (USHORT) (nUnitEnd - nUnitStart), sal_True );
+                  (sal_uInt16) (nUnitEnd - nUnitStart), sal_True );
     // end selection now. Otherwise SHIFT+HOME (extending the selection)
     // won't work when the dialog is closed without any replacement.
     // (see #116346#)
@@ -244,7 +231,7 @@ void SwHHCWrapper::SelectNewUnit_impl( sal_Int32 nUnitStart, sal_Int32 nUnitEnd
 void SwHHCWrapper::HandleNewUnit(
         const sal_Int32 nUnitStart, const sal_Int32 nUnitEnd )
 {
-    DBG_ASSERT( nUnitStart >= 0 && nUnitEnd >= nUnitStart, "wrong arguments" );
+    OSL_ENSURE( nUnitStart >= 0 && nUnitEnd >= nUnitStart, "wrong arguments" );
     if (!(0 <= nUnitStart && nUnitStart <= nUnitEnd))
         return;
 
@@ -267,7 +254,7 @@ void SwHHCWrapper::ChangeText( const String &rNewText,
     //!! please see also TextConvWrapper::ChangeText with is a modified
     //!! copy of this code
 
-    DBG_ASSERT( rNewText.Len() != 0, "unexpected empty string" );
+    OSL_ENSURE( rNewText.Len() != 0, "unexpected empty string" );
     if (rNewText.Len() == 0)
         return;
 
@@ -293,7 +280,7 @@ void SwHHCWrapper::ChangeText( const String &rNewText,
         // different length. Negative values allowed!
         long nCorrectionOffset = 0;
 
-        DBG_ASSERT(nIndices == 0 || nIndices == nConvTextLen,
+        OSL_ENSURE(nIndices == 0 || nIndices == nConvTextLen,
                 "mismatch between string length and sequence length!" );
 
         // find all substrings that need to be replaced (and only those)
@@ -324,7 +311,7 @@ void SwHHCWrapper::ChangeText( const String &rNewText,
 
                     // set selection to sub string to be replaced in original text
                     xub_StrLen nChgInNodeStartIndex = static_cast< xub_StrLen >( nStartIndex + nCorrectionOffset + nChgPos );
-                    DBG_ASSERT( rWrtShell.GetCrsr()->HasMark(), "cursor misplaced (nothing selected)" );
+                    OSL_ENSURE( rWrtShell.GetCrsr()->HasMark(), "cursor misplaced (nothing selected)" );
                     rWrtShell.GetCrsr()->GetMark()->nContent.Assign( pStartTxtNode, nChgInNodeStartIndex );
                     rWrtShell.GetCrsr()->GetPoint()->nContent.Assign( pStartTxtNode, nChgInNodeStartIndex + nChgLen );
 #ifdef DEBUG
@@ -425,7 +412,7 @@ void SwHHCWrapper::ReplaceUnit(
     static OUString aBracketedStart( C2U( "(" ) );
     static OUString aBracketedEnd( C2U( ")" ) );
 
-    DBG_ASSERT( nUnitStart >= 0 && nUnitEnd >= nUnitStart, "wrong arguments" );
+    OSL_ENSURE( nUnitStart >= 0 && nUnitEnd >= nUnitStart, "wrong arguments" );
     if (!(nUnitStart >= 0 && nUnitEnd >= nUnitStart))
         return;
 
@@ -439,7 +426,7 @@ void SwHHCWrapper::ReplaceUnit(
 
     OUString aOrigTxt( rWrtShell.GetSelTxt() );
     OUString aNewTxt( rReplaceWith );
-    DBG_ASSERT( aOrigTxt == rOrigText, "!! text mismatch !!" );
+    OSL_ENSURE( aOrigTxt == rOrigText, "!! text mismatch !!" );
     SwFmtRuby *pRuby = 0;
     sal_Bool bRubyBelow = sal_False;
     String  aNewOrigText;
@@ -482,7 +469,7 @@ void SwHHCWrapper::ReplaceUnit(
         }
         break;
         default:
-            DBG_ERROR( "unexpected case" );
+            OSL_FAIL("unexpected case" );
     }
     nUnitOffset += nUnitStart + aNewTxt.getLength();
 
@@ -504,14 +491,12 @@ void SwHHCWrapper::ReplaceUnit(
             // of the flag.
             rWrtShell.EndSelect();
 
-            rWrtShell.Left( 0, TRUE, aNewOrigText.Len(), TRUE, TRUE );
+            rWrtShell.Left( 0, sal_True, aNewOrigText.Len(), sal_True, sal_True );
         }
 
         pRuby->SetPosition( bRubyBelow );
         pRuby->SetAdjustment( RubyAdjust_CENTER );
-        //!! the following seem not to be needed
-        //pRuby->SetCharFmtName( const String& rNm );
-        //pRuby->SetCharFmtId( USHORT nNew );
+
 #ifdef DEBUG
         SwPaM *pPaM = rWrtShell.GetCrsr();
         (void)pPaM;
@@ -539,7 +524,7 @@ void SwHHCWrapper::ReplaceUnit(
             rWrtShell.SetMark();
             rWrtShell.GetCrsr()->GetMark()->nContent -= (xub_StrLen) aNewTxt.getLength();
 
-            DBG_ASSERT( GetTargetLanguage() == LANGUAGE_CHINESE_SIMPLIFIED || GetTargetLanguage() == LANGUAGE_CHINESE_TRADITIONAL,
+            OSL_ENSURE( GetTargetLanguage() == LANGUAGE_CHINESE_SIMPLIFIED || GetTargetLanguage() == LANGUAGE_CHINESE_TRADITIONAL,
                     "SwHHCWrapper::ReplaceUnit : unexpected target language" );
 
             sal_uInt16 aRanges[] = {
@@ -550,21 +535,19 @@ void SwHHCWrapper::ReplaceUnit(
             SfxItemSet aSet( rWrtShell.GetAttrPool(), aRanges );
             if (pNewUnitLanguage)
             {
-                //DBG_ASSERT(!IsSimilarChinese( *pNewUnitLanguage, nOldLang ),
-                //		"similar language should not be changed!");
                 aSet.Put( SvxLanguageItem( *pNewUnitLanguage, RES_CHRATR_CJK_LANGUAGE ) );
             }
 
             const Font *pTargetFont = GetTargetFont();
-            DBG_ASSERT( pTargetFont, "target font missing?" );
+            OSL_ENSURE( pTargetFont, "target font missing?" );
             if (pTargetFont && pNewUnitLanguage)
             {
                 SvxFontItem aFontItem = (SvxFontItem&) aSet.Get( RES_CHRATR_CJK_FONT );
-                aFontItem.GetFamilyName()   = pTargetFont->GetName();
-                aFontItem.GetFamily()       = pTargetFont->GetFamily();
-                aFontItem.GetStyleName()    = pTargetFont->GetStyleName();
-                aFontItem.GetPitch()        = pTargetFont->GetPitch();
-                aFontItem.GetCharSet()      = pTargetFont->GetCharSet();
+                aFontItem.SetFamilyName(    pTargetFont->GetName());
+                aFontItem.SetFamily(        pTargetFont->GetFamily());
+                aFontItem.SetStyleName(     pTargetFont->GetStyleName());
+                aFontItem.SetPitch(         pTargetFont->GetPitch());
+                aFontItem.SetCharSet( pTargetFont->GetCharSet() );
                 aSet.Put( aFontItem );
             }
 
@@ -588,7 +571,7 @@ sal_Bool SwHHCWrapper::HasRubySupport() const
 
 void SwHHCWrapper::Convert()
 {
-    DBG_ASSERT( pConvArgs == 0, "NULL pointer expected" );
+    OSL_ENSURE( pConvArgs == 0, "NULL pointer expected" );
     {
         SwPaM *pCrsr = pView->GetWrtShell().GetCrsr();
         SwPosition* pSttPos = pCrsr->Start();
@@ -618,13 +601,13 @@ void SwHHCWrapper::Convert()
                             pTxtNode, pSttPos->nContent,
                             pTxtNode, pSttPos->nContent );
         }
-        DBG_ASSERT( pConvArgs->pStartNode && pConvArgs->pStartNode->IsTxtNode(),
+        OSL_ENSURE( pConvArgs->pStartNode && pConvArgs->pStartNode->IsTxtNode(),
                 "failed to get proper start text node" );
-        DBG_ASSERT( pConvArgs->pEndNode && pConvArgs->pEndNode->IsTxtNode(),
+        OSL_ENSURE( pConvArgs->pEndNode && pConvArgs->pEndNode->IsTxtNode(),
                 "failed to get proper end text node" );
 
         // chinese conversion specific settings
-        DBG_ASSERT( IsChinese( GetSourceLanguage() ) == IsChinese( GetTargetLanguage() ),
+        OSL_ENSURE( IsChinese( GetSourceLanguage() ) == IsChinese( GetTargetLanguage() ),
                 "source and target language mismatch?" );
         if (IsChinese( GetTargetLanguage() ))
         {
@@ -702,7 +685,6 @@ sal_Bool SwHHCWrapper::ConvNext_impl( )
         return sal_False;
     }
 
-    //ResMgr* pMgr = DIALOG_MGR();
     sal_Bool bGoOn = sal_False;
 
     if ( bIsOtherCntnt )
@@ -724,29 +706,9 @@ sal_Bool SwHHCWrapper::ConvNext_impl( )
     }
     else
     {
-        // Ein BODY_Bereich erledigt, Frage nach dem anderen BODY_Bereich
-/*
-        //pWin->LeaveWait();
-
-        sal_uInt16 nResId = RID_SVXQB_CONTINUE;
-        QueryBox aBox( pWin, ResId( nResId, pMgr ) );
-        if ( aBox.Execute() != RET_YES )
-        {
-            // Verzicht auf den anderen Bereich, ggf. Frage nach Sonderbereich
-            //pWin->EnterWait();
-            bStartDone = bEndDone = sal_True;
-            return SpellNext();
-        }
-        else
-        {
-*/
             bStartChk = !bStartDone;
             ConvStart_impl( pConvArgs, bStartChk ? SVX_SPELL_BODY_START : SVX_SPELL_BODY_END );
             bGoOn = sal_True;
-/*
-        }
-        pWin->EnterWait();
-*/
     }
     return bGoOn;
 }
@@ -756,8 +718,6 @@ sal_Bool SwHHCWrapper::FindConvText_impl()
 {
     //! modified version of SvxSpellWrapper::FindSpellError
 
-    //ShowLanguageErrors();
-
     sal_Bool bFound = sal_False;
 
     pWin->EnterWait();
@@ -797,22 +757,20 @@ void SwHHCWrapper::ConvStart_impl( SwConversionArgs /* [out] */ *pConversionArgs
 void SwHHCWrapper::ConvEnd_impl( SwConversionArgs *pConversionArgs )
 {
     pView->SpellEnd( pConversionArgs );
-    //ShowLanguageErrors();
 }
 
 
 sal_Bool SwHHCWrapper::ConvContinue_impl( SwConversionArgs *pConversionArgs )
 {
     sal_Bool bProgress = !bIsDrawObj && !bIsSelection;
-//    bLastRet = aConvText.getLength() == 0;
     pConversionArgs->aConvText = OUString();
     pConversionArgs->nConvTextLang = LANGUAGE_NONE;
     uno::Any  aRet = bProgress ?
         pView->GetWrtShell().SpellContinue( &nPageCount, &nPageStart, pConversionArgs ) :
         pView->GetWrtShell().SpellContinue( &nPageCount, NULL, pConversionArgs );
-    //aRet >>= aConvText;
     return pConversionArgs->aConvText.getLength() != 0;
 }
 
 //////////////////////////////////////////////////////////////////////
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
