@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,9 +29,7 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
 
-
-
-#include <string> // HACK: prevent conflict between STLPORT and Workshop headers
+#include <string>
 
 #include "hintids.hxx"
 #include <vcl/svapp.hxx>
@@ -40,18 +39,12 @@
 #include <svl/srchitem.hxx>
 #include <sfx2/request.hxx>
 #include <swmodule.hxx>
-#ifndef _VIEW_HXX
 #include <view.hxx>
-#endif
 #include <wrtsh.hxx>
-#ifndef _DOCSH_HXX
 #include <docsh.hxx>
-#endif
 #include <viewopt.hxx>
 #include <frmatr.hxx>
-#ifndef _WDOCSH_HXX
 #include <wdocsh.hxx>
-#endif
 #include <uitool.hxx>
 #include <edtwin.hxx>
 #include <pagedesc.hxx>
@@ -60,30 +53,18 @@
 #include <workctrl.hxx>
 #include <usrpref.hxx>
 #include <scroll.hxx>
-#ifndef _WVIEW_HXX
 #include <wview.hxx>
-#endif
 
-#ifndef _CMDID_H
 #include <cmdid.h>
-#endif
-#ifndef _VIEW_HRC
 #include <view.hrc>
-#endif
-#ifndef _RIBBAR_HRC
 #include <ribbar.hrc>
-#endif
-#ifndef _HELPID_H
 #include <helpid.h>
-#endif
-#ifndef _GLOBALS_HRC
 #include <globals.hrc>
-#endif
 
 #include <IDocumentSettingAccess.hxx>
 #include <PostItMgr.hxx>
 
-USHORT	SwView::nMoveType = NID_PGE;
+sal_uInt16	SwView::nMoveType = NID_PGE;
 sal_Int32 SwView::nActMark = 0;
 
 
@@ -92,16 +73,16 @@ sal_Int32 SwView::nActMark = 0;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::frame;
 
-void SwView::SetZoom( SvxZoomType eZoomType, short nFactor, BOOL bViewOnly )
+void SwView::SetZoom( SvxZoomType eZoomType, short nFactor, sal_Bool bViewOnly )
 {
     _SetZoom( GetEditWin().GetOutputSizePixel(), eZoomType, nFactor, bViewOnly );
 }
 
 void SwView::_SetZoom( const Size &rEditSize, SvxZoomType eZoomType,
-                        short nFactor, BOOL bViewOnly )
+                        short nFactor, sal_Bool bViewOnly )
 {
-    BOOL bUnLockView = !pWrtShell->IsViewLocked();
-    pWrtShell->LockView( TRUE );
+    sal_Bool bUnLockView = !pWrtShell->IsViewLocked();
+    pWrtShell->LockView( sal_True );
     pWrtShell->LockPaint();
 
     {
@@ -109,7 +90,7 @@ void SwView::_SetZoom( const Size &rEditSize, SvxZoomType eZoomType,
 
     long nFac = nFactor;
 
-    BOOL bWeb = 0 != PTR_CAST(SwWebView, this);
+    sal_Bool bWeb = 0 != PTR_CAST(SwWebView, this);
     SwMasterUsrPref *pUsrPref = (SwMasterUsrPref*)SW_MOD()->GetUsrPref(bWeb);
 
     const SwPageDesc &rDesc = pWrtShell->GetPageDesc( pWrtShell->GetCurPageDesc() );
@@ -142,15 +123,9 @@ void SwView::_SetZoom( const Size &rEditSize, SvxZoomType eZoomType,
 
         if( SVX_ZOOM_OPTIMAL == eZoomType )
         {
-            if (pPostItMgr->HasNotes() && pPostItMgr->ShowNotes())
-            {
-                lLeftMargin = long(rLRSpace.GetLeft()) + aPageRect.Left() + nLeftOfst;
-            }
-            else
-            {
+            if (!pPostItMgr->HasNotes() || !pPostItMgr->ShowNotes())
                 aPageSize.Width() -= ( rLRSpace.GetLeft() + rLRSpace.GetRight() + nLeftOfst * 2 );
-                lLeftMargin = long(rLRSpace.GetLeft()) + aPageRect.Left() + nLeftOfst;
-            }
+            lLeftMargin = long(rLRSpace.GetLeft()) + DOCUMENTBORDER + nLeftOfst;
             nFac = aWindowSize.Width() * 100 / aPageSize.Width();
         }
         else if(SVX_ZOOM_WHOLEPAGE == eZoomType || SVX_ZOOM_PAGEWIDTH == eZoomType )
@@ -167,7 +142,7 @@ void SwView::_SetZoom( const Size &rEditSize, SvxZoomType eZoomType,
                 nFac = Min( nFac, nVisPercent );
             }
         }
-        else /*if( SVX_ZOOM_PAGEWIDTH_NOBORDER == eZoomType )*/
+        else
         {
             const long nTmpWidth = bAutomaticViewLayout ? aPageSize.Width() : aRootSize.Width();
             nFac = aWindowSize.Width() * 100 / nTmpWidth;
@@ -182,19 +157,19 @@ void SwView::_SetZoom( const Size &rEditSize, SvxZoomType eZoomType,
         //MasterUsrPrefs updaten UND DANACH die ViewOptions der aktuellen
         //View updaten.
         if ( !bViewOnly &&
-                (USHORT(nFac) 	   != pUsrPref->GetZoom() ||
-                BYTE  (eZoomType) != pUsrPref->GetZoomType()) )
+                (sal_uInt16(nFac) 	   != pUsrPref->GetZoom() ||
+                sal_uInt8  (eZoomType) != pUsrPref->GetZoomType()) )
         {
-            pUsrPref->SetZoom	 ( USHORT(nFac) );
+            pUsrPref->SetZoom	 ( sal_uInt16(nFac) );
             pUsrPref->SetZoomType( eZoomType );
             SW_MOD()->ApplyUsrPref( *pUsrPref,
                     bViewOnly ? this: 0,
                     bViewOnly ? VIEWOPT_DEST_VIEW_ONLY : 0 );
             pUsrPref->SetModified();
         }
-        if ( pOpt->GetZoom() != (USHORT) nFac )
+        if ( pOpt->GetZoom() != (sal_uInt16) nFac )
         {
-            aOpt.SetZoom	( USHORT(nFac) );
+            aOpt.SetZoom	( sal_uInt16(nFac) );
             aOpt.SetReadonly(pOpt->IsReadonly());
             pWrtShell->ApplyViewOptions( aOpt );
         }
@@ -223,9 +198,9 @@ void SwView::_SetZoom( const Size &rEditSize, SvxZoomType eZoomType,
         ((SwViewOption*)pWrtShell->GetViewOptions())->SetZoomType( eZoomType );
         CalcVisArea( rEditSize );	//fuer das Neuberechnen des sichtbaren Bereiches
     }
-    else if ( USHORT(nFac) != pOpt->GetZoom() )
+    else if ( sal_uInt16(nFac) != pOpt->GetZoom() )
     {
-        aOpt.SetZoom	( USHORT(nFac) );
+        aOpt.SetZoom	( sal_uInt16(nFac) );
         pWrtShell->ApplyViewOptions( aOpt );
     }
 
@@ -238,22 +213,13 @@ void SwView::_SetZoom( const Size &rEditSize, SvxZoomType eZoomType,
     }
     pWrtShell->UnlockPaint();
     if( bUnLockView )
-        pWrtShell->LockView( FALSE );
-
-//    if ( mpPostItMgr )
-//    {
-//        mpPostItMgr->Rescale();
-//        mpPostItMgr->CalcRects();
-//        mpPostItMgr->LayoutPostIts();
-//    }
-
-//	eZoom = eZoomType;
+        pWrtShell->LockView( sal_False );
 }
 
-void SwView::SetViewLayout( USHORT nColumns, bool bBookMode, BOOL bViewOnly )
+void SwView::SetViewLayout( sal_uInt16 nColumns, bool bBookMode, sal_Bool bViewOnly )
 {
-    const BOOL bUnLockView = !pWrtShell->IsViewLocked();
-    pWrtShell->LockView( TRUE );
+    const sal_Bool bUnLockView = !pWrtShell->IsViewLocked();
+    pWrtShell->LockView( sal_True );
     pWrtShell->LockPaint();
 
     {
@@ -262,7 +228,7 @@ void SwView::SetViewLayout( USHORT nColumns, bool bBookMode, BOOL bViewOnly )
 
     if ( !GetViewFrame()->GetFrame().IsInPlace() && !bViewOnly )
     {
-        const BOOL bWeb = 0 != PTR_CAST(SwWebView, this);
+        const sal_Bool bWeb = 0 != PTR_CAST(SwWebView, this);
         SwMasterUsrPref *pUsrPref = (SwMasterUsrPref*)SW_MOD()->GetUsrPref(bWeb);
 
         //MasterUsrPrefs updaten UND DANACH die ViewOptions der aktuellen
@@ -297,7 +263,7 @@ void SwView::SetViewLayout( USHORT nColumns, bool bBookMode, BOOL bViewOnly )
 
     pWrtShell->UnlockPaint();
     if( bUnLockView )
-        pWrtShell->LockView( FALSE );
+        pWrtShell->LockView( sal_False );
 
     SfxBindings& rBnd = GetViewFrame()->GetBindings();
     rBnd.Invalidate( SID_ATTR_VIEWLAYOUT );
@@ -307,29 +273,28 @@ void SwView::SetViewLayout( USHORT nColumns, bool bBookMode, BOOL bViewOnly )
 /*
  * Scrollbar - Handler
  */
-
 IMPL_LINK( SwView, WindowChildEventListener, VclSimpleEvent*, pEvent )
 {
-    DBG_ASSERT( pEvent && pEvent->ISA( VclWindowEvent ), "Unknown WindowEvent!" );
+    OSL_ENSURE( pEvent && pEvent->ISA( VclWindowEvent ), "Unknown WindowEvent!" );
     if ( pEvent && pEvent->ISA( VclWindowEvent ) )
     {
         VclWindowEvent *pVclEvent = static_cast< VclWindowEvent * >( pEvent );
-        DBG_ASSERT( pVclEvent->GetWindow(), "Window???" );
+        OSL_ENSURE( pVclEvent->GetWindow(), "Window???" );
         Window* pChildWin = static_cast< Window* >( pVclEvent->GetData() );
 
         switch ( pVclEvent->GetId() )
         {
             case VCLEVENT_WINDOW_HIDE:
                 if( pChildWin == pHScrollbar )
-                    ShowHScrollbar( FALSE );
+                    ShowHScrollbar( sal_False );
                 else if( pChildWin == pVScrollbar )
-                    ShowVScrollbar( FALSE );
+                    ShowVScrollbar( sal_False );
                 break;
             case VCLEVENT_WINDOW_SHOW:
                 if( pChildWin == pHScrollbar )
-                    ShowHScrollbar( TRUE );
+                    ShowHScrollbar( sal_True );
                 else if( pChildWin == pVScrollbar )
-                    ShowVScrollbar( TRUE );
+                    ShowVScrollbar( sal_True );
                 break;
         }
     }
@@ -337,12 +302,12 @@ IMPL_LINK( SwView, WindowChildEventListener, VclSimpleEvent*, pEvent )
     return 0;
 }
 
-int SwView::_CreateScrollbar( BOOL bHori )
+int SwView::_CreateScrollbar( sal_Bool bHori )
 {
     Window *pMDI = &GetViewFrame()->GetWindow();
     SwScrollbar** ppScrollbar = bHori ? &pHScrollbar : &pVScrollbar;
 
-    ASSERT( !*ppScrollbar, "vorher abpruefen!" )
+    OSL_ENSURE( !*ppScrollbar, "vorher abpruefen!" );
 
     if( !bHori )
         CreatePageButtons( !bShowAtResize );
@@ -355,9 +320,9 @@ int SwView::_CreateScrollbar( BOOL bHori )
         (*ppScrollbar)->SetScrollHdl( LINK( this, SwView, ScrollHdl ));
     (*ppScrollbar)->SetEndScrollHdl( LINK( this, SwView, EndScrollHdl ));
 
-    (*ppScrollbar)->EnableDrag( TRUE );
+    (*ppScrollbar)->EnableDrag( sal_True );
 
-    (*ppScrollbar)->SetAuto( TRUE );
+    (*ppScrollbar)->SetAuto( sal_True );
 
     if(GetWindow())
         InvalidateBorder();
@@ -370,12 +335,12 @@ int SwView::_CreateScrollbar( BOOL bHori )
     return 1;
 }
 
-void SwView::CreatePageButtons(BOOL bShow)
+void SwView::CreatePageButtons(sal_Bool bShow)
 {
     Window *pMDI = &GetViewFrame()->GetWindow();
-    pPageUpBtn		= new SwHlpImageButton(pMDI, SW_RES( BTN_PAGEUP ), TRUE );
+    pPageUpBtn		= new SwHlpImageButton(pMDI, SW_RES( BTN_PAGEUP ), sal_True );
     pPageUpBtn->SetHelpId(HID_SCRL_PAGEUP);
-    pPageDownBtn	= new SwHlpImageButton(pMDI, SW_RES( BTN_PAGEDOWN ), FALSE );
+    pPageDownBtn	= new SwHlpImageButton(pMDI, SW_RES( BTN_PAGEDOWN ), sal_False );
     pPageDownBtn->SetHelpId(HID_SCRL_PAGEDOWN);
     Reference< XFrame > xFrame = GetViewFrame()->GetFrame().GetFrameInterface();
     pNaviBtn = new SwNaviImageButton(pMDI, xFrame );
@@ -407,9 +372,7 @@ IMPL_LINK( SwView, BtnPage, Button *, pButton )
     Application::PostUserEvent( STATIC_LINK(this, SwView, MoveNavigationHdl), pbNext );
     return 0;
 }
-/*-----------------20.06.97 10:46-------------------
 
---------------------------------------------------*/
 IMPL_STATIC_LINK( SwView, MoveNavigationHdl, bool *, pbNext )
 {
     if ( !pbNext )
@@ -432,12 +395,12 @@ IMPL_STATIC_LINK( SwView, MoveNavigationHdl, bool *, pbNext )
         case NID_GRF:
         case NID_OLE:
         {
-            USHORT eType = GOTOOBJ_FLY_FRM;
+            sal_uInt16 eType = GOTOOBJ_FLY_FRM;
             if(nMoveType == NID_GRF)
                 eType = GOTOOBJ_FLY_GRF;
             else if(nMoveType == NID_OLE)
                 eType = GOTOOBJ_FLY_OLE;
-            BOOL bSuccess = bNext ?
+            sal_Bool bSuccess = bNext ?
                     rSh.GotoNextFly(eType) :
                         rSh.GotoPrevFly(eType);
             if(bSuccess)
@@ -533,7 +496,7 @@ IMPL_STATIC_LINK( SwView, MoveNavigationHdl, bool *, pbNext )
         case NID_SRCH_REP:
         if(pSrchItem)
         {
-            BOOL bBackward = pSrchItem->GetBackward();
+            sal_Bool bBackward = pSrchItem->GetBackward();
             if(rSh.HasSelection() && !bNext == rSh.IsCrsrPtAtEnd())
                 rSh.SwapPam();
             pSrchItem->SetBackward(!bNext);
@@ -551,7 +514,7 @@ IMPL_STATIC_LINK( SwView, MoveNavigationHdl, bool *, pbNext )
             break;
 
         case NID_TABLE_FORMULA_ERROR:
-            rSh.GotoNxtPrvTblFormula( bNext, TRUE );
+            rSh.GotoNxtPrvTblFormula( bNext, sal_True );
             break;
     }
     pThis->pEditWin->GrabFocus();
@@ -559,16 +522,6 @@ IMPL_STATIC_LINK( SwView, MoveNavigationHdl, bool *, pbNext )
     return 0;
 }
 
-/*************************************************************************
-|*
-|*	SwView::CreateTab()
-|*
-|*	Beschreibung
-|*	Ersterstellung		VB 29.05.91
-|*	Letzte Aenderung	OS 09.05.96
-|*
-*************************************************************************/
-
 int SwView::CreateTab()
 {
     pHRuler->SetActive(GetFrame() && IsActive());
@@ -578,16 +531,6 @@ int SwView::CreateTab()
     return 1;
 }
 
-/*************************************************************************
-|*
-|*	SwView::KillTab()
-|*
-|*	Beschreibung
-|*	Ersterstellung		VB 29.05.91
-|*	Letzte Aenderung	OS 09.05.96
-|*
-*************************************************************************/
-
 int SwView::KillTab()
 {
     pHRuler->Hide();
@@ -612,28 +555,16 @@ void SwView::ChangeVLinealMetric( FieldUnit eUnit )
         pVRuler->Invalidate();
     }
 }
-/* -----------------------------07.04.01 17:09--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwView::GetVLinealMetric(FieldUnit& eToFill) const
 {
     eToFill = pVRuler->GetUnit();
 }
-/* -----------------------------07.04.01 17:09--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwView::GetHLinealMetric(FieldUnit& eToFill) const
 {
     eToFill = pHRuler->GetUnit();
 }
-/*************************************************************************
-|*
-|*	SwView::CreateVLineal()
-|*
-|*	Beschreibung
-|*	Ersterstellung	VB 29.05.91
-|*
-*************************************************************************/
 
 int SwView::CreateVLineal()
 {
@@ -645,15 +576,6 @@ int SwView::CreateVLineal()
     return 1;
 }
 
-/*************************************************************************
-|*
-|*	SwView::KillVLineal()
-|*
-|*	Beschreibung
-|*	Ersterstellung	VB 29.05.91
-|*
-*************************************************************************/
-
 int SwView::KillVLineal()
 {
     pVRuler->Hide();
@@ -661,19 +583,10 @@ int SwView::KillVLineal()
     InvalidateBorder();
     return 1;
 }
-/*************************************************************************
-|*
-|*	SwView::ExecRulerClick()
-|*
-|*	Beschreibung
-|*	Ersterstellung	OS 15.06.95
-|*	Letzte Aenderung
-|*
-*************************************************************************/
 
 IMPL_LINK( SwView, ExecRulerClick, Ruler *, pRuler )
 {
-    USHORT nDefPage = 0;
+    sal_uInt16 nDefPage = 0;
     switch( pRuler->GetClickType() )
     {
         case RULER_TYPE_DONTKNOW:
@@ -695,24 +608,16 @@ IMPL_LINK( SwView, ExecRulerClick, Ruler *, pRuler )
     return 0;
 }
 
-
-/*-----------------20.02.97 09:11-------------------
-
---------------------------------------------------*/
-
-USHORT SwView::GetMoveType()
+sal_uInt16 SwView::GetMoveType()
 {
     return nMoveType;
 }
-/*-----------------20.02.97 09:11-------------------
 
---------------------------------------------------*/
-
-void SwView::SetMoveType(USHORT nSet)
+void SwView::SetMoveType(sal_uInt16 nSet)
 {
-    BOOL bLastPage = nMoveType == NID_PGE;
+    sal_Bool bLastPage = nMoveType == NID_PGE;
     nMoveType = nSet;
-    BOOL bNewPage = nMoveType == NID_PGE;
+    sal_Bool bNewPage = nMoveType == NID_PGE;
     if(bNewPage != bLastPage)
     {
         Color aColor(bNewPage ? COL_BLACK : VIEW_IMAGECOLOR);
@@ -726,18 +631,11 @@ void SwView::SetMoveType(USHORT nSet)
     }
 }
 
-/*-----------------20.06.97 11:18-------------------
-
---------------------------------------------------*/
 void SwView::SetActMark(sal_Int32 nSet)
 {
     nActMark = nSet;
 }
 
-/*-----------------15.03.97 10:53-------------------
-
---------------------------------------------------*/
-
 void SwView::SetImageButtonColor(Color& rColor)
 {
     if(pPageUpBtn)
@@ -746,40 +644,33 @@ void SwView::SetImageButtonColor(Color& rColor)
         pPageDownBtn->SetControlForeground(rColor);
     }
 }
-/* -----------------------------2002/06/26 13:57------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwView::ShowHScrollbar(sal_Bool bShow)
 {
-    DBG_ASSERT(pHScrollbar, "Scrollbar invalid");
+    OSL_ENSURE(pHScrollbar, "Scrollbar invalid");
     pHScrollbar->ExtendedShow(bShow);
 }
-/* -----------------------------2002/06/26 13:57------------------------------
 
- ---------------------------------------------------------------------------*/
 sal_Bool SwView::IsHScrollbarVisible()const
 {
-    DBG_ASSERT(pHScrollbar, "Scrollbar invalid");
-    return pHScrollbar->IsVisible( FALSE ) || pHScrollbar->IsAuto();
+    OSL_ENSURE(pHScrollbar, "Scrollbar invalid");
+    return pHScrollbar->IsVisible( sal_False ) || pHScrollbar->IsAuto();
 }
-/* -----------------------------2002/06/26 13:57------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwView::ShowVScrollbar(sal_Bool bShow)
 {
-    DBG_ASSERT(pVScrollbar, "Scrollbar invalid");
+    OSL_ENSURE(pVScrollbar, "Scrollbar invalid");
     pVScrollbar->ExtendedShow(bShow);
     pPageUpBtn->Show(bShow);
     pPageDownBtn->Show(bShow);
     pNaviBtn->Show(bShow);
 }
-/* -----------------------------2002/06/26 13:57------------------------------
 
- ---------------------------------------------------------------------------*/
 sal_Bool SwView::IsVScrollbarVisible()const
 {
-    DBG_ASSERT(pVScrollbar, "Scrollbar invalid");
-    return pVScrollbar->IsVisible( FALSE );
+    OSL_ENSURE(pVScrollbar, "Scrollbar invalid");
+    return pVScrollbar->IsVisible( sal_False );
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
