@@ -53,7 +53,7 @@
 #include <comphelper/ChainablePropertySetInfo.hxx>
 #include <edtwin.hxx>
 #include <rtl/ustrbuf.hxx>
-
+#include <tools/urlobj.hxx>
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::beans;
@@ -246,7 +246,7 @@ Reference< XPropertySet >  SwXModule::getViewSettings(void) throw( uno::RuntimeE
     if(!pxViewSettings)
     {
         ((SwXModule*)this)->pxViewSettings = new Reference< XPropertySet > ;
-        OSL_ENSURE(false, "Web or Text?");
+        OSL_FAIL("Web or Text?");
         *pxViewSettings = static_cast < HelperBaseNoState * > ( new SwXViewSettings( sal_False, 0 ) );
     }
     return *pxViewSettings;
@@ -258,7 +258,7 @@ Reference< XPropertySet >  SwXModule::getPrintSettings(void) throw( uno::Runtime
     if(!pxPrintSettings)
     {
         ((SwXModule*)this)->pxPrintSettings = new Reference< XPropertySet > ;
-        OSL_ENSURE(false, "Web or Text?");
+        OSL_FAIL("Web or Text?");
         *pxPrintSettings = static_cast < HelperBaseNoState * > ( new SwXPrintSettings ( PRINT_SETTINGS_MODULE ) );
     }
     return *pxPrintSettings;
@@ -275,9 +275,9 @@ sal_Bool SwXModule::supportsService(const OUString& rServiceName) throw( Runtime
     for(sal_Int32 nService = 0; nService < aNames.getLength(); nService++)
     {
         if(aNames.getConstArray()[nService] == rServiceName)
-            return TRUE;
+            return sal_True;
     }
-    return FALSE;
+    return sal_False;
 }
 
 Sequence< OUString > SwXModule::getSupportedServiceNames(void) throw( RuntimeException )
@@ -316,13 +316,7 @@ void SwXPrintSettings::_preSetValues ()
         {
             if (!mpDoc)
                 throw IllegalArgumentException ();
-            if ( !mpDoc->getPrintData() )
-            {
-                mpPrtOpt = new SwPrintData;
-                mpDoc->setPrintData ( *mpPrtOpt );
-                delete mpPrtOpt;
-            }
-            mpPrtOpt = mpDoc->getPrintData();
+            mpPrtOpt = const_cast< SwPrintData * >(&mpDoc->getPrintData());
         }
         break;
     }
@@ -479,13 +473,7 @@ void SwXPrintSettings::_preGetValues ()
         {
             if (!mpDoc)
                 throw IllegalArgumentException ();
-            if ( !mpDoc->getPrintData() )
-            {
-                mpPrtOpt = new SwPrintData;
-                mpDoc->setPrintData ( *mpPrtOpt );
-                delete mpPrtOpt;
-            }
-            mpPrtOpt = mpDoc->getPrintData();
+            mpPrtOpt = const_cast< SwPrintData * >(&mpDoc->getPrintData());
         }
         break;
     }
@@ -651,10 +639,10 @@ void SwXViewSettings::_setSingleValue( const comphelper::PropertyInfo & rInfo, c
         case  HANDLE_VIEWSET_DRAWINGS              :   mpViewOption->SetDraw(bVal);	break;
         case  HANDLE_VIEWSET_FIELD_COMMANDS        :   mpViewOption->SetFldName(bVal);	break;
         case  HANDLE_VIEWSET_ANNOTATIONS           :   mpViewOption->SetPostIts(bVal);	break;
-        case  HANDLE_VIEWSET_INDEX_MARK_BACKGROUND :   mpViewOption->SetAppearanceFlag(VIEWOPT_FIELD_SHADINGS, bVal, TRUE);  break;
+        case  HANDLE_VIEWSET_INDEX_MARK_BACKGROUND :   mpViewOption->SetAppearanceFlag(VIEWOPT_FIELD_SHADINGS, bVal, sal_True);  break;
         case  HANDLE_VIEWSET_NONPRINTING_CHARACTERS:   mpViewOption->SetViewMetaChars( bVal ); break;
-        case  HANDLE_VIEWSET_FOOTNOTE_BACKGROUND   :   mpViewOption->SetAppearanceFlag(VIEWOPT_FIELD_SHADINGS, bVal, TRUE); break;
-        case  HANDLE_VIEWSET_TEXT_FIELD_BACKGROUND :   mpViewOption->SetAppearanceFlag(VIEWOPT_FIELD_SHADINGS, bVal, TRUE);    break;
+        case  HANDLE_VIEWSET_FOOTNOTE_BACKGROUND   :   mpViewOption->SetAppearanceFlag(VIEWOPT_FIELD_SHADINGS, bVal, sal_True); break;
+        case  HANDLE_VIEWSET_TEXT_FIELD_BACKGROUND :   mpViewOption->SetAppearanceFlag(VIEWOPT_FIELD_SHADINGS, bVal, sal_True);    break;
         case  HANDLE_VIEWSET_PARA_BREAKS           :   mpViewOption->SetParagraph(bVal);	break;
         case  HANDLE_VIEWSET_SOFT_HYPHENS          :   mpViewOption->SetSoftHyph(bVal);	break;
         case  HANDLE_VIEWSET_SPACES                :   mpViewOption->SetBlank(bVal);	break;
@@ -664,7 +652,7 @@ void SwXViewSettings::_setSingleValue( const comphelper::PropertyInfo & rInfo, c
         case  HANDLE_VIEWSET_HIDDEN_TEXT           :   mpViewOption->SetShowHiddenField(bVal);  break;
         case  HANDLE_VIEWSET_HIDDEN_CHARACTERS     :   mpViewOption->SetShowHiddenChar(bVal); break;
         case  HANDLE_VIEWSET_HIDDEN_PARAGRAPHS     :   mpViewOption->SetShowHiddenPara(bVal);	break;
-        case  HANDLE_VIEWSET_TABLE_BOUNDARIES      :   mpViewOption->SetAppearanceFlag(VIEWOPT_TABLE_BOUNDARIES, bVal, TRUE);    break;
+        case  HANDLE_VIEWSET_TABLE_BOUNDARIES      :   mpViewOption->SetAppearanceFlag(VIEWOPT_TABLE_BOUNDARIES, bVal, sal_True);    break;
         case  HANDLE_VIEWSET_TEXT_BOUNDARIES       :   mpViewOption->SetDocBoundaries(bVal);    break;
         case  HANDLE_VIEWSET_SMOOTH_SCROLLING      :   mpViewOption->SetSmoothScroll(bVal);	break;
         case  HANDLE_VIEWSET_SOLID_MARK_HANDLES    :   mpViewOption->SetSolidMarkHdl(bVal);	break;
@@ -754,8 +742,13 @@ void SwXViewSettings::_setSingleValue( const comphelper::PropertyInfo & rInfo, c
         break;
         case HANDLE_VIEWSET_ONLINE_LAYOUT :
         {
-            if( pView && !bVal != !pView->GetWrtShell().getIDocumentSettingAccess()->get(IDocumentSettingAccess::BROWSE_MODE) )
-                pView->GetDocShell()->ToggleBrowserMode(bVal, pView );
+            if( pView && !bVal != !pView->GetWrtShell().GetViewOptions()->getBrowseMode() )
+            {
+                SwViewOption aOpt( *pView->GetWrtShell().GetViewOptions() );
+                aOpt.setBrowseMode( bVal );
+                pView->GetWrtShell().ApplyViewOptions( aOpt );
+                pView->RecheckBrowseMode();
+            }
         }
         break;
         case HANDLE_VIEWSET_HELP_URL :
@@ -765,14 +758,12 @@ void SwXViewSettings::_setSingleValue( const comphelper::PropertyInfo & rInfo, c
                 OUString sHelpURL;
                 if ( ! ( rValue >>= sHelpURL ) )
                     throw IllegalArgumentException();
-                SwEditWin &rEditWin = pView->GetEditWin();
-                OUString sPrefix = sHelpURL.copy ( 0, 4 );
-                // Make sure we have a valid string...should be in the format HID:12345
-                if ( ! sPrefix.equalsAsciiL ( RTL_CONSTASCII_STRINGPARAM ( "HID:" ) ) )
+
+                INetURLObject aHID( sHelpURL );
+                if ( aHID.GetProtocol() == INET_PROT_HID )
+                      pView->GetEditWin().SetHelpId( rtl::OUStringToOString( aHID.GetURLPath(), RTL_TEXTENCODING_UTF8 ) );
+                else
                     throw IllegalArgumentException ();
-                OUString sNumber = sHelpURL.copy ( 4 );
-                sal_uInt32 nHelpId = sNumber.toInt32();
-                rEditWin.SetHelpId ( nHelpId );
             }
             else
                 throw UnknownPropertyException();
@@ -859,13 +850,13 @@ void SwXViewSettings::_preGetValues ()
 void SwXViewSettings::_getSingleValue( const comphelper::PropertyInfo & rInfo, uno::Any & rValue )
     throw(UnknownPropertyException, WrappedTargetException )
 {
-    sal_Bool bBool = TRUE;
+    sal_Bool bBool = sal_True;
     sal_Bool bBoolVal;
     switch( rInfo.mnHandle )
     {
         case  HANDLE_VIEWSET_SHOW_RULER:                bBoolVal = mpConstViewOption->IsViewAnyRuler();   break;
-        case  HANDLE_VIEWSET_HRULER :                   bBoolVal = mpConstViewOption->IsViewHRuler(TRUE);   break;
-        case  HANDLE_VIEWSET_VRULER :                   bBoolVal = mpConstViewOption->IsViewVRuler(TRUE);break;
+        case  HANDLE_VIEWSET_HRULER :                   bBoolVal = mpConstViewOption->IsViewHRuler(sal_True);   break;
+        case  HANDLE_VIEWSET_VRULER :                   bBoolVal = mpConstViewOption->IsViewVRuler(sal_True);break;
         case  HANDLE_VIEWSET_VRULER_RIGHT          :   bBoolVal = mpConstViewOption->IsVRulerRight();break;
         case  HANDLE_VIEWSET_HSCROLL:                   bBoolVal = mpConstViewOption->IsViewHScrollBar();break;
         case  HANDLE_VIEWSET_VSCROLL: 					bBoolVal = mpConstViewOption->IsViewVScrollBar();break;
@@ -895,28 +886,28 @@ void SwXViewSettings::_getSingleValue( const comphelper::PropertyInfo & rInfo, u
         case  HANDLE_VIEWSET_IS_RASTER_VISIBLE     : bBoolVal = mpConstViewOption->IsGridVisible(); break;
         case  HANDLE_VIEWSET_IS_SNAP_TO_RASTER     : bBoolVal = mpConstViewOption->IsSnap(); break;
         case  HANDLE_VIEWSET_RASTER_RESOLUTION_X   :
-            bBool = FALSE;
+            bBool = sal_False;
             rValue <<= (sal_Int32) TWIP_TO_MM100(mpConstViewOption->GetSnapSize().Width());
         break;
         case  HANDLE_VIEWSET_RASTER_RESOLUTION_Y   :
-            bBool = FALSE;
+            bBool = sal_False;
             rValue <<= (sal_Int32) TWIP_TO_MM100(mpConstViewOption->GetSnapSize().Height());
         break;
         case  HANDLE_VIEWSET_RASTER_SUBDIVISION_X  :
-            bBool = FALSE;
+            bBool = sal_False;
             rValue <<= (sal_Int32) mpConstViewOption->GetDivisionX();
         break;
         case  HANDLE_VIEWSET_RASTER_SUBDIVISION_Y  :
-            bBool = FALSE;
+            bBool = sal_False;
             rValue <<= (sal_Int32) mpConstViewOption->GetDivisionY();
         break;
         case  HANDLE_VIEWSET_ZOOM                   :
-                bBool = FALSE;
+                bBool = sal_False;
                 rValue <<= (sal_Int16)mpConstViewOption->GetZoom();
         break;
         case HANDLE_VIEWSET_ZOOM_TYPE:
         {
-            bBool = FALSE;
+            bBool = sal_False;
             sal_Int16 nRet(0);
             switch (mpConstViewOption->GetZoomType())
             {
@@ -936,7 +927,7 @@ void SwXViewSettings::_getSingleValue( const comphelper::PropertyInfo & rInfo, u
                     nRet = view::DocumentZoomType::PAGE_WIDTH_EXACT;
                 break;
                 default:
-                    OSL_ENSURE(false, "SwXViewSettings: invalid zoom type");
+                    OSL_FAIL("SwXViewSettings: invalid zoom type");
                 break;
             }
             rValue <<= nRet;
@@ -944,7 +935,7 @@ void SwXViewSettings::_getSingleValue( const comphelper::PropertyInfo & rInfo, u
         break;
         case HANDLE_VIEWSET_ONLINE_LAYOUT:
             if(pView)
-                bBoolVal = pView->GetWrtShell().getIDocumentSettingAccess()->get(IDocumentSettingAccess::BROWSE_MODE);
+                bBoolVal = pView->GetWrtShell().GetViewOptions()->getBrowseMode();
         break;
         case HANDLE_VIEWSET_HELP_URL :
         {
@@ -952,9 +943,9 @@ void SwXViewSettings::_getSingleValue( const comphelper::PropertyInfo & rInfo, u
             {
                 bBool = sal_False;
                 OUStringBuffer sHelpURL;
-                sHelpURL.appendAscii ( "HID:" );
+                sHelpURL.appendAscii ( INET_HID_SCHEME );
                 SwEditWin &rEditWin = pView->GetEditWin();
-                sHelpURL.append ( static_cast < sal_Int32 > ( rEditWin.GetHelpId() ) );
+                sHelpURL.append( rtl::OStringToOUString( rEditWin.GetHelpId(), RTL_TEXTENCODING_UTF8 ) );
                 rValue <<= sHelpURL.makeStringAndClear();
             }
             else
@@ -993,7 +984,7 @@ void SwXViewSettings::_getSingleValue( const comphelper::PropertyInfo & rInfo, u
             bBool = sal_False;
         }
         break;
-        default: OSL_ENSURE(false, "there is no such ID!");
+        default: OSL_FAIL("there is no such ID!");
     }
     if( bBool )
         rValue.setValue(&bBoolVal, ::getBooleanCppuType());
